Class: Aws::GuardDuty::Types::Account

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about the Amazon Web Services account within which the activity took place.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

Name of the member’s Amazon Web Services account.

Returns:

  • (String)


184
185
186
187
188
189
# File 'lib/aws-sdk-guardduty/types.rb', line 184

class Account < Struct.new(
  :uid,
  :name)
  SENSITIVE = []
  include Aws::Structure
end

#uidString

The Amazon Web Services account ID within which the activity took place. This may differ from the account that owns the user identity.

Returns:

  • (String)


184
185
186
187
188
189
# File 'lib/aws-sdk-guardduty/types.rb', line 184

class Account < Struct.new(
  :uid,
  :name)
  SENSITIVE = []
  include Aws::Structure
end