Class: Aws::GuardDuty::Types::Actor

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Information about the actors involved in an attack sequence.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

ID of the threat actor.

Returns:

  • (String)


410
411
412
413
414
415
416
417
# File 'lib/aws-sdk-guardduty/types.rb', line 410

class Actor < Struct.new(
  :id,
  :user,
  :session,
  :process)
  SENSITIVE = []
  include Aws::Structure
end

#processTypes::ActorProcess

Contains information about the process associated with the threat actor. This includes details such as process name, path, execution time, and unique identifiers that help track the actor's activities within the system.

Returns:



410
411
412
413
414
415
416
417
# File 'lib/aws-sdk-guardduty/types.rb', line 410

class Actor < Struct.new(
  :id,
  :user,
  :session,
  :process)
  SENSITIVE = []
  include Aws::Structure
end

#sessionTypes::Session

Contains information about the user session where the activity initiated.

Returns:



410
411
412
413
414
415
416
417
# File 'lib/aws-sdk-guardduty/types.rb', line 410

class Actor < Struct.new(
  :id,
  :user,
  :session,
  :process)
  SENSITIVE = []
  include Aws::Structure
end

#userTypes::User

Contains information about the user credentials used by the threat actor.

Returns:



410
411
412
413
414
415
416
417
# File 'lib/aws-sdk-guardduty/types.rb', line 410

class Actor < Struct.new(
  :id,
  :user,
  :session,
  :process)
  SENSITIVE = []
  include Aws::Structure
end