Class: Aws::GuardDuty::Types::ArchiveFindingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ArchiveFindingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The ID of the detector that specifies the GuardDuty service whose findings you want to archive.
-
#finding_ids ⇒ Array<String>
The IDs of the findings that you want to archive.
Instance Attribute Details
#detector_id ⇒ String
The ID of the detector that specifies the GuardDuty service whose findings you want to archive.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
657 658 659 660 661 662 |
# File 'lib/aws-sdk-guardduty/types.rb', line 657 class ArchiveFindingsRequest < Struct.new( :detector_id, :finding_ids) SENSITIVE = [] include Aws::Structure end |
#finding_ids ⇒ Array<String>
The IDs of the findings that you want to archive.
657 658 659 660 661 662 |
# File 'lib/aws-sdk-guardduty/types.rb', line 657 class ArchiveFindingsRequest < Struct.new( :detector_id, :finding_ids) SENSITIVE = [] include Aws::Structure end |