Class: Aws::GuardDuty::Types::AwsApiCallAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::AwsApiCallAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the API action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#affected_resources ⇒ Hash<String,String>
The details of the Amazon Web Services account that made the API call.
-
#api ⇒ String
The Amazon Web Services API name.
-
#caller_type ⇒ String
The Amazon Web Services API caller type.
-
#domain_details ⇒ Types::DomainDetails
The domain information for the Amazon Web Services API call.
-
#error_code ⇒ String
The error code of the failed Amazon Web Services API action.
-
#remote_account_details ⇒ Types::RemoteAccountDetails
The details of the Amazon Web Services account that made the API call.
-
#remote_ip_details ⇒ Types::RemoteIpDetails
The remote IP information of the connection that initiated the Amazon Web Services API call.
-
#service_name ⇒ String
The Amazon Web Services service name whose API was invoked.
-
#user_agent ⇒ String
The agent through which the API request was made.
Instance Attribute Details
#affected_resources ⇒ Hash<String,String>
The details of the Amazon Web Services account that made the API call. This field identifies the resources that were affected by this API call.
699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/aws-sdk-guardduty/types.rb', line 699 class AwsApiCallAction < Struct.new( :api, :caller_type, :domain_details, :error_code, :user_agent, :remote_ip_details, :service_name, :remote_account_details, :affected_resources) SENSITIVE = [] include Aws::Structure end |
#api ⇒ String
The Amazon Web Services API name.
699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/aws-sdk-guardduty/types.rb', line 699 class AwsApiCallAction < Struct.new( :api, :caller_type, :domain_details, :error_code, :user_agent, :remote_ip_details, :service_name, :remote_account_details, :affected_resources) SENSITIVE = [] include Aws::Structure end |
#caller_type ⇒ String
The Amazon Web Services API caller type.
699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/aws-sdk-guardduty/types.rb', line 699 class AwsApiCallAction < Struct.new( :api, :caller_type, :domain_details, :error_code, :user_agent, :remote_ip_details, :service_name, :remote_account_details, :affected_resources) SENSITIVE = [] include Aws::Structure end |
#domain_details ⇒ Types::DomainDetails
The domain information for the Amazon Web Services API call.
699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/aws-sdk-guardduty/types.rb', line 699 class AwsApiCallAction < Struct.new( :api, :caller_type, :domain_details, :error_code, :user_agent, :remote_ip_details, :service_name, :remote_account_details, :affected_resources) SENSITIVE = [] include Aws::Structure end |
#error_code ⇒ String
The error code of the failed Amazon Web Services API action.
699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/aws-sdk-guardduty/types.rb', line 699 class AwsApiCallAction < Struct.new( :api, :caller_type, :domain_details, :error_code, :user_agent, :remote_ip_details, :service_name, :remote_account_details, :affected_resources) SENSITIVE = [] include Aws::Structure end |
#remote_account_details ⇒ Types::RemoteAccountDetails
The details of the Amazon Web Services account that made the API call. This field appears if the call was made from outside your account.
699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/aws-sdk-guardduty/types.rb', line 699 class AwsApiCallAction < Struct.new( :api, :caller_type, :domain_details, :error_code, :user_agent, :remote_ip_details, :service_name, :remote_account_details, :affected_resources) SENSITIVE = [] include Aws::Structure end |
#remote_ip_details ⇒ Types::RemoteIpDetails
The remote IP information of the connection that initiated the Amazon Web Services API call.
699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/aws-sdk-guardduty/types.rb', line 699 class AwsApiCallAction < Struct.new( :api, :caller_type, :domain_details, :error_code, :user_agent, :remote_ip_details, :service_name, :remote_account_details, :affected_resources) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The Amazon Web Services service name whose API was invoked.
699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/aws-sdk-guardduty/types.rb', line 699 class AwsApiCallAction < Struct.new( :api, :caller_type, :domain_details, :error_code, :user_agent, :remote_ip_details, :service_name, :remote_account_details, :affected_resources) SENSITIVE = [] include Aws::Structure end |
#user_agent ⇒ String
The agent through which the API request was made.
699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/aws-sdk-guardduty/types.rb', line 699 class AwsApiCallAction < Struct.new( :api, :caller_type, :domain_details, :error_code, :user_agent, :remote_ip_details, :service_name, :remote_account_details, :affected_resources) SENSITIVE = [] include Aws::Structure end |