Class: Aws::GuardDuty::Types::BedrockGuardrailDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::BedrockGuardrailDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the Bedrock guardrail that was involved in a finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_policy_filters ⇒ Array<Types::ContentPolicyFilter>
The list of content policy filters that matched during the guardrail evaluation.
-
#guardrail_action ⇒ String
Indicates whether the guardrail intervened or not.
-
#guardrail_arn ⇒ String
The ARN of the Bedrock guardrail.
-
#guardrail_source ⇒ String
Indicates whether the guardrail was applied on the input or output of the model invocation.
-
#guardrail_version ⇒ String
The version of the Bedrock guardrail.
-
#guardrails ⇒ Array<Types::BedrockGuardrail>
The list of Bedrock guardrails associated with the finding.
Instance Attribute Details
#content_policy_filters ⇒ Array<Types::ContentPolicyFilter>
The list of content policy filters that matched during the guardrail evaluation.
785 786 787 788 789 790 791 792 793 794 |
# File 'lib/aws-sdk-guardduty/types.rb', line 785 class BedrockGuardrailDetails < Struct.new( :guardrail_arn, :guardrail_version, :guardrails, :guardrail_action, :guardrail_source, :content_policy_filters) SENSITIVE = [] include Aws::Structure end |
#guardrail_action ⇒ String
Indicates whether the guardrail intervened or not.
785 786 787 788 789 790 791 792 793 794 |
# File 'lib/aws-sdk-guardduty/types.rb', line 785 class BedrockGuardrailDetails < Struct.new( :guardrail_arn, :guardrail_version, :guardrails, :guardrail_action, :guardrail_source, :content_policy_filters) SENSITIVE = [] include Aws::Structure end |
#guardrail_arn ⇒ String
The ARN of the Bedrock guardrail. This field is deprecated. Use the
guardrails list instead.
785 786 787 788 789 790 791 792 793 794 |
# File 'lib/aws-sdk-guardduty/types.rb', line 785 class BedrockGuardrailDetails < Struct.new( :guardrail_arn, :guardrail_version, :guardrails, :guardrail_action, :guardrail_source, :content_policy_filters) SENSITIVE = [] include Aws::Structure end |
#guardrail_source ⇒ String
Indicates whether the guardrail was applied on the input or output of the model invocation.
785 786 787 788 789 790 791 792 793 794 |
# File 'lib/aws-sdk-guardduty/types.rb', line 785 class BedrockGuardrailDetails < Struct.new( :guardrail_arn, :guardrail_version, :guardrails, :guardrail_action, :guardrail_source, :content_policy_filters) SENSITIVE = [] include Aws::Structure end |
#guardrail_version ⇒ String
The version of the Bedrock guardrail. This field is deprecated. Use
the guardrails list instead.
785 786 787 788 789 790 791 792 793 794 |
# File 'lib/aws-sdk-guardduty/types.rb', line 785 class BedrockGuardrailDetails < Struct.new( :guardrail_arn, :guardrail_version, :guardrails, :guardrail_action, :guardrail_source, :content_policy_filters) SENSITIVE = [] include Aws::Structure end |
#guardrails ⇒ Array<Types::BedrockGuardrail>
The list of Bedrock guardrails associated with the finding.
785 786 787 788 789 790 791 792 793 794 |
# File 'lib/aws-sdk-guardduty/types.rb', line 785 class BedrockGuardrailDetails < Struct.new( :guardrail_arn, :guardrail_version, :guardrails, :guardrail_action, :guardrail_source, :content_policy_filters) SENSITIVE = [] include Aws::Structure end |