Class: Aws::GuardDuty::Types::CloudDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains details about the cloud environment associated with an investigation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accountString

The Amazon Web Services account ID of the investigated resource.

Returns:

  • (String)


848
849
850
851
852
853
854
# File 'lib/aws-sdk-guardduty/types.rb', line 848

class CloudDetails < Struct.new(
  :provider,
  :region,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#providerString

The cloud provider. Currently, only ‘AWS` is supported.

Returns:

  • (String)


848
849
850
851
852
853
854
# File 'lib/aws-sdk-guardduty/types.rb', line 848

class CloudDetails < Struct.new(
  :provider,
  :region,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region in which the investigated resource resides.

Returns:

  • (String)


848
849
850
851
852
853
854
# File 'lib/aws-sdk-guardduty/types.rb', line 848

class CloudDetails < Struct.new(
  :provider,
  :region,
  :account)
  SENSITIVE = []
  include Aws::Structure
end