Class: Aws::GuardDuty::Types::ContainerFindingResource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about container resources involved in a GuardDuty finding. This structure provides details about containers that were identified as part of suspicious or malicious activity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#imageString

The container image information, including the image name and tag used to run the container that was involved in the finding.

Returns:

  • (String)


1055
1056
1057
1058
1059
1060
# File 'lib/aws-sdk-guardduty/types.rb', line 1055

class ContainerFindingResource < Struct.new(
  :image,
  :image_uid)
  SENSITIVE = []
  include Aws::Structure
end

#image_uidString

The unique ID associated with the container image.

Returns:

  • (String)


1055
1056
1057
1058
1059
1060
# File 'lib/aws-sdk-guardduty/types.rb', line 1055

class ContainerFindingResource < Struct.new(
  :image,
  :image_uid)
  SENSITIVE = []
  include Aws::Structure
end