Class: Aws::GuardDuty::Types::CoverageSortCriteria

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Information about the sorting criteria used in the coverage statistics.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attribute_nameString

Represents the field name used to sort the coverage details.

<note markdown=“1”> Replace the enum value CLUSTER_NAME with EKS_CLUSTER_NAME. CLUSTER_NAME has been deprecated.

</note>

Returns:

  • (String)


1371
1372
1373
1374
1375
1376
# File 'lib/aws-sdk-guardduty/types.rb', line 1371

class CoverageSortCriteria < Struct.new(
  :attribute_name,
  :order_by)
  SENSITIVE = []
  include Aws::Structure
end

#order_byString

The order in which the sorted findings are to be displayed.

Returns:

  • (String)


1371
1372
1373
1374
1375
1376
# File 'lib/aws-sdk-guardduty/types.rb', line 1371

class CoverageSortCriteria < Struct.new(
  :attribute_name,
  :order_by)
  SENSITIVE = []
  include Aws::Structure
end