Class: Aws::GuardDuty::Types::CreateInvestigationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The idempotency token for the create request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


3057
3058
3059
3060
3061
3062
3063
# File 'lib/aws-sdk-guardduty/types.rb', line 3057

class CreateInvestigationRequest < Struct.new(
  :detector_id,
  :trigger_prompt,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The unique ID of the GuardDuty detector for the account in which the investigation is created.

To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

Returns:

  • (String)


3057
3058
3059
3060
3061
3062
3063
# File 'lib/aws-sdk-guardduty/types.rb', line 3057

class CreateInvestigationRequest < Struct.new(
  :detector_id,
  :trigger_prompt,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_promptString

A natural-language description of what to investigate. For example:

  • ‘“Investigate finding 1ab2c3d4e5f6a7b8c9d0e1f2a3b4c5d6 in account 123456789012”`

  • ‘“Analyze findings in account with id 123456789012”`

  • ‘“Analyze findings in my organization”`

Returns:

  • (String)


3057
3058
3059
3060
3061
3062
3063
# File 'lib/aws-sdk-guardduty/types.rb', line 3057

class CreateInvestigationRequest < Struct.new(
  :detector_id,
  :trigger_prompt,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end