Class: Aws::GuardDuty::Types::CreateThreatEntitySetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activateBoolean

A boolean value that indicates whether GuardDuty should start using the uploaded threat entity set to generate findings.

Returns:

  • (Boolean)


3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
# File 'lib/aws-sdk-guardduty/types.rb', line 3262

class CreateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :activate,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

The idempotency token for the create request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
# File 'lib/aws-sdk-guardduty/types.rb', line 3262

class CreateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :activate,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The unique ID of the detector of the GuardDuty account for which you want to create a threat entity set.

To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

Returns:

  • (String)


3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
# File 'lib/aws-sdk-guardduty/types.rb', line 3262

class CreateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :activate,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.

Returns:

  • (String)


3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
# File 'lib/aws-sdk-guardduty/types.rb', line 3262

class CreateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :activate,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#formatString

The format of the file that contains the threat entity set.

Returns:

  • (String)


3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
# File 'lib/aws-sdk-guardduty/types.rb', line 3262

class CreateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :activate,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The URI of the file that contains the threat entity set. The format of the ‘Location` URL must be a valid Amazon S3 URL format. Invalid URL formats will result in an error, regardless of whether you activate the entity set or not. For more information about format of the location URLs, see [Format of location URL under Step 2: Adding trusted or threat intelligence data] in the *Amazon GuardDuty User Guide*.

[1]: docs.aws.amazon.com/guardduty/latest/ug/guardduty-lists-create-activate.html

Returns:

  • (String)


3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
# File 'lib/aws-sdk-guardduty/types.rb', line 3262

class CreateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :activate,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A user-friendly name to identify the threat entity set.

The name of your list can include lowercase letters, uppercase letters, numbers, dash (-), and underscore (_).

Returns:

  • (String)


3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
# File 'lib/aws-sdk-guardduty/types.rb', line 3262

class CreateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :activate,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to be added to a new threat entity set resource.

Returns:

  • (Hash<String,String>)


3262
3263
3264
3265
3266
3267
3268
3269
3270
3271
3272
3273
# File 'lib/aws-sdk-guardduty/types.rb', line 3262

class CreateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :activate,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end