Class: Aws::GuardDuty::Types::CreateTrustedEntitySetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::CreateTrustedEntitySetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#trusted_entity_set_id ⇒ String
The ID returned by GuardDuty after creation of the trusted entity set resource.
Instance Attribute Details
#trusted_entity_set_id ⇒ String
The ID returned by GuardDuty after creation of the trusted entity set resource.
3530 3531 3532 3533 3534 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3530 class CreateTrustedEntitySetResponse < Struct.new( :trusted_entity_set_id) SENSITIVE = [] include Aws::Structure end |