Class: Aws::GuardDuty::Types::DeleteDetectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::DeleteDetectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector that you want to delete.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector that you want to delete.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
4142 4143 4144 4145 4146 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4142 class DeleteDetectorRequest < Struct.new( :detector_id) SENSITIVE = [] include Aws::Structure end |