Class: Aws::GuardDuty::Types::DeleteFilterRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector that is associated with the filter.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

Returns:



2565
2566
2567
2568
2569
2570
# File 'lib/aws-sdk-guardduty/types.rb', line 2565

class DeleteFilterRequest < Struct.new(
  :detector_id,
  :filter_name)
  SENSITIVE = []
  include Aws::Structure
end

#filter_nameString

The name of the filter that you want to delete.

Returns:



2565
2566
2567
2568
2569
2570
# File 'lib/aws-sdk-guardduty/types.rb', line 2565

class DeleteFilterRequest < Struct.new(
  :detector_id,
  :filter_name)
  SENSITIVE = []
  include Aws::Structure
end