Class: Aws::GuardDuty::Types::DeletePublishingDestinationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::DeletePublishingDestinationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_id ⇒ String
The ID of the publishing destination to delete.
-
#detector_id ⇒ String
The unique ID of the detector associated with the publishing destination to delete.
Instance Attribute Details
#destination_id ⇒ String
The ID of the publishing destination to delete.
4028 4029 4030 4031 4032 4033 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4028 class DeletePublishingDestinationRequest < Struct.new( :detector_id, :destination_id) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The unique ID of the detector associated with the publishing destination to delete.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
4028 4029 4030 4031 4032 4033 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4028 class DeletePublishingDestinationRequest < Struct.new( :detector_id, :destination_id) SENSITIVE = [] include Aws::Structure end |