Class: Aws::GuardDuty::Types::DeleteThreatIntelSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::DeleteThreatIntelSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector that is associated with the threatIntelSet.
-
#threat_intel_set_id ⇒ String
The unique ID of the threatIntelSet that you want to delete.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector that is associated with the threatIntelSet.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
4087 4088 4089 4090 4091 4092 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4087 class DeleteThreatIntelSetRequest < Struct.new( :detector_id, :threat_intel_set_id) SENSITIVE = [] include Aws::Structure end |
#threat_intel_set_id ⇒ String
The unique ID of the threatIntelSet that you want to delete.
4087 4088 4089 4090 4091 4092 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4087 class DeleteThreatIntelSetRequest < Struct.new( :detector_id, :threat_intel_set_id) SENSITIVE = [] include Aws::Structure end |