Class: Aws::GuardDuty::Types::DeleteTrustedEntitySetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector associated with the trusted entity set resource.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


4117
4118
4119
4120
4121
4122
# File 'lib/aws-sdk-guardduty/types.rb', line 4117

class DeleteTrustedEntitySetRequest < Struct.new(
  :detector_id,
  :trusted_entity_set_id)
  SENSITIVE = []
  include Aws::Structure
end

#trusted_entity_set_idString

The unique ID that helps GuardDuty identify which trusted entity set needs to be deleted.

Returns:

  • (String)


4117
4118
4119
4120
4121
4122
# File 'lib/aws-sdk-guardduty/types.rb', line 4117

class DeleteTrustedEntitySetRequest < Struct.new(
  :detector_id,
  :trusted_entity_set_id)
  SENSITIVE = []
  include Aws::Structure
end