Class: Aws::GuardDuty::Types::DescribeMalwareScansRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector that the request is associated with.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


4169
4170
4171
4172
4173
4174
4175
4176
4177
# File 'lib/aws-sdk-guardduty/types.rb', line 4169

class DescribeMalwareScansRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#filter_criteriaTypes::FilterCriteria

Represents the criteria to be used in the filter for describing scan entries.



4169
4170
4171
4172
4173
4174
4175
4176
4177
# File 'lib/aws-sdk-guardduty/types.rb', line 4169

class DescribeMalwareScansRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50.

Returns:

  • (Integer)


4169
4170
4171
4172
4173
4174
4175
4176
4177
# File 'lib/aws-sdk-guardduty/types.rb', line 4169

class DescribeMalwareScansRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.

Returns:

  • (String)


4169
4170
4171
4172
4173
4174
4175
4176
4177
# File 'lib/aws-sdk-guardduty/types.rb', line 4169

class DescribeMalwareScansRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#sort_criteriaTypes::SortCriteria

Represents the criteria used for sorting scan entries. The attributeName is required and it must be scanStartTime.

Returns:



4169
4170
4171
4172
4173
4174
4175
4176
4177
# File 'lib/aws-sdk-guardduty/types.rb', line 4169

class DescribeMalwareScansRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end