Class: Aws::GuardDuty::Types::DescribeOrganizationConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::DescribeOrganizationConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The detector ID of the delegated administrator for which you need to retrieve the information.
-
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items that you want in the response.
-
#next_token ⇒ String
You can use this parameter when paginating results.
Instance Attribute Details
#detector_id ⇒ String
The detector ID of the delegated administrator for which you need to retrieve the information.
To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4136 class DescribeOrganizationConfigurationRequest < Struct.new( :detector_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items that you want in the response.
4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4136 class DescribeOrganizationConfigurationRequest < Struct.new( :detector_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill ‘nextToken` in the request with the value of `NextToken` from the previous response to continue listing data.
4136 4137 4138 4139 4140 4141 4142 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4136 class DescribeOrganizationConfigurationRequest < Struct.new( :detector_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |