Class: Aws::GuardDuty::Types::DescribePublishingDestinationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_idString

The ID of the publishing destination to retrieve.

Returns:

  • (String)


4320
4321
4322
4323
4324
4325
# File 'lib/aws-sdk-guardduty/types.rb', line 4320

class DescribePublishingDestinationRequest < Struct.new(
  :detector_id,
  :destination_id)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The unique ID of the detector associated with the publishing destination to retrieve.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


4320
4321
4322
4323
4324
4325
# File 'lib/aws-sdk-guardduty/types.rb', line 4320

class DescribePublishingDestinationRequest < Struct.new(
  :detector_id,
  :destination_id)
  SENSITIVE = []
  include Aws::Structure
end