Class: Aws::GuardDuty::Types::DescribePublishingDestinationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_idString

The ID of the publishing destination.

Returns:

  • (String)


4356
4357
4358
4359
4360
4361
4362
4363
4364
4365
# File 'lib/aws-sdk-guardduty/types.rb', line 4356

class DescribePublishingDestinationResponse < Struct.new(
  :destination_id,
  :destination_type,
  :status,
  :publishing_failure_start_timestamp,
  :destination_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#destination_propertiesTypes::DestinationProperties

A DestinationProperties object that includes the DestinationArn and KmsKeyArn of the publishing destination.



4356
4357
4358
4359
4360
4361
4362
4363
4364
4365
# File 'lib/aws-sdk-guardduty/types.rb', line 4356

class DescribePublishingDestinationResponse < Struct.new(
  :destination_id,
  :destination_type,
  :status,
  :publishing_failure_start_timestamp,
  :destination_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#destination_typeString

The type of publishing destination. Currently, only Amazon S3 buckets are supported.

Returns:

  • (String)


4356
4357
4358
4359
4360
4361
4362
4363
4364
4365
# File 'lib/aws-sdk-guardduty/types.rb', line 4356

class DescribePublishingDestinationResponse < Struct.new(
  :destination_id,
  :destination_type,
  :status,
  :publishing_failure_start_timestamp,
  :destination_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#publishing_failure_start_timestampInteger

The time, in epoch millisecond format, at which GuardDuty was first unable to publish findings to the destination.

Returns:

  • (Integer)


4356
4357
4358
4359
4360
4361
4362
4363
4364
4365
# File 'lib/aws-sdk-guardduty/types.rb', line 4356

class DescribePublishingDestinationResponse < Struct.new(
  :destination_id,
  :destination_type,
  :status,
  :publishing_failure_start_timestamp,
  :destination_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the publishing destination.

Returns:

  • (String)


4356
4357
4358
4359
4360
4361
4362
4363
4364
4365
# File 'lib/aws-sdk-guardduty/types.rb', line 4356

class DescribePublishingDestinationResponse < Struct.new(
  :destination_id,
  :destination_type,
  :status,
  :publishing_failure_start_timestamp,
  :destination_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags of the publishing destination resource.

Returns:

  • (Hash<String,String>)


4356
4357
4358
4359
4360
4361
4362
4363
4364
4365
# File 'lib/aws-sdk-guardduty/types.rb', line 4356

class DescribePublishingDestinationResponse < Struct.new(
  :destination_id,
  :destination_type,
  :status,
  :publishing_failure_start_timestamp,
  :destination_properties,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end