Class: Aws::GuardDuty::Types::DetectorAdditionalConfigurationResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::DetectorAdditionalConfigurationResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Information about the additional configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the additional configuration.
-
#status ⇒ String
Status of the additional configuration.
-
#updated_at ⇒ Time
The timestamp at which the additional configuration was last updated.
Instance Attribute Details
#name ⇒ String
Name of the additional configuration.
4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4307 class DetectorAdditionalConfigurationResult < Struct.new( :name, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Status of the additional configuration.
4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4307 class DetectorAdditionalConfigurationResult < Struct.new( :name, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp at which the additional configuration was last updated. This is in UTC format.
4307 4308 4309 4310 4311 4312 4313 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4307 class DetectorAdditionalConfigurationResult < Struct.new( :name, :status, :updated_at) SENSITIVE = [] include Aws::Structure end |