Class: Aws::GuardDuty::Types::DetectorFeatureConfigurationResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about a GuardDuty feature.

Specifying both EKS Runtime Monitoring (EKS_RUNTIME_MONITORING) and Runtime Monitoring (RUNTIME_MONITORING) will cause an error. You can add only one of these two features because Runtime Monitoring already includes the threat detection for Amazon EKS resources. For more information, see Runtime Monitoring.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_configurationArray<Types::DetectorAdditionalConfigurationResult>

Additional configuration for a resource.



4459
4460
4461
4462
4463
4464
4465
4466
# File 'lib/aws-sdk-guardduty/types.rb', line 4459

class DetectorFeatureConfigurationResult < Struct.new(
  :name,
  :status,
  :updated_at,
  :additional_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Indicates the name of the feature that can be enabled for the detector.

Returns:

  • (String)


4459
4460
4461
4462
4463
4464
4465
4466
# File 'lib/aws-sdk-guardduty/types.rb', line 4459

class DetectorFeatureConfigurationResult < Struct.new(
  :name,
  :status,
  :updated_at,
  :additional_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Indicates the status of the feature that is enabled for the detector.

Returns:

  • (String)


4459
4460
4461
4462
4463
4464
4465
4466
# File 'lib/aws-sdk-guardduty/types.rb', line 4459

class DetectorFeatureConfigurationResult < Struct.new(
  :name,
  :status,
  :updated_at,
  :additional_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp at which the feature object was updated.

Returns:

  • (Time)


4459
4460
4461
4462
4463
4464
4465
4466
# File 'lib/aws-sdk-guardduty/types.rb', line 4459

class DetectorFeatureConfigurationResult < Struct.new(
  :name,
  :status,
  :updated_at,
  :additional_configuration)
  SENSITIVE = []
  include Aws::Structure
end