Class: Aws::GuardDuty::Types::Ec2Image

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about the Amazon EC2 Image involved in a GuardDuty finding, including unique identifiers of the Amazon EC2 instances.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ec2_instance_uidsArray<String>

A list of unique identifiers for the compromised Amazon EC2 instances that were launched with the same Amazon Machine Image (AMI).

Returns:

  • (Array<String>)


4642
4643
4644
4645
4646
# File 'lib/aws-sdk-guardduty/types.rb', line 4642

class Ec2Image < Struct.new(
  :ec2_instance_uids)
  SENSITIVE = []
  include Aws::Structure
end