Class: Aws::GuardDuty::Types::EnableOrganizationAdminAccountRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::EnableOrganizationAdminAccountRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#admin_account_id ⇒ String
The Amazon Web Services account ID for the organization account to be enabled as a GuardDuty delegated administrator.
Instance Attribute Details
#admin_account_id ⇒ String
The Amazon Web Services account ID for the organization account to be enabled as a GuardDuty delegated administrator.
5087 5088 5089 5090 5091 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5087 class EnableOrganizationAdminAccountRequest < Struct.new( :admin_account_id) SENSITIVE = [] include Aws::Structure end |