Class: Aws::GuardDuty::Types::FargateDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about Amazon Web Services Fargate details associated with an Amazon ECS cluster.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#issuesArray<String>

Runtime coverage issues identified for the resource running on Amazon Web Services Fargate.



3962
3963
3964
3965
3966
3967
# File 'lib/aws-sdk-guardduty/types.rb', line 3962

class FargateDetails < Struct.new(
  :issues,
  :management_type)
  SENSITIVE = []
  include Aws::Structure
end

#management_typeString

Indicates how the GuardDuty security agent is managed for this resource.

  • AUTO_MANAGED indicates that GuardDuty deploys and manages updates for this resource.

  • DISABLED indicates that the deployment of the GuardDuty security agent is disabled for this resource.

<note markdown=“1”> The MANUAL status doesn’t apply to the Amazon Web Services Fargate (Amazon ECS only) woprkloads.

</note>


3962
3963
3964
3965
3966
3967
# File 'lib/aws-sdk-guardduty/types.rb', line 3962

class FargateDetails < Struct.new(
  :issues,
  :management_type)
  SENSITIVE = []
  include Aws::Structure
end