Class: Aws::GuardDuty::Types::Finding
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::Finding
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the finding that is generated when abnormal or suspicious activity is detected.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the account in which the finding was generated.
-
#arn ⇒ String
The ARN of the finding.
-
#associated_attack_sequence_arn ⇒ String
Amazon Resource Name (ARN) associated with the attack sequence finding.
-
#confidence ⇒ Float
The confidence score for the finding.
-
#created_at ⇒ String
The time and date when the finding was created.
-
#description ⇒ String
The description of the finding.
-
#id ⇒ String
The ID of the finding.
-
#partition ⇒ String
The partition associated with the finding.
-
#region ⇒ String
The Region where the finding was generated.
-
#resource ⇒ Types::Resource
Contains information about the Amazon Web Services resource associated with the activity that prompted GuardDuty to generate a finding.
-
#schema_version ⇒ String
The version of the schema used for the finding.
-
#service ⇒ Types::Service
Contains additional information about the generated finding.
-
#severity ⇒ Float
The severity of the finding.
-
#title ⇒ String
The title of the finding.
-
#type ⇒ String
The type of finding.
-
#updated_at ⇒ String
The time and date when the finding was last updated.
Instance Attribute Details
#account_id ⇒ String
The ID of the account in which the finding was generated.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
The ARN of the finding.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#associated_attack_sequence_arn ⇒ String
Amazon Resource Name (ARN) associated with the attack sequence finding.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#confidence ⇒ Float
The confidence score for the finding.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ String
The time and date when the finding was created.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the finding.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The ID of the finding.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#partition ⇒ String
The partition associated with the finding.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Region where the finding was generated. For findings generated from [Global Service Events], the Region value in the finding might differ from the Region where GuardDuty identifies the potential threat. For more information, see [How GuardDuty handles Amazon Web Services CloudTrail global events] in the *Amazon GuardDuty User Guide*.
[1]: docs.aws.amazon.com/awscloudtrail/latest/userguide/cloudtrail-concepts.html#cloudtrail-concepts-global-service-events [2]: docs.aws.amazon.com/guardduty/latest/ug/guardduty_data-sources.html#cloudtrail_global
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ Types::Resource
Contains information about the Amazon Web Services resource associated with the activity that prompted GuardDuty to generate a finding.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#schema_version ⇒ String
The version of the schema used for the finding.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#service ⇒ Types::Service
Contains additional information about the generated finding.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ Float
The severity of the finding.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the finding.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of finding.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ String
The time and date when the finding was last updated.
5269 5270 5271 5272 5273 5274 5275 5276 5277 5278 5279 5280 5281 5282 5283 5284 5285 5286 5287 5288 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5269 class Finding < Struct.new( :account_id, :arn, :confidence, :created_at, :description, :id, :partition, :region, :resource, :schema_version, :service, :severity, :title, :type, :updated_at, :associated_attack_sequence_arn) SENSITIVE = [] include Aws::Structure end |