Class: Aws::GuardDuty::Types::FindingStatistics
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::FindingStatistics
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about finding statistics.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#count_by_severity ⇒ Hash<String,Integer>
Represents a list of map of severity to count statistics for a set of findings.
-
#grouped_by_account ⇒ Array<Types::AccountStatistics>
Represents a list of map of accounts with a findings count associated with each account.
-
#grouped_by_date ⇒ Array<Types::DateStatistics>
Represents a list of map of dates with a count of total findings generated on each date per severity level.
-
#grouped_by_finding_type ⇒ Array<Types::FindingTypeStatistics>
Represents a list of map of finding types with a count of total findings generated for each type.
-
#grouped_by_resource ⇒ Array<Types::ResourceStatistics>
Represents a list of map of top resources with a count of total findings.
-
#grouped_by_severity ⇒ Array<Types::SeverityStatistics>
Represents a list of map of total findings for each severity level.
Instance Attribute Details
#count_by_severity ⇒ Hash<String,Integer>
Represents a list of map of severity to count statistics for a set of findings.
5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5522 class FindingStatistics < Struct.new( :count_by_severity, :grouped_by_account, :grouped_by_date, :grouped_by_finding_type, :grouped_by_resource, :grouped_by_severity) SENSITIVE = [] include Aws::Structure end |
#grouped_by_account ⇒ Array<Types::AccountStatistics>
Represents a list of map of accounts with a findings count associated with each account.
5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5522 class FindingStatistics < Struct.new( :count_by_severity, :grouped_by_account, :grouped_by_date, :grouped_by_finding_type, :grouped_by_resource, :grouped_by_severity) SENSITIVE = [] include Aws::Structure end |
#grouped_by_date ⇒ Array<Types::DateStatistics>
Represents a list of map of dates with a count of total findings generated on each date per severity level.
5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5522 class FindingStatistics < Struct.new( :count_by_severity, :grouped_by_account, :grouped_by_date, :grouped_by_finding_type, :grouped_by_resource, :grouped_by_severity) SENSITIVE = [] include Aws::Structure end |
#grouped_by_finding_type ⇒ Array<Types::FindingTypeStatistics>
Represents a list of map of finding types with a count of total findings generated for each type.
Based on the orderBy parameter, this request returns either the
most occurring finding types or the least occurring finding types.
If the orderBy parameter is ASC, this will represent the least
occurring finding types in your account; otherwise, this will
represent the most occurring finding types. The default value of
orderBy is DESC.
5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5522 class FindingStatistics < Struct.new( :count_by_severity, :grouped_by_account, :grouped_by_date, :grouped_by_finding_type, :grouped_by_resource, :grouped_by_severity) SENSITIVE = [] include Aws::Structure end |
#grouped_by_resource ⇒ Array<Types::ResourceStatistics>
Represents a list of map of top resources with a count of total findings.
5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5522 class FindingStatistics < Struct.new( :count_by_severity, :grouped_by_account, :grouped_by_date, :grouped_by_finding_type, :grouped_by_resource, :grouped_by_severity) SENSITIVE = [] include Aws::Structure end |
#grouped_by_severity ⇒ Array<Types::SeverityStatistics>
Represents a list of map of total findings for each severity level.
5522 5523 5524 5525 5526 5527 5528 5529 5530 5531 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5522 class FindingStatistics < Struct.new( :count_by_severity, :grouped_by_account, :grouped_by_date, :grouped_by_finding_type, :grouped_by_resource, :grouped_by_severity) SENSITIVE = [] include Aws::Structure end |