Class: Aws::GuardDuty::Types::GetCoverageStatisticsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetCoverageStatisticsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the GuardDuty detector.
-
#filter_criteria ⇒ Types::CoverageFilterCriteria
Represents the criteria used to filter the coverage statistics.
-
#statistics_type ⇒ Array<String>
Represents the statistics type used to aggregate the coverage details.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the GuardDuty detector.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
5660 5661 5662 5663 5664 5665 5666 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5660 class GetCoverageStatisticsRequest < Struct.new( :detector_id, :filter_criteria, :statistics_type) SENSITIVE = [] include Aws::Structure end |
#filter_criteria ⇒ Types::CoverageFilterCriteria
Represents the criteria used to filter the coverage statistics.
5660 5661 5662 5663 5664 5665 5666 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5660 class GetCoverageStatisticsRequest < Struct.new( :detector_id, :filter_criteria, :statistics_type) SENSITIVE = [] include Aws::Structure end |
#statistics_type ⇒ Array<String>
Represents the statistics type used to aggregate the coverage details.
5660 5661 5662 5663 5664 5665 5666 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5660 class GetCoverageStatisticsRequest < Struct.new( :detector_id, :filter_criteria, :statistics_type) SENSITIVE = [] include Aws::Structure end |