Class: Aws::GuardDuty::Types::GetDetectorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector that you want to get.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


6189
6190
6191
6192
6193
# File 'lib/aws-sdk-guardduty/types.rb', line 6189

class GetDetectorRequest < Struct.new(
  :detector_id)
  SENSITIVE = []
  include Aws::Structure
end