Class: Aws::GuardDuty::Types::GetFilterRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector that is associated with this filter.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

Returns:

  • (String)


4436
4437
4438
4439
4440
4441
# File 'lib/aws-sdk-guardduty/types.rb', line 4436

class GetFilterRequest < Struct.new(
  :detector_id,
  :filter_name)
  SENSITIVE = []
  include Aws::Structure
end

#filter_nameString

The name of the filter you want to get.

Returns:

  • (String)


4436
4437
4438
4439
4440
4441
# File 'lib/aws-sdk-guardduty/types.rb', line 4436

class GetFilterRequest < Struct.new(
  :detector_id,
  :filter_name)
  SENSITIVE = []
  include Aws::Structure
end