Class: Aws::GuardDuty::Types::GetFilterResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

Specifies the action that is to be applied to the findings that match the filter.

Returns:

  • (String)


6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
# File 'lib/aws-sdk-guardduty/types.rb', line 6315

class GetFilterResponse < Struct.new(
  :name,
  :description,
  :action,
  :rank,
  :finding_criteria,
  :tags,
  :created_at,
  :updated_at,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when the filter was created. This field is not available for filters that were created before the lifecycle metadata feature was enabled (legacy filters).

Returns:

  • (Time)


6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
# File 'lib/aws-sdk-guardduty/types.rb', line 6315

class GetFilterResponse < Struct.new(
  :name,
  :description,
  :action,
  :rank,
  :finding_criteria,
  :tags,
  :created_at,
  :updated_at,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the filter.

Returns:

  • (String)


6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
# File 'lib/aws-sdk-guardduty/types.rb', line 6315

class GetFilterResponse < Struct.new(
  :name,
  :description,
  :action,
  :rank,
  :finding_criteria,
  :tags,
  :created_at,
  :updated_at,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#finding_criteriaTypes::FindingCriteria

Represents the criteria to be used in the filter for querying findings.



6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
# File 'lib/aws-sdk-guardduty/types.rb', line 6315

class GetFilterResponse < Struct.new(
  :name,
  :description,
  :action,
  :rank,
  :finding_criteria,
  :tags,
  :created_at,
  :updated_at,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the filter.

Returns:

  • (String)


6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
# File 'lib/aws-sdk-guardduty/types.rb', line 6315

class GetFilterResponse < Struct.new(
  :name,
  :description,
  :action,
  :rank,
  :finding_criteria,
  :tags,
  :created_at,
  :updated_at,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#rankInteger

Specifies the position of the filter in the list of current filters. Also specifies the order in which this filter is applied to the findings.

Returns:

  • (Integer)


6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
# File 'lib/aws-sdk-guardduty/types.rb', line 6315

class GetFilterResponse < Struct.new(
  :name,
  :description,
  :action,
  :rank,
  :finding_criteria,
  :tags,
  :created_at,
  :updated_at,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags of the filter resource.

Returns:

  • (Hash<String,String>)


6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
# File 'lib/aws-sdk-guardduty/types.rb', line 6315

class GetFilterResponse < Struct.new(
  :name,
  :description,
  :action,
  :rank,
  :finding_criteria,
  :tags,
  :created_at,
  :updated_at,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp when the filter was last updated. For legacy filters, this field is present only after the filter has been updated at least once since the lifecycle metadata feature was enabled.

Returns:

  • (Time)


6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
# File 'lib/aws-sdk-guardduty/types.rb', line 6315

class GetFilterResponse < Struct.new(
  :name,
  :description,
  :action,
  :rank,
  :finding_criteria,
  :tags,
  :created_at,
  :updated_at,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#versionInteger

The version of the filter. Every time the filter is updated, the version increments by 1. This field is not available for legacy filters that were created before the lifecycle metadata feature was enabled.

Returns:

  • (Integer)


6315
6316
6317
6318
6319
6320
6321
6322
6323
6324
6325
6326
6327
# File 'lib/aws-sdk-guardduty/types.rb', line 6315

class GetFilterResponse < Struct.new(
  :name,
  :description,
  :action,
  :rank,
  :finding_criteria,
  :tags,
  :created_at,
  :updated_at,
  :version)
  SENSITIVE = []
  include Aws::Structure
end