Class: Aws::GuardDuty::Types::GetFindingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The ID of the detector that specifies the GuardDuty service whose findings you want to retrieve.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


5856
5857
5858
5859
5860
5861
5862
# File 'lib/aws-sdk-guardduty/types.rb', line 5856

class GetFindingsRequest < Struct.new(
  :detector_id,
  :finding_ids,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#finding_idsArray<String>

The IDs of the findings that you want to retrieve.

Returns:

  • (Array<String>)


5856
5857
5858
5859
5860
5861
5862
# File 'lib/aws-sdk-guardduty/types.rb', line 5856

class GetFindingsRequest < Struct.new(
  :detector_id,
  :finding_ids,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#sort_criteriaTypes::SortCriteria

Represents the criteria used for sorting findings.

Returns:



5856
5857
5858
5859
5860
5861
5862
# File 'lib/aws-sdk-guardduty/types.rb', line 5856

class GetFindingsRequest < Struct.new(
  :detector_id,
  :finding_ids,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end