Class: Aws::GuardDuty::Types::GetFindingsStatisticsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetFindingsStatisticsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The ID of the detector whose findings statistics you want to retrieve.
-
#finding_criteria ⇒ Types::FindingCriteria
Represents the criteria that is used for querying findings.
-
#finding_statistic_types ⇒ Array<String>
The types of finding statistics to retrieve.
-
#group_by ⇒ String
Displays the findings statistics grouped by one of the listed valid values.
-
#max_results ⇒ Integer
The maximum number of results to be returned in the response.
-
#order_by ⇒ String
Displays the sorted findings in the requested order.
Instance Attribute Details
#detector_id ⇒ String
The ID of the detector whose findings statistics you want to retrieve.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
5895 5896 5897 5898 5899 5900 5901 5902 5903 5904 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5895 class GetFindingsStatisticsRequest < Struct.new( :detector_id, :finding_statistic_types, :finding_criteria, :group_by, :order_by, :max_results) SENSITIVE = [] include Aws::Structure end |
#finding_criteria ⇒ Types::FindingCriteria
Represents the criteria that is used for querying findings.
5895 5896 5897 5898 5899 5900 5901 5902 5903 5904 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5895 class GetFindingsStatisticsRequest < Struct.new( :detector_id, :finding_statistic_types, :finding_criteria, :group_by, :order_by, :max_results) SENSITIVE = [] include Aws::Structure end |
#finding_statistic_types ⇒ Array<String>
The types of finding statistics to retrieve.
5895 5896 5897 5898 5899 5900 5901 5902 5903 5904 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5895 class GetFindingsStatisticsRequest < Struct.new( :detector_id, :finding_statistic_types, :finding_criteria, :group_by, :order_by, :max_results) SENSITIVE = [] include Aws::Structure end |
#group_by ⇒ String
Displays the findings statistics grouped by one of the listed valid values.
5895 5896 5897 5898 5899 5900 5901 5902 5903 5904 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5895 class GetFindingsStatisticsRequest < Struct.new( :detector_id, :finding_statistic_types, :finding_criteria, :group_by, :order_by, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to be returned in the response. The default value is 25.
You can use this parameter only with the groupBy parameter.
5895 5896 5897 5898 5899 5900 5901 5902 5903 5904 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5895 class GetFindingsStatisticsRequest < Struct.new( :detector_id, :finding_statistic_types, :finding_criteria, :group_by, :order_by, :max_results) SENSITIVE = [] include Aws::Structure end |
#order_by ⇒ String
Displays the sorted findings in the requested order. The default
value of orderBy is DESC.
You can use this parameter only with the groupBy parameter.
5895 5896 5897 5898 5899 5900 5901 5902 5903 5904 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5895 class GetFindingsStatisticsRequest < Struct.new( :detector_id, :finding_statistic_types, :finding_criteria, :group_by, :order_by, :max_results) SENSITIVE = [] include Aws::Structure end |