Class: Aws::GuardDuty::Types::GetIPSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector that is associated with the IPSet.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


6460
6461
6462
6463
6464
6465
# File 'lib/aws-sdk-guardduty/types.rb', line 6460

class GetIPSetRequest < Struct.new(
  :detector_id,
  :ip_set_id)
  SENSITIVE = []
  include Aws::Structure
end

#ip_set_idString

The unique ID of the IPSet to retrieve.

Returns:

  • (String)


6460
6461
6462
6463
6464
6465
# File 'lib/aws-sdk-guardduty/types.rb', line 6460

class GetIPSetRequest < Struct.new(
  :detector_id,
  :ip_set_id)
  SENSITIVE = []
  include Aws::Structure
end