Class: Aws::GuardDuty::Types::GetIPSetResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expected_bucket_ownerString

The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter. This field appears in the response only if it was provided during IPSet creation or update.

Returns:

  • (String)


6495
6496
6497
6498
6499
6500
6501
6502
6503
6504
# File 'lib/aws-sdk-guardduty/types.rb', line 6495

class GetIPSetResponse < Struct.new(
  :name,
  :format,
  :location,
  :status,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#formatString

The format of the file that contains the IPSet.

Returns:

  • (String)


6495
6496
6497
6498
6499
6500
6501
6502
6503
6504
# File 'lib/aws-sdk-guardduty/types.rb', line 6495

class GetIPSetResponse < Struct.new(
  :name,
  :format,
  :location,
  :status,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The URI of the file that contains the IPSet.

Returns:

  • (String)


6495
6496
6497
6498
6499
6500
6501
6502
6503
6504
# File 'lib/aws-sdk-guardduty/types.rb', line 6495

class GetIPSetResponse < Struct.new(
  :name,
  :format,
  :location,
  :status,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The user-friendly name for the IPSet.

Returns:

  • (String)


6495
6496
6497
6498
6499
6500
6501
6502
6503
6504
# File 'lib/aws-sdk-guardduty/types.rb', line 6495

class GetIPSetResponse < Struct.new(
  :name,
  :format,
  :location,
  :status,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of IPSet file that was uploaded.

Returns:

  • (String)


6495
6496
6497
6498
6499
6500
6501
6502
6503
6504
# File 'lib/aws-sdk-guardduty/types.rb', line 6495

class GetIPSetResponse < Struct.new(
  :name,
  :format,
  :location,
  :status,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags of the IPSet resource.

Returns:

  • (Hash<String,String>)


6495
6496
6497
6498
6499
6500
6501
6502
6503
6504
# File 'lib/aws-sdk-guardduty/types.rb', line 6495

class GetIPSetResponse < Struct.new(
  :name,
  :format,
  :location,
  :status,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end