Class: Aws::GuardDuty::Types::GetMalwareScanSettingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector that is associated with this scan.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


6305
6306
6307
6308
6309
# File 'lib/aws-sdk-guardduty/types.rb', line 6305

class GetMalwareScanSettingsRequest < Struct.new(
  :detector_id)
  SENSITIVE = []
  include Aws::Structure
end