Class: Aws::GuardDuty::Types::GetThreatEntitySetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetThreatEntitySetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector associated with the threat entity set resource.
-
#threat_entity_set_id ⇒ String
The unique ID that helps GuardDuty identify the threat entity set.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector associated with the threat entity set resource.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
7037 7038 7039 7040 7041 7042 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7037 class GetThreatEntitySetRequest < Struct.new( :detector_id, :threat_entity_set_id) SENSITIVE = [] include Aws::Structure end |
#threat_entity_set_id ⇒ String
The unique ID that helps GuardDuty identify the threat entity set.
7037 7038 7039 7040 7041 7042 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7037 class GetThreatEntitySetRequest < Struct.new( :detector_id, :threat_entity_set_id) SENSITIVE = [] include Aws::Structure end |