Class: Aws::GuardDuty::Types::GetThreatIntelSetResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expected_bucket_ownerString

The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter. This field appears in the response only if it was provided during ThreatIntelSet creation or update.

Returns:

  • (String)


6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
# File 'lib/aws-sdk-guardduty/types.rb', line 6659

class GetThreatIntelSetResponse < Struct.new(
  :name,
  :format,
  :location,
  :status,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#formatString

The format of the threatIntelSet.

Returns:

  • (String)


6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
# File 'lib/aws-sdk-guardduty/types.rb', line 6659

class GetThreatIntelSetResponse < Struct.new(
  :name,
  :format,
  :location,
  :status,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The URI of the file that contains the ThreatIntelSet.

Returns:

  • (String)


6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
# File 'lib/aws-sdk-guardduty/types.rb', line 6659

class GetThreatIntelSetResponse < Struct.new(
  :name,
  :format,
  :location,
  :status,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A user-friendly ThreatIntelSet name displayed in all findings that are generated by activity that involves IP addresses included in this ThreatIntelSet.

Returns:

  • (String)


6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
# File 'lib/aws-sdk-guardduty/types.rb', line 6659

class GetThreatIntelSetResponse < Struct.new(
  :name,
  :format,
  :location,
  :status,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of threatIntelSet file uploaded.

Returns:

  • (String)


6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
# File 'lib/aws-sdk-guardduty/types.rb', line 6659

class GetThreatIntelSetResponse < Struct.new(
  :name,
  :format,
  :location,
  :status,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags of the threat list resource.

Returns:

  • (Hash<String,String>)


6659
6660
6661
6662
6663
6664
6665
6666
6667
6668
# File 'lib/aws-sdk-guardduty/types.rb', line 6659

class GetThreatIntelSetResponse < Struct.new(
  :name,
  :format,
  :location,
  :status,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end