Class: Aws::GuardDuty::Types::GetUsageStatisticsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetUsageStatisticsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The ID of the detector that specifies the GuardDuty service whose usage statistics you want to retrieve.
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#unit ⇒ String
The currency unit you would like to view your usage statistics in.
-
#usage_criteria ⇒ Types::UsageCriteria
Represents the criteria used for querying usage.
-
#usage_statistic_type ⇒ String
The type of usage statistics to retrieve.
Instance Attribute Details
#detector_id ⇒ String
The ID of the detector that specifies the GuardDuty service whose usage statistics you want to retrieve.
To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6545 class GetUsageStatisticsRequest < Struct.new( :detector_id, :usage_statistic_type, :usage_criteria, :unit, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in the response.
6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6545 class GetUsageStatisticsRequest < Struct.new( :detector_id, :usage_statistic_type, :usage_criteria, :unit, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.
6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6545 class GetUsageStatisticsRequest < Struct.new( :detector_id, :usage_statistic_type, :usage_criteria, :unit, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
The currency unit you would like to view your usage statistics in. Current valid values are USD.
6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6545 class GetUsageStatisticsRequest < Struct.new( :detector_id, :usage_statistic_type, :usage_criteria, :unit, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#usage_criteria ⇒ Types::UsageCriteria
Represents the criteria used for querying usage.
6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6545 class GetUsageStatisticsRequest < Struct.new( :detector_id, :usage_statistic_type, :usage_criteria, :unit, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#usage_statistic_type ⇒ String
The type of usage statistics to retrieve.
6545 6546 6547 6548 6549 6550 6551 6552 6553 6554 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6545 class GetUsageStatisticsRequest < Struct.new( :detector_id, :usage_statistic_type, :usage_criteria, :unit, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |