Class: Aws::GuardDuty::Types::HighestSeverityThreatDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains details of the highest severity threat detected during scan and number of infected files.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#countInteger

Total number of infected files with the highest severity threat detected.

Returns:

  • (Integer)


6604
6605
6606
6607
6608
6609
6610
# File 'lib/aws-sdk-guardduty/types.rb', line 6604

class HighestSeverityThreatDetails < Struct.new(
  :severity,
  :threat_name,
  :count)
  SENSITIVE = []
  include Aws::Structure
end

#severityString

Severity level of the highest severity threat detected.

Returns:

  • (String)


6604
6605
6606
6607
6608
6609
6610
# File 'lib/aws-sdk-guardduty/types.rb', line 6604

class HighestSeverityThreatDetails < Struct.new(
  :severity,
  :threat_name,
  :count)
  SENSITIVE = []
  include Aws::Structure
end

#threat_nameString

Threat name of the highest severity threat detected as part of the malware scan.

Returns:

  • (String)


6604
6605
6606
6607
6608
6609
6610
# File 'lib/aws-sdk-guardduty/types.rb', line 6604

class HighestSeverityThreatDetails < Struct.new(
  :severity,
  :threat_name,
  :count)
  SENSITIVE = []
  include Aws::Structure
end