Class: Aws::GuardDuty::Types::Investigation
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::Investigation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains the details and results of a GuardDuty investigation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cloud ⇒ Types::CloudDetails
Details about the cloud environment in which the investigation was performed, including the provider, region, and account.
-
#confidence ⇒ String
The confidence level of the investigation's assessment.
-
#end_time ⇒ Time
The timestamp at which the investigation completed.
-
#error ⇒ String
Details about the error if the investigation status is
FAILED. -
#investigation_id ⇒ String
The unique identifier of the investigation.
-
#metadata ⇒ Types::InvestigationMetadata
Metadata about the product and version that produced the investigation.
-
#risk ⇒ String
A human-readable description of the assessed risk.
-
#risk_level ⇒ String
The assessed risk level of the investigated threat.
-
#start_time ⇒ Time
The timestamp at which the investigation started.
-
#status ⇒ String
The current status of the investigation.
-
#summary ⇒ String
A structured summary of the investigation findings, including affected resources, threat assessment, and recommended remediation steps.
-
#trigger_prompt ⇒ String
The natural-language prompt that initiated this investigation.
-
#triggered_by ⇒ String
The account that initiated the investigation.
Instance Attribute Details
#cloud ⇒ Types::CloudDetails
Details about the cloud environment in which the investigation was performed, including the provider, region, and account.
7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7115 class Investigation < Struct.new( :investigation_id, :status, :trigger_prompt, :triggered_by, :metadata, :cloud, :risk_level, :risk, :confidence, :summary, :start_time, :end_time, :error) SENSITIVE = [] include Aws::Structure end |
#confidence ⇒ String
The confidence level of the investigation's assessment. Possible
values are Unknown, Low, Medium, and High.
7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7115 class Investigation < Struct.new( :investigation_id, :status, :trigger_prompt, :triggered_by, :metadata, :cloud, :risk_level, :risk, :confidence, :summary, :start_time, :end_time, :error) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
The timestamp at which the investigation completed.
7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7115 class Investigation < Struct.new( :investigation_id, :status, :trigger_prompt, :triggered_by, :metadata, :cloud, :risk_level, :risk, :confidence, :summary, :start_time, :end_time, :error) SENSITIVE = [] include Aws::Structure end |
#error ⇒ String
Details about the error if the investigation status is FAILED.
7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7115 class Investigation < Struct.new( :investigation_id, :status, :trigger_prompt, :triggered_by, :metadata, :cloud, :risk_level, :risk, :confidence, :summary, :start_time, :end_time, :error) SENSITIVE = [] include Aws::Structure end |
#investigation_id ⇒ String
The unique identifier of the investigation.
7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7115 class Investigation < Struct.new( :investigation_id, :status, :trigger_prompt, :triggered_by, :metadata, :cloud, :risk_level, :risk, :confidence, :summary, :start_time, :end_time, :error) SENSITIVE = [] include Aws::Structure end |
#metadata ⇒ Types::InvestigationMetadata
Metadata about the product and version that produced the investigation.
7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7115 class Investigation < Struct.new( :investigation_id, :status, :trigger_prompt, :triggered_by, :metadata, :cloud, :risk_level, :risk, :confidence, :summary, :start_time, :end_time, :error) SENSITIVE = [] include Aws::Structure end |
#risk ⇒ String
A human-readable description of the assessed risk.
7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7115 class Investigation < Struct.new( :investigation_id, :status, :trigger_prompt, :triggered_by, :metadata, :cloud, :risk_level, :risk, :confidence, :summary, :start_time, :end_time, :error) SENSITIVE = [] include Aws::Structure end |
#risk_level ⇒ String
The assessed risk level of the investigated threat. Possible values
are Info, Low, Medium, High, and Critical.
7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7115 class Investigation < Struct.new( :investigation_id, :status, :trigger_prompt, :triggered_by, :metadata, :cloud, :risk_level, :risk, :confidence, :summary, :start_time, :end_time, :error) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The timestamp at which the investigation started.
7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7115 class Investigation < Struct.new( :investigation_id, :status, :trigger_prompt, :triggered_by, :metadata, :cloud, :risk_level, :risk, :confidence, :summary, :start_time, :end_time, :error) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the investigation. Possible values are
RUNNING, COMPLETED, and FAILED.
7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7115 class Investigation < Struct.new( :investigation_id, :status, :trigger_prompt, :triggered_by, :metadata, :cloud, :risk_level, :risk, :confidence, :summary, :start_time, :end_time, :error) SENSITIVE = [] include Aws::Structure end |
#summary ⇒ String
A structured summary of the investigation findings, including affected resources, threat assessment, and recommended remediation steps.
7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7115 class Investigation < Struct.new( :investigation_id, :status, :trigger_prompt, :triggered_by, :metadata, :cloud, :risk_level, :risk, :confidence, :summary, :start_time, :end_time, :error) SENSITIVE = [] include Aws::Structure end |
#trigger_prompt ⇒ String
The natural-language prompt that initiated this investigation.
7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7115 class Investigation < Struct.new( :investigation_id, :status, :trigger_prompt, :triggered_by, :metadata, :cloud, :risk_level, :risk, :confidence, :summary, :start_time, :end_time, :error) SENSITIVE = [] include Aws::Structure end |
#triggered_by ⇒ String
The account that initiated the investigation.
7115 7116 7117 7118 7119 7120 7121 7122 7123 7124 7125 7126 7127 7128 7129 7130 7131 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7115 class Investigation < Struct.new( :investigation_id, :status, :trigger_prompt, :triggered_by, :metadata, :cloud, :risk_level, :risk, :confidence, :summary, :start_time, :end_time, :error) SENSITIVE = [] include Aws::Structure end |