Class: Aws::GuardDuty::Types::InvestigationMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains metadata about the product and version that produced an investigation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#productTypes::Product

Information about the product that produced the investigation.

Returns:



7146
7147
7148
7149
7150
7151
# File 'lib/aws-sdk-guardduty/types.rb', line 7146

class InvestigationMetadata < Struct.new(
  :version,
  :product)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the investigation engine that produced the results.

Returns:

  • (String)


7146
7147
7148
7149
7150
7151
# File 'lib/aws-sdk-guardduty/types.rb', line 7146

class InvestigationMetadata < Struct.new(
  :version,
  :product)
  SENSITIVE = []
  include Aws::Structure
end