Class: Aws::GuardDuty::Types::KubernetesRoleBindingDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::KubernetesRoleBindingDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the role binding that grants the permission defined in a Kubernetes role.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kind ⇒ String
The kind of the role.
-
#name ⇒ String
The name of the
RoleBinding. -
#role_ref_kind ⇒ String
The type of the role being referenced.
-
#role_ref_name ⇒ String
The name of the role being referenced.
-
#uid ⇒ String
The unique identifier of the role binding.
Instance Attribute Details
#kind ⇒ String
The kind of the role. For role binding, this value will be RoleBinding.
6023 6024 6025 6026 6027 6028 6029 6030 6031 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6023 class KubernetesRoleBindingDetails < Struct.new( :kind, :name, :uid, :role_ref_name, :role_ref_kind) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the RoleBinding.
6023 6024 6025 6026 6027 6028 6029 6030 6031 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6023 class KubernetesRoleBindingDetails < Struct.new( :kind, :name, :uid, :role_ref_name, :role_ref_kind) SENSITIVE = [] include Aws::Structure end |
#role_ref_kind ⇒ String
The type of the role being referenced. This could be either Role or ClusterRole.
6023 6024 6025 6026 6027 6028 6029 6030 6031 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6023 class KubernetesRoleBindingDetails < Struct.new( :kind, :name, :uid, :role_ref_name, :role_ref_kind) SENSITIVE = [] include Aws::Structure end |
#role_ref_name ⇒ String
The name of the role being referenced. This must match the name of the Role or ClusterRole that you want to bind to.
6023 6024 6025 6026 6027 6028 6029 6030 6031 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6023 class KubernetesRoleBindingDetails < Struct.new( :kind, :name, :uid, :role_ref_name, :role_ref_kind) SENSITIVE = [] include Aws::Structure end |
#uid ⇒ String
The unique identifier of the role binding.
6023 6024 6025 6026 6027 6028 6029 6030 6031 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6023 class KubernetesRoleBindingDetails < Struct.new( :kind, :name, :uid, :role_ref_name, :role_ref_kind) SENSITIVE = [] include Aws::Structure end |