Class: Aws::GuardDuty::Types::KubernetesWorkload

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about Kubernetes workloads involved in a GuardDuty finding, including pods, deployments, and other Kubernetes resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_uidsArray<String>

A list of unique identifiers for the containers that are part of the Kubernetes workload.

Returns:

  • (Array<String>)


7263
7264
7265
7266
7267
7268
7269
# File 'lib/aws-sdk-guardduty/types.rb', line 7263

class KubernetesWorkload < Struct.new(
  :container_uids,
  :namespace,
  :kubernetes_resources_types)
  SENSITIVE = []
  include Aws::Structure
end

#kubernetes_resources_typesString

The types of Kubernetes resources involved in the workload.

Returns:

  • (String)


7263
7264
7265
7266
7267
7268
7269
# File 'lib/aws-sdk-guardduty/types.rb', line 7263

class KubernetesWorkload < Struct.new(
  :container_uids,
  :namespace,
  :kubernetes_resources_types)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The Kubernetes namespace in which the workload is running, providing logical isolation within the cluster.

Returns:

  • (String)


7263
7264
7265
7266
7267
7268
7269
# File 'lib/aws-sdk-guardduty/types.rb', line 7263

class KubernetesWorkload < Struct.new(
  :container_uids,
  :namespace,
  :kubernetes_resources_types)
  SENSITIVE = []
  include Aws::Structure
end