Class: Aws::GuardDuty::Types::ListCoverageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector whose coverage details you want to retrieve.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:



8386
8387
8388
8389
8390
8391
8392
8393
8394
# File 'lib/aws-sdk-guardduty/types.rb', line 8386

class ListCoverageRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#filter_criteriaTypes::CoverageFilterCriteria

Represents the criteria used to filter the coverage details.

Returns:



8386
8387
8388
8389
8390
8391
8392
8393
8394
# File 'lib/aws-sdk-guardduty/types.rb', line 8386

class ListCoverageRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in the response.

Returns:



8386
8387
8388
8389
8390
8391
8392
8393
8394
# File 'lib/aws-sdk-guardduty/types.rb', line 8386

class ListCoverageRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.

Returns:



8386
8387
8388
8389
8390
8391
8392
8393
8394
# File 'lib/aws-sdk-guardduty/types.rb', line 8386

class ListCoverageRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#sort_criteriaTypes::CoverageSortCriteria

Represents the criteria used to sort the coverage details.

Returns:



8386
8387
8388
8389
8390
8391
8392
8393
8394
# File 'lib/aws-sdk-guardduty/types.rb', line 8386

class ListCoverageRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end