Class: Aws::GuardDuty::Types::ListCoverageResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The pagination parameter to be used on the next list operation to retrieve more items.



8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-guardduty/types.rb', line 8407

class ListCoverageResponse < Struct.new(
  :resources,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resourcesArray<Types::CoverageResource>

A list of resources and their attributes providing cluster details.



8407
8408
8409
8410
8411
8412
# File 'lib/aws-sdk-guardduty/types.rb', line 8407

class ListCoverageResponse < Struct.new(
  :resources,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end