Class: Aws::GuardDuty::Types::ListCustomDetectionRuleAssociationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A pagination token to retrieve the next page of results. If this field is empty, there are no additional results.

Returns:

  • (String)


8455
8456
8457
8458
8459
8460
# File 'lib/aws-sdk-guardduty/types.rb', line 8455

class ListCustomDetectionRuleAssociationsResponse < Struct.new(
  :rule_associations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#rule_associationsArray<Types::AssociationSummary>

A list of custom detection rule association summaries.

Returns:



8455
8456
8457
8458
8459
8460
# File 'lib/aws-sdk-guardduty/types.rb', line 8455

class ListCustomDetectionRuleAssociationsResponse < Struct.new(
  :rule_associations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end