Class: Aws::GuardDuty::Types::ListCustomDetectionRuleOrgConfigurationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return in a single page. Minimum value of 1, maximum value of 100.

Returns:

  • (Integer)


8478
8479
8480
8481
8482
8483
8484
# File 'lib/aws-sdk-guardduty/types.rb', line 8478

class ListCustomDetectionRuleOrgConfigurationsRequest < Struct.new(
  :max_results,
  :next_token,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A pagination token from a previous response. Use this token to retrieve the next page of results.

Returns:

  • (String)


8478
8479
8480
8481
8482
8483
8484
# File 'lib/aws-sdk-guardduty/types.rb', line 8478

class ListCustomDetectionRuleOrgConfigurationsRequest < Struct.new(
  :max_results,
  :next_token,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The configuration status to filter by.

Returns:

  • (String)


8478
8479
8480
8481
8482
8483
8484
# File 'lib/aws-sdk-guardduty/types.rb', line 8478

class ListCustomDetectionRuleOrgConfigurationsRequest < Struct.new(
  :max_results,
  :next_token,
  :status)
  SENSITIVE = []
  include Aws::Structure
end