Class: Aws::GuardDuty::Types::ListCustomDetectionRuleOrgConfigurationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configurationsArray<Types::DetectionRuleOrgConfigurationSummary>

A list of organization configurations for custom detection rules.



8497
8498
8499
8500
8501
8502
# File 'lib/aws-sdk-guardduty/types.rb', line 8497

class ListCustomDetectionRuleOrgConfigurationsResponse < Struct.new(
  :configurations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A pagination token to retrieve the next page of results. If this field is empty, there are no additional results.

Returns:

  • (String)


8497
8498
8499
8500
8501
8502
# File 'lib/aws-sdk-guardduty/types.rb', line 8497

class ListCustomDetectionRuleOrgConfigurationsResponse < Struct.new(
  :configurations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end