Class: Aws::GuardDuty::Types::ListCustomDetectionRulesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A pagination token to retrieve the next page of results. If this field is empty, there are no additional results.

Returns:

  • (String)


8540
8541
8542
8543
8544
8545
# File 'lib/aws-sdk-guardduty/types.rb', line 8540

class ListCustomDetectionRulesResponse < Struct.new(
  :rules,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#rulesArray<Types::RuleSummary>

A list of custom detection rule summaries.

Returns:



8540
8541
8542
8543
8544
8545
# File 'lib/aws-sdk-guardduty/types.rb', line 8540

class ListCustomDetectionRulesResponse < Struct.new(
  :rules,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end