Class: Aws::GuardDuty::Types::ListIPSetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector that is associated with IPSet.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

Returns:

  • (String)


6649
6650
6651
6652
6653
6654
6655
# File 'lib/aws-sdk-guardduty/types.rb', line 6649

class ListIPSetsRequest < Struct.new(
  :detector_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

You can use this parameter to indicate the maximum number of items you want in the response. The default value is 50. The maximum value is 50.

Returns:

  • (Integer)


6649
6650
6651
6652
6653
6654
6655
# File 'lib/aws-sdk-guardduty/types.rb', line 6649

class ListIPSetsRequest < Struct.new(
  :detector_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.

Returns:

  • (String)


6649
6650
6651
6652
6653
6654
6655
# File 'lib/aws-sdk-guardduty/types.rb', line 6649

class ListIPSetsRequest < Struct.new(
  :detector_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end