Class: Aws::GuardDuty::Types::ListInvestigationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the GuardDuty detector whose investigations you want to list.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


8897
8898
8899
8900
8901
8902
8903
8904
# File 'lib/aws-sdk-guardduty/types.rb', line 8897

class ListInvestigationsRequest < Struct.new(
  :detector_id,
  :sort_criteria,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

You can use this parameter to indicate the maximum number of items you want in the response. The default value is 50.

Returns:

  • (Integer)


8897
8898
8899
8900
8901
8902
8903
8904
# File 'lib/aws-sdk-guardduty/types.rb', line 8897

class ListInvestigationsRequest < Struct.new(
  :detector_id,
  :sort_criteria,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.

Returns:

  • (String)


8897
8898
8899
8900
8901
8902
8903
8904
# File 'lib/aws-sdk-guardduty/types.rb', line 8897

class ListInvestigationsRequest < Struct.new(
  :detector_id,
  :sort_criteria,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#sort_criteriaTypes::InvestigationSortCriteria

Represents the criteria used for sorting investigations.



8897
8898
8899
8900
8901
8902
8903
8904
# File 'lib/aws-sdk-guardduty/types.rb', line 8897

class ListInvestigationsRequest < Struct.new(
  :detector_id,
  :sort_criteria,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end