Class: Aws::GuardDuty::Types::ListInvestigationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#investigationsArray<Types::InvestigationSummary>

A list of investigation summaries associated with the specified detector.

Returns:



8918
8919
8920
8921
8922
8923
# File 'lib/aws-sdk-guardduty/types.rb', line 8918

class ListInvestigationsResponse < Struct.new(
  :investigations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination parameter to be used on the next list operation to retrieve more items.

Returns:

  • (String)


8918
8919
8920
8921
8922
8923
# File 'lib/aws-sdk-guardduty/types.rb', line 8918

class ListInvestigationsResponse < Struct.new(
  :investigations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end