Class: Aws::GuardDuty::Types::ListInvitationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ListInvitationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items that you want in the response.
-
#next_token ⇒ String
You can use this parameter when paginating results.
Instance Attribute Details
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50.
8941 8942 8943 8944 8945 8946 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8941 class ListInvitationsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
8941 8942 8943 8944 8945 8946 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8941 class ListInvitationsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |