Class: Aws::GuardDuty::Types::ListMalwareProtectionPlansRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data. The default page size is 100 plans.

Returns:

  • (String)


8976
8977
8978
8979
8980
# File 'lib/aws-sdk-guardduty/types.rb', line 8976

class ListMalwareProtectionPlansRequest < Struct.new(
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end