Class: Aws::GuardDuty::Types::ListMalwareScansFilterCriteria

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Represents the criteria used to filter the malware scan entries.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#list_malware_scans_filter_criterionArray<Types::ListMalwareScansFilterCriterion>

Represents a condition that when matched will be added to the response of the operation.



6763
6764
6765
6766
6767
# File 'lib/aws-sdk-guardduty/types.rb', line 6763

class ListMalwareScansFilterCriteria < Struct.new(
  :list_malware_scans_filter_criterion)
  SENSITIVE = []
  include Aws::Structure
end