Class: Aws::GuardDuty::Types::ListMalwareScansRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filter_criteriaTypes::ListMalwareScansFilterCriteria

Represents the criteria used to filter the malware scan entries.



9067
9068
9069
9070
9071
9072
9073
9074
# File 'lib/aws-sdk-guardduty/types.rb', line 9067

class ListMalwareScansRequest < Struct.new(
  :max_results,
  :next_token,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50.

Returns:

  • (Integer)


9067
9068
9069
9070
9071
9072
9073
9074
# File 'lib/aws-sdk-guardduty/types.rb', line 9067

class ListMalwareScansRequest < Struct.new(
  :max_results,
  :next_token,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing results.

Returns:

  • (String)


9067
9068
9069
9070
9071
9072
9073
9074
# File 'lib/aws-sdk-guardduty/types.rb', line 9067

class ListMalwareScansRequest < Struct.new(
  :max_results,
  :next_token,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#sort_criteriaTypes::SortCriteria

Represents the criteria used for sorting malware scan entries.

Returns:



9067
9068
9069
9070
9071
9072
9073
9074
# File 'lib/aws-sdk-guardduty/types.rb', line 9067

class ListMalwareScansRequest < Struct.new(
  :max_results,
  :next_token,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end