Class: Aws::GuardDuty::Types::ListMalwareScansResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The pagination parameter to be used on the next list operation to retrieve more scans.

Returns:

  • (String)


9088
9089
9090
9091
9092
9093
# File 'lib/aws-sdk-guardduty/types.rb', line 9088

class ListMalwareScansResponse < Struct.new(
  :scans,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#scansArray<Types::MalwareScan>

The list of malware scans associated with the provided input parameters.

Returns:



9088
9089
9090
9091
9092
9093
# File 'lib/aws-sdk-guardduty/types.rb', line 9088

class ListMalwareScansResponse < Struct.new(
  :scans,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end