Class: Aws::GuardDuty::Types::ListMembersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ListMembersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector that is associated with the member.
-
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items you want in the response.
-
#next_token ⇒ String
You can use this parameter when paginating results.
-
#only_associated ⇒ String
Specifies whether to only return associated members or to return all members (including members who haven't been invited yet or have been disassociated).
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector that is associated with the member.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
9134 9135 9136 9137 9138 9139 9140 9141 |
# File 'lib/aws-sdk-guardduty/types.rb', line 9134 class ListMembersRequest < Struct.new( :detector_id, :max_results, :next_token, :only_associated) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items you want in the response. The default value is 50. The maximum value is 50.
9134 9135 9136 9137 9138 9139 9140 9141 |
# File 'lib/aws-sdk-guardduty/types.rb', line 9134 class ListMembersRequest < Struct.new( :detector_id, :max_results, :next_token, :only_associated) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
9134 9135 9136 9137 9138 9139 9140 9141 |
# File 'lib/aws-sdk-guardduty/types.rb', line 9134 class ListMembersRequest < Struct.new( :detector_id, :max_results, :next_token, :only_associated) SENSITIVE = [] include Aws::Structure end |
#only_associated ⇒ String
Specifies whether to only return associated members or to return all
members (including members who haven't been invited yet or have
been disassociated). Member accounts must have been previously
associated with the GuardDuty administrator account using Create Members .
9134 9135 9136 9137 9138 9139 9140 9141 |
# File 'lib/aws-sdk-guardduty/types.rb', line 9134 class ListMembersRequest < Struct.new( :detector_id, :max_results, :next_token, :only_associated) SENSITIVE = [] include Aws::Structure end |