Class: Aws::GuardDuty::Types::ListOrganizationAdminAccountsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return in the response.

Returns:



6930
6931
6932
6933
6934
6935
# File 'lib/aws-sdk-guardduty/types.rb', line 6930

class ListOrganizationAdminAccountsRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.

Returns:



6930
6931
6932
6933
6934
6935
# File 'lib/aws-sdk-guardduty/types.rb', line 6930

class ListOrganizationAdminAccountsRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end