Class: Aws::GuardDuty::Types::ListPublishingDestinationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The detector ID for which you want to retrieve the publishing destination.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


9231
9232
9233
9234
9235
9236
9237
# File 'lib/aws-sdk-guardduty/types.rb', line 9231

class ListPublishingDestinationsRequest < Struct.new(
  :detector_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in the response.

Returns:

  • (Integer)


9231
9232
9233
9234
9235
9236
9237
# File 'lib/aws-sdk-guardduty/types.rb', line 9231

class ListPublishingDestinationsRequest < Struct.new(
  :detector_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.

Returns:

  • (String)


9231
9232
9233
9234
9235
9236
9237
# File 'lib/aws-sdk-guardduty/types.rb', line 9231

class ListPublishingDestinationsRequest < Struct.new(
  :detector_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end