Class: Aws::GuardDuty::Types::ListThreatIntelSetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector that is associated with the threatIntelSet.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:



9366
9367
9368
9369
9370
9371
9372
# File 'lib/aws-sdk-guardduty/types.rb', line 9366

class ListThreatIntelSetsRequest < Struct.new(
  :detector_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50.

Returns:



9366
9367
9368
9369
9370
9371
9372
# File 'lib/aws-sdk-guardduty/types.rb', line 9366

class ListThreatIntelSetsRequest < Struct.new(
  :detector_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

You can use this parameter to paginate results in the response. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.

Returns:



9366
9367
9368
9369
9370
9371
9372
# File 'lib/aws-sdk-guardduty/types.rb', line 9366

class ListThreatIntelSetsRequest < Struct.new(
  :detector_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end