Class: Aws::GuardDuty::Types::ListTrustedEntitySetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ListTrustedEntitySetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the GuardDuty detector that is associated with this threat entity set.
-
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items you want in the response.
-
#next_token ⇒ String
You can use this parameter when paginating results.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the GuardDuty detector that is associated with this threat entity set.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
9419 9420 9421 9422 9423 9424 9425 |
# File 'lib/aws-sdk-guardduty/types.rb', line 9419 class ListTrustedEntitySetsRequest < Struct.new( :detector_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items you want in the response. The default value is 50.
9419 9420 9421 9422 9423 9424 9425 |
# File 'lib/aws-sdk-guardduty/types.rb', line 9419 class ListTrustedEntitySetsRequest < Struct.new( :detector_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
9419 9420 9421 9422 9423 9424 9425 |
# File 'lib/aws-sdk-guardduty/types.rb', line 9419 class ListTrustedEntitySetsRequest < Struct.new( :detector_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |