Class: Aws::GuardDuty::Types::MalwareScanDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Information about the malware scan that generated a GuardDuty finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#scan_categoryString

The category of the malware scan.

Returns:

  • (String)


8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
# File 'lib/aws-sdk-guardduty/types.rb', line 8663

class MalwareScanDetails < Struct.new(
  :threats,
  :scan_id,
  :scan_type,
  :scan_category,
  :scan_configuration,
  :unique_threat_count)
  SENSITIVE = []
  include Aws::Structure
end

#scan_configurationTypes::MalwareProtectionFindingsScanConfiguration

The configuration settings used for the malware scan.



8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
# File 'lib/aws-sdk-guardduty/types.rb', line 8663

class MalwareScanDetails < Struct.new(
  :threats,
  :scan_id,
  :scan_type,
  :scan_category,
  :scan_configuration,
  :unique_threat_count)
  SENSITIVE = []
  include Aws::Structure
end

#scan_idString

The unique identifier for the malware scan.

Returns:

  • (String)


8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
# File 'lib/aws-sdk-guardduty/types.rb', line 8663

class MalwareScanDetails < Struct.new(
  :threats,
  :scan_id,
  :scan_type,
  :scan_category,
  :scan_configuration,
  :unique_threat_count)
  SENSITIVE = []
  include Aws::Structure
end

#scan_typeString

The type of malware scan performed.

Returns:

  • (String)


8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
# File 'lib/aws-sdk-guardduty/types.rb', line 8663

class MalwareScanDetails < Struct.new(
  :threats,
  :scan_id,
  :scan_type,
  :scan_category,
  :scan_configuration,
  :unique_threat_count)
  SENSITIVE = []
  include Aws::Structure
end

#threatsArray<Types::Threat>

Information about the detected threats associated with the generated GuardDuty finding.

Returns:



8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
# File 'lib/aws-sdk-guardduty/types.rb', line 8663

class MalwareScanDetails < Struct.new(
  :threats,
  :scan_id,
  :scan_type,
  :scan_category,
  :scan_configuration,
  :unique_threat_count)
  SENSITIVE = []
  include Aws::Structure
end

#unique_threat_countInteger

The number of unique malware threats detected during the scan.

Returns:

  • (Integer)


8663
8664
8665
8666
8667
8668
8669
8670
8671
8672
# File 'lib/aws-sdk-guardduty/types.rb', line 8663

class MalwareScanDetails < Struct.new(
  :threats,
  :scan_id,
  :scan_type,
  :scan_category,
  :scan_configuration,
  :unique_threat_count)
  SENSITIVE = []
  include Aws::Structure
end