Class: Aws::GuardDuty::Types::MemberFeaturesConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::MemberFeaturesConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the features for the member account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_configuration ⇒ Array<Types::MemberAdditionalConfiguration>
Additional configuration of the feature for the member account.
-
#name ⇒ String
The name of the feature.
-
#status ⇒ String
The status of the feature.
Instance Attribute Details
#additional_configuration ⇒ Array<Types::MemberAdditionalConfiguration>
Additional configuration of the feature for the member account.
9268 9269 9270 9271 9272 9273 9274 |
# File 'lib/aws-sdk-guardduty/types.rb', line 9268 class MemberFeaturesConfiguration < Struct.new( :name, :status, :additional_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the feature.
9268 9269 9270 9271 9272 9273 9274 |
# File 'lib/aws-sdk-guardduty/types.rb', line 9268 class MemberFeaturesConfiguration < Struct.new( :name, :status, :additional_configuration) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the feature.
9268 9269 9270 9271 9272 9273 9274 |
# File 'lib/aws-sdk-guardduty/types.rb', line 9268 class MemberFeaturesConfiguration < Struct.new( :name, :status, :additional_configuration) SENSITIVE = [] include Aws::Structure end |