Class: Aws::GuardDuty::Types::Product

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about the product that produced an investigation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#featureString

The specific feature within the product that produced the investigation.

Returns:

  • (String)


10932
10933
10934
10935
10936
10937
# File 'lib/aws-sdk-guardduty/types.rb', line 10932

class Product < Struct.new(
  :name,
  :feature)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the product.

Returns:

  • (String)


10932
10933
10934
10935
10936
10937
# File 'lib/aws-sdk-guardduty/types.rb', line 10932

class Product < Struct.new(
  :name,
  :feature)
  SENSITIVE = []
  include Aws::Structure
end