Class: Aws::GuardDuty::Types::RecoveryPoint

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about the recovery point configuration for scanning backup data from Amazon Web Services Backup.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_vault_nameString

The name of the Amazon Web Services Backup vault that contains the name of the recovery point to be scanned.

Returns:

  • (String)


10076
10077
10078
10079
10080
10081
# File 'lib/aws-sdk-guardduty/types.rb', line 10076

class RecoveryPoint < Struct.new(
  :backup_vault_name,
  :continuous_scan_details)
  SENSITIVE = []
  include Aws::Structure
end

#continuous_scan_detailsTypes::ContinuousScanDetails

Contains information about the time range within the continuous backup in Amazon Web Services Backup to scan.



10076
10077
10078
10079
10080
10081
# File 'lib/aws-sdk-guardduty/types.rb', line 10076

class RecoveryPoint < Struct.new(
  :backup_vault_name,
  :continuous_scan_details)
  SENSITIVE = []
  include Aws::Structure
end