Class: Aws::GuardDuty::Types::RemoteAccountDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains details about the remote Amazon Web Services account that made the API call.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idString

The Amazon Web Services account ID of the remote API caller.

Returns:

  • (String)


10589
10590
10591
10592
10593
10594
# File 'lib/aws-sdk-guardduty/types.rb', line 10589

class RemoteAccountDetails < Struct.new(
  :account_id,
  :affiliated)
  SENSITIVE = []
  include Aws::Structure
end

#affiliatedBoolean

Details on whether the Amazon Web Services account of the remote API caller is related to your GuardDuty environment. If this value is True the API caller is affiliated to your account in some way. If it is False the API caller is from outside your environment.

Returns:

  • (Boolean)


10589
10590
10591
10592
10593
10594
# File 'lib/aws-sdk-guardduty/types.rb', line 10589

class RemoteAccountDetails < Struct.new(
  :account_id,
  :affiliated)
  SENSITIVE = []
  include Aws::Structure
end