Class: Aws::GuardDuty::Types::S3Bucket

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about the Amazon S3 bucket policies and encryption.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_public_accessTypes::PublicAccessConfiguration

Contains information about the public access policies that apply to the Amazon S3 bucket at the account level.



11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
11151
11152
11153
11154
# File 'lib/aws-sdk-guardduty/types.rb', line 11141

class S3Bucket < Struct.new(
  :owner_id,
  :created_at,
  :encryption_type,
  :encryption_key_arn,
  :effective_permission,
  :public_read_access,
  :public_write_access,
  :account_public_access,
  :bucket_public_access,
  :s3_object_uids)
  SENSITIVE = []
  include Aws::Structure
end

#bucket_public_accessTypes::PublicAccessConfiguration

Contains information about public access policies that apply to the Amazon S3 bucket.



11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
11151
11152
11153
11154
# File 'lib/aws-sdk-guardduty/types.rb', line 11141

class S3Bucket < Struct.new(
  :owner_id,
  :created_at,
  :encryption_type,
  :encryption_key_arn,
  :effective_permission,
  :public_read_access,
  :public_write_access,
  :account_public_access,
  :bucket_public_access,
  :s3_object_uids)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp at which the Amazon S3 bucket was created.

Returns:

  • (Time)


11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
11151
11152
11153
11154
# File 'lib/aws-sdk-guardduty/types.rb', line 11141

class S3Bucket < Struct.new(
  :owner_id,
  :created_at,
  :encryption_type,
  :encryption_key_arn,
  :effective_permission,
  :public_read_access,
  :public_write_access,
  :account_public_access,
  :bucket_public_access,
  :s3_object_uids)
  SENSITIVE = []
  include Aws::Structure
end

#effective_permissionString

Describes the effective permissions on this S3 bucket, after factoring all the attached policies.

Returns:

  • (String)


11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
11151
11152
11153
11154
# File 'lib/aws-sdk-guardduty/types.rb', line 11141

class S3Bucket < Struct.new(
  :owner_id,
  :created_at,
  :encryption_type,
  :encryption_key_arn,
  :effective_permission,
  :public_read_access,
  :public_write_access,
  :account_public_access,
  :bucket_public_access,
  :s3_object_uids)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_key_arnString

The Amazon Resource Name (ARN) of the encryption key that is used to encrypt the Amazon S3 bucket and its objects.

Returns:

  • (String)


11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
11151
11152
11153
11154
# File 'lib/aws-sdk-guardduty/types.rb', line 11141

class S3Bucket < Struct.new(
  :owner_id,
  :created_at,
  :encryption_type,
  :encryption_key_arn,
  :effective_permission,
  :public_read_access,
  :public_write_access,
  :account_public_access,
  :bucket_public_access,
  :s3_object_uids)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_typeString

The type of encryption used for the Amazon S3 buckets and its objects. For more information, see [Protecting data with server-side encryption] in the *Amazon S3 User Guide*.

[1]: docs.aws.amazon.com/AmazonS3/latest/userguide/serv-side-encryption.html

Returns:

  • (String)


11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
11151
11152
11153
11154
# File 'lib/aws-sdk-guardduty/types.rb', line 11141

class S3Bucket < Struct.new(
  :owner_id,
  :created_at,
  :encryption_type,
  :encryption_key_arn,
  :effective_permission,
  :public_read_access,
  :public_write_access,
  :account_public_access,
  :bucket_public_access,
  :s3_object_uids)
  SENSITIVE = []
  include Aws::Structure
end

#owner_idString

The owner ID of the associated S3Amazon S3bucket.

Returns:

  • (String)


11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
11151
11152
11153
11154
# File 'lib/aws-sdk-guardduty/types.rb', line 11141

class S3Bucket < Struct.new(
  :owner_id,
  :created_at,
  :encryption_type,
  :encryption_key_arn,
  :effective_permission,
  :public_read_access,
  :public_write_access,
  :account_public_access,
  :bucket_public_access,
  :s3_object_uids)
  SENSITIVE = []
  include Aws::Structure
end

#public_read_accessString

Indicates whether or not the public read access is allowed for an Amazon S3 bucket.

Returns:

  • (String)


11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
11151
11152
11153
11154
# File 'lib/aws-sdk-guardduty/types.rb', line 11141

class S3Bucket < Struct.new(
  :owner_id,
  :created_at,
  :encryption_type,
  :encryption_key_arn,
  :effective_permission,
  :public_read_access,
  :public_write_access,
  :account_public_access,
  :bucket_public_access,
  :s3_object_uids)
  SENSITIVE = []
  include Aws::Structure
end

#public_write_accessString

Indicates whether or not the public write access is allowed for an Amazon S3 bucket.

Returns:

  • (String)


11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
11151
11152
11153
11154
# File 'lib/aws-sdk-guardduty/types.rb', line 11141

class S3Bucket < Struct.new(
  :owner_id,
  :created_at,
  :encryption_type,
  :encryption_key_arn,
  :effective_permission,
  :public_read_access,
  :public_write_access,
  :account_public_access,
  :bucket_public_access,
  :s3_object_uids)
  SENSITIVE = []
  include Aws::Structure
end

#s3_object_uidsArray<String>

Represents a list of Amazon S3 object identifiers.

Returns:

  • (Array<String>)


11141
11142
11143
11144
11145
11146
11147
11148
11149
11150
11151
11152
11153
11154
# File 'lib/aws-sdk-guardduty/types.rb', line 11141

class S3Bucket < Struct.new(
  :owner_id,
  :created_at,
  :encryption_type,
  :encryption_key_arn,
  :effective_permission,
  :public_read_access,
  :public_write_access,
  :account_public_access,
  :bucket_public_access,
  :s3_object_uids)
  SENSITIVE = []
  include Aws::Structure
end