Class: Aws::GuardDuty::Types::S3ObjectForSendObjectMalwareScan

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

The S3 object path to initiate a scan, including bucket name, object key, and optional version ID.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucketString

The name of the S3 bucket containing the object to scan. The bucket must have GuardDuty Malware Protection enabled.



12263
12264
12265
12266
12267
12268
12269
# File 'lib/aws-sdk-guardduty/types.rb', line 12263

class S3ObjectForSendObjectMalwareScan < Struct.new(
  :bucket,
  :key,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#keyString

The key (name) of the S3 object to scan for malware. This must be the full key path of the object within the bucket.



12263
12264
12265
12266
12267
12268
12269
# File 'lib/aws-sdk-guardduty/types.rb', line 12263

class S3ObjectForSendObjectMalwareScan < Struct.new(
  :bucket,
  :key,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The version ID of the S3 object to scan. If not specified, the latest version of the object is scanned.



12263
12264
12265
12266
12267
12268
12269
# File 'lib/aws-sdk-guardduty/types.rb', line 12263

class S3ObjectForSendObjectMalwareScan < Struct.new(
  :bucket,
  :key,
  :version_id)
  SENSITIVE = []
  include Aws::Structure
end