Class: Aws::GuardDuty::Types::Scan
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::Scan
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about malware scans associated with GuardDuty Malware Protection for EC2.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID for the account that belongs to the scan.
-
#admin_detector_id ⇒ String
The unique detector ID of the administrator account that the request is associated with.
-
#attached_volumes ⇒ Array<Types::VolumeDetail>
List of volumes that were attached to the original instance to be scanned.
-
#detector_id ⇒ String
The unique ID of the detector that is associated with the request.
-
#failure_reason ⇒ String
Represents the reason for ‘FAILED` scan status.
-
#file_count ⇒ Integer
Represents the number of files that were scanned.
-
#resource_details ⇒ Types::ResourceDetails
Represents the resources that were scanned in the scan entry.
-
#scan_end_time ⇒ Time
The timestamp of when the scan was finished.
-
#scan_id ⇒ String
The unique scan ID associated with a scan entry.
-
#scan_result_details ⇒ Types::ScanResultDetails
Represents the result of the scan.
-
#scan_start_time ⇒ Time
The timestamp of when the scan was triggered.
-
#scan_status ⇒ String
An enum value representing possible scan statuses.
-
#scan_type ⇒ String
Specifies the scan type that invoked the malware scan.
-
#total_bytes ⇒ Integer
Represents total bytes that were scanned.
-
#trigger_details ⇒ Types::TriggerDetails
Specifies the reason why the scan was initiated.
Instance Attribute Details
#account_id ⇒ String
The ID for the account that belongs to the scan.
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#admin_detector_id ⇒ String
The unique detector ID of the administrator account that the request is associated with. If the account is an administrator, the ‘AdminDetectorId` will be the same as the one used for `DetectorId`.
To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#attached_volumes ⇒ Array<Types::VolumeDetail>
List of volumes that were attached to the original instance to be scanned.
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The unique ID of the detector that is associated with the request.
To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
Represents the reason for ‘FAILED` scan status.
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#file_count ⇒ Integer
Represents the number of files that were scanned.
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#resource_details ⇒ Types::ResourceDetails
Represents the resources that were scanned in the scan entry.
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#scan_end_time ⇒ Time
The timestamp of when the scan was finished.
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#scan_id ⇒ String
The unique scan ID associated with a scan entry.
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#scan_result_details ⇒ Types::ScanResultDetails
Represents the result of the scan.
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#scan_start_time ⇒ Time
The timestamp of when the scan was triggered.
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#scan_status ⇒ String
An enum value representing possible scan statuses.
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#scan_type ⇒ String
Specifies the scan type that invoked the malware scan.
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#total_bytes ⇒ Integer
Represents total bytes that were scanned.
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |
#trigger_details ⇒ Types::TriggerDetails
Specifies the reason why the scan was initiated.
11409 11410 11411 11412 11413 11414 11415 11416 11417 11418 11419 11420 11421 11422 11423 11424 11425 11426 11427 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11409 class Scan < Struct.new( :detector_id, :admin_detector_id, :scan_id, :scan_status, :failure_reason, :scan_start_time, :scan_end_time, :trigger_details, :resource_details, :scan_result_details, :account_id, :total_bytes, :file_count, :attached_volumes, :scan_type) SENSITIVE = [] include Aws::Structure end |