Class: Aws::GuardDuty::Types::ScanConfigurationContinuousScanDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about the time range within the continuous backup in Amazon Web Services Backup that was scanned for a point-in-time recovery resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTime

The timestamp representing the end of the time range that was scanned.

Returns:

  • (Time)


11138
11139
11140
11141
11142
11143
# File 'lib/aws-sdk-guardduty/types.rb', line 11138

class ScanConfigurationContinuousScanDetails < Struct.new(
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The timestamp representing the start of the time range that was scanned.

Returns:

  • (Time)


11138
11139
11140
11141
11142
11143
# File 'lib/aws-sdk-guardduty/types.rb', line 11138

class ScanConfigurationContinuousScanDetails < Struct.new(
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end