Class: Aws::GuardDuty::Types::ScanResultThreat

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about a specific threat that was detected during the malware scan.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#countInteger

The number of instances of this threat that were detected.

Returns:

  • (Integer)


11260
11261
11262
11263
11264
11265
11266
11267
11268
# File 'lib/aws-sdk-guardduty/types.rb', line 11260

class ScanResultThreat < Struct.new(
  :name,
  :source,
  :count,
  :hash,
  :item_details)
  SENSITIVE = []
  include Aws::Structure
end

#hashString

The hash value associated with the detected threat.

Returns:

  • (String)


11260
11261
11262
11263
11264
11265
11266
11267
11268
# File 'lib/aws-sdk-guardduty/types.rb', line 11260

class ScanResultThreat < Struct.new(
  :name,
  :source,
  :count,
  :hash,
  :item_details)
  SENSITIVE = []
  include Aws::Structure
end

#item_detailsArray<Types::ItemDetails>

Additional information about where this threat was detected.

Returns:



11260
11261
11262
11263
11264
11265
11266
11267
11268
# File 'lib/aws-sdk-guardduty/types.rb', line 11260

class ScanResultThreat < Struct.new(
  :name,
  :source,
  :count,
  :hash,
  :item_details)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the detected threat.

Returns:

  • (String)


11260
11261
11262
11263
11264
11265
11266
11267
11268
# File 'lib/aws-sdk-guardduty/types.rb', line 11260

class ScanResultThreat < Struct.new(
  :name,
  :source,
  :count,
  :hash,
  :item_details)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The source that detected this threat.

Returns:

  • (String)


11260
11261
11262
11263
11264
11265
11266
11267
11268
# File 'lib/aws-sdk-guardduty/types.rb', line 11260

class ScanResultThreat < Struct.new(
  :name,
  :source,
  :count,
  :hash,
  :item_details)
  SENSITIVE = []
  include Aws::Structure
end