Class: Aws::GuardDuty::Types::ScannedResource
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ScannedResource
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about a resource that was scanned as part of the malware scan operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#resource_details ⇒ Types::ScannedResourceDetails
Information about the scanned resource.
-
#scan_status_reason ⇒ String
The reason for the scan status of this particular resource, if applicable.
-
#scanned_resource_arn ⇒ String
Amazon Resource Name (ARN) of the scanned resource.
-
#scanned_resource_status ⇒ String
The status of the scanned resource.
-
#scanned_resource_type ⇒ String
The resource type of the scanned resource.
Instance Attribute Details
#resource_details ⇒ Types::ScannedResourceDetails
Information about the scanned resource.
11350 11351 11352 11353 11354 11355 11356 11357 11358 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11350 class ScannedResource < Struct.new( :scanned_resource_arn, :scanned_resource_type, :scanned_resource_status, :scan_status_reason, :resource_details) SENSITIVE = [] include Aws::Structure end |
#scan_status_reason ⇒ String
The reason for the scan status of this particular resource, if applicable.
11350 11351 11352 11353 11354 11355 11356 11357 11358 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11350 class ScannedResource < Struct.new( :scanned_resource_arn, :scanned_resource_type, :scanned_resource_status, :scan_status_reason, :resource_details) SENSITIVE = [] include Aws::Structure end |
#scanned_resource_arn ⇒ String
Amazon Resource Name (ARN) of the scanned resource.
11350 11351 11352 11353 11354 11355 11356 11357 11358 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11350 class ScannedResource < Struct.new( :scanned_resource_arn, :scanned_resource_type, :scanned_resource_status, :scan_status_reason, :resource_details) SENSITIVE = [] include Aws::Structure end |
#scanned_resource_status ⇒ String
The status of the scanned resource.
11350 11351 11352 11353 11354 11355 11356 11357 11358 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11350 class ScannedResource < Struct.new( :scanned_resource_arn, :scanned_resource_type, :scanned_resource_status, :scan_status_reason, :resource_details) SENSITIVE = [] include Aws::Structure end |
#scanned_resource_type ⇒ String
The resource type of the scanned resource.
11350 11351 11352 11353 11354 11355 11356 11357 11358 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11350 class ScannedResource < Struct.new( :scanned_resource_arn, :scanned_resource_type, :scanned_resource_status, :scan_status_reason, :resource_details) SENSITIVE = [] include Aws::Structure end |