Class: Aws::GuardDuty::Types::Signal

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about the signals involved in the attack sequence.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actor_idsArray<String>

Information about the IDs of the threat actors involved in the signal.

Returns:

  • (Array<String>)


12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#countInteger

The number of times this signal was observed.

Returns:

  • (Integer)


12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The timestamp when the first finding or activity related to this signal was observed.

Returns:

  • (Time)


12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the signal.

Returns:

  • (String)


12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_idsArray<String>

Information about the endpoint IDs associated with this signal.

Returns:

  • (Array<String>)


12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#first_seen_atTime

The timestamp when the first finding or activity related to this signal was observed.

Returns:

  • (Time)


12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#last_seen_atTime

The timestamp when the last finding or activity related to this signal was observed.

Returns:

  • (Time)


12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the signal. For example, when signal type is FINDING, the signal name is the name of the finding.

Returns:

  • (String)


12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#resource_uidsArray<String>

Information about the unique identifiers of the resources involved in the signal.

Returns:

  • (Array<String>)


12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#severityFloat

The severity associated with the signal. For more information about severity, see Findings severity levels in the Amazon GuardDuty User Guide.

Returns:

  • (Float)


12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#signal_indicatorsArray<Types::Indicator>

Contains information about the indicators associated with the signals.

Returns:



12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the signal used to identify an attack sequence.

Signals can be GuardDuty findings or activities observed in data sources that GuardDuty monitors. For more information, see Foundational data sources in the Amazon GuardDuty User Guide.

A signal type can be one of the valid values listed in this API. Here are the related descriptions:

  • FINDING - Individually generated GuardDuty finding.

  • CLOUD_TRAIL - Activity observed from CloudTrail logs

  • S3_DATA_EVENTS - Activity observed from CloudTrail data events for S3. Activities associated with this type will show up only when you have enabled GuardDuty S3 Protection feature in your account. For more information about S3 Protection and steps to enable it, see S3 Protection in the Amazon GuardDuty User Guide.

Returns:

  • (String)


12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#uidString

The unique identifier of the signal.

Returns:

  • (String)


12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp when this signal was last observed.

Returns:

  • (Time)


12327
12328
12329
12330
12331
12332
12333
12334
12335
12336
12337
12338
12339
12340
12341
12342
12343
12344
# File 'lib/aws-sdk-guardduty/types.rb', line 12327

class Signal < Struct.new(
  :uid,
  :type,
  :description,
  :name,
  :created_at,
  :updated_at,
  :first_seen_at,
  :last_seen_at,
  :severity,
  :count,
  :resource_uids,
  :actor_ids,
  :endpoint_ids,
  :signal_indicators)
  SENSITIVE = []
  include Aws::Structure
end