Class: Aws::GuardDuty::Types::SortCriteria
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::SortCriteria
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the criteria used for sorting findings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_name ⇒ String
Represents the finding attribute, such as
accountId, that sorts the findings. -
#order_by ⇒ String
The order by which the sorted findings are to be displayed.
Instance Attribute Details
#attribute_name ⇒ String
Represents the finding attribute, such as accountId, that sorts the findings.
10648 10649 10650 10651 10652 10653 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10648 class SortCriteria < Struct.new( :attribute_name, :order_by) SENSITIVE = [] include Aws::Structure end |
#order_by ⇒ String
The order by which the sorted findings are to be displayed.
10648 10649 10650 10651 10652 10653 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10648 class SortCriteria < Struct.new( :attribute_name, :order_by) SENSITIVE = [] include Aws::Structure end |