Class: Aws::GuardDuty::Types::StartMalwareScanConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about the configuration to be used for the malware scan.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#incremental_scan_detailsTypes::IncrementalScanDetails

Contains information about the incremental scan configuration. When specified, the scan will only process changes since the baseline resource.



12387
12388
12389
12390
12391
12392
12393
# File 'lib/aws-sdk-guardduty/types.rb', line 12387

class StartMalwareScanConfiguration < Struct.new(
  :role,
  :incremental_scan_details,
  :recovery_point)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_pointTypes::RecoveryPoint

Contains information about the recovery point configuration for the requested scan.



12387
12388
12389
12390
12391
12392
12393
# File 'lib/aws-sdk-guardduty/types.rb', line 12387

class StartMalwareScanConfiguration < Struct.new(
  :role,
  :incremental_scan_details,
  :recovery_point)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

Amazon Resource Name (ARN) of the IAM role that is used for scanning the resource.

Returns:

  • (String)


12387
12388
12389
12390
12391
12392
12393
# File 'lib/aws-sdk-guardduty/types.rb', line 12387

class StartMalwareScanConfiguration < Struct.new(
  :role,
  :incremental_scan_details,
  :recovery_point)
  SENSITIVE = []
  include Aws::Structure
end