Class: Aws::GuardDuty::Types::StartMalwareScanRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::StartMalwareScanRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The idempotency token for the create request.
-
#resource_arn ⇒ String
Amazon Resource Name (ARN) of the resource for which you invoked the API.
-
#scan_configuration ⇒ Types::StartMalwareScanConfiguration
Contains information about the configuration to be used for the malware scan.
Instance Attribute Details
#client_token ⇒ String
The idempotency token for the create request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
11854 11855 11856 11857 11858 11859 11860 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11854 class StartMalwareScanRequest < Struct.new( :resource_arn, :client_token, :scan_configuration) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
Amazon Resource Name (ARN) of the resource for which you invoked the API.
11854 11855 11856 11857 11858 11859 11860 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11854 class StartMalwareScanRequest < Struct.new( :resource_arn, :client_token, :scan_configuration) SENSITIVE = [] include Aws::Structure end |
#scan_configuration ⇒ Types::StartMalwareScanConfiguration
Contains information about the configuration to be used for the malware scan.
11854 11855 11856 11857 11858 11859 11860 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11854 class StartMalwareScanRequest < Struct.new( :resource_arn, :client_token, :scan_configuration) SENSITIVE = [] include Aws::Structure end |