Class: Aws::GuardDuty::Types::UpdateFilterRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#actionString

Specifies the action that is to be applied to the findings that match the filter.



11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
# File 'lib/aws-sdk-guardduty/types.rb', line 11180

class UpdateFilterRequest < Struct.new(
  :detector_id,
  :filter_name,
  :description,
  :action,
  :rank,
  :finding_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the filter. Valid characters include alphanumeric characters, and special characters such as hyphen, period, colon, underscore, parentheses (‘{ }`, `[ ]`, and `( )`), forward slash, horizontal tab, vertical tab, newline, form feed, return, and whitespace.



11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
# File 'lib/aws-sdk-guardduty/types.rb', line 11180

class UpdateFilterRequest < Struct.new(
  :detector_id,
  :filter_name,
  :description,
  :action,
  :rank,
  :finding_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The unique ID of the detector that specifies the GuardDuty service where you want to update a filter.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html



11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
# File 'lib/aws-sdk-guardduty/types.rb', line 11180

class UpdateFilterRequest < Struct.new(
  :detector_id,
  :filter_name,
  :description,
  :action,
  :rank,
  :finding_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#filter_nameString

The name of the filter.



11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
# File 'lib/aws-sdk-guardduty/types.rb', line 11180

class UpdateFilterRequest < Struct.new(
  :detector_id,
  :filter_name,
  :description,
  :action,
  :rank,
  :finding_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#finding_criteriaTypes::FindingCriteria

Represents the criteria to be used in the filter for querying findings.



11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
# File 'lib/aws-sdk-guardduty/types.rb', line 11180

class UpdateFilterRequest < Struct.new(
  :detector_id,
  :filter_name,
  :description,
  :action,
  :rank,
  :finding_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#rankInteger

Specifies the position of the filter in the list of current filters. Also specifies the order in which this filter is applied to the findings.



11180
11181
11182
11183
11184
11185
11186
11187
11188
11189
# File 'lib/aws-sdk-guardduty/types.rb', line 11180

class UpdateFilterRequest < Struct.new(
  :detector_id,
  :filter_name,
  :description,
  :action,
  :rank,
  :finding_criteria)
  SENSITIVE = []
  include Aws::Structure
end