Class: Aws::GuardDuty::Types::UpdateIPSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::UpdateIPSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activate ⇒ Boolean
The updated Boolean value that specifies whether the IPSet is active or not.
-
#detector_id ⇒ String
The detectorID that specifies the GuardDuty service whose IPSet you want to update.
-
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
-
#ip_set_id ⇒ String
The unique ID that specifies the IPSet that you want to update.
-
#location ⇒ String
The updated URI of the file that contains the IPSet.
-
#name ⇒ String
The unique ID that specifies the IPSet that you want to update.
Instance Attribute Details
#activate ⇒ Boolean
The updated Boolean value that specifies whether the IPSet is active or not.
14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14335 class UpdateIPSetRequest < Struct.new( :detector_id, :ip_set_id, :name, :location, :activate, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The detectorID that specifies the GuardDuty service whose IPSet you want to update.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14335 class UpdateIPSetRequest < Struct.new( :detector_id, :ip_set_id, :name, :location, :activate, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14335 class UpdateIPSetRequest < Struct.new( :detector_id, :ip_set_id, :name, :location, :activate, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#ip_set_id ⇒ String
The unique ID that specifies the IPSet that you want to update.
14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14335 class UpdateIPSetRequest < Struct.new( :detector_id, :ip_set_id, :name, :location, :activate, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The updated URI of the file that contains the IPSet.
14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14335 class UpdateIPSetRequest < Struct.new( :detector_id, :ip_set_id, :name, :location, :activate, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique ID that specifies the IPSet that you want to update.
14335 14336 14337 14338 14339 14340 14341 14342 14343 14344 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14335 class UpdateIPSetRequest < Struct.new( :detector_id, :ip_set_id, :name, :location, :activate, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |