Class: Aws::GuardDuty::Types::UpdateMalwareProtectionPlanRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::UpdateMalwareProtectionPlanRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Types::MalwareProtectionPlanActions
Information about whether the tags will be added to the S3 object after scanning.
-
#malware_protection_plan_id ⇒ String
A unique identifier associated with the Malware Protection plan.
-
#protected_resource ⇒ Types::UpdateProtectedResource
Information about the protected resource that is associated with the created Malware Protection plan.
-
#role ⇒ String
Amazon Resource Name (ARN) of the IAM role with permissions to scan and add tags to the associated protected resource.
Instance Attribute Details
#actions ⇒ Types::MalwareProtectionPlanActions
Information about whether the tags will be added to the S3 object after scanning.
14394 14395 14396 14397 14398 14399 14400 14401 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14394 class UpdateMalwareProtectionPlanRequest < Struct.new( :malware_protection_plan_id, :role, :actions, :protected_resource) SENSITIVE = [] include Aws::Structure end |
#malware_protection_plan_id ⇒ String
A unique identifier associated with the Malware Protection plan.
14394 14395 14396 14397 14398 14399 14400 14401 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14394 class UpdateMalwareProtectionPlanRequest < Struct.new( :malware_protection_plan_id, :role, :actions, :protected_resource) SENSITIVE = [] include Aws::Structure end |
#protected_resource ⇒ Types::UpdateProtectedResource
Information about the protected resource that is associated with the
created Malware Protection plan. Presently, S3Bucket is the only
supported protected resource.
14394 14395 14396 14397 14398 14399 14400 14401 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14394 class UpdateMalwareProtectionPlanRequest < Struct.new( :malware_protection_plan_id, :role, :actions, :protected_resource) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
Amazon Resource Name (ARN) of the IAM role with permissions to scan and add tags to the associated protected resource.
14394 14395 14396 14397 14398 14399 14400 14401 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14394 class UpdateMalwareProtectionPlanRequest < Struct.new( :malware_protection_plan_id, :role, :actions, :protected_resource) SENSITIVE = [] include Aws::Structure end |