Class: Aws::GuardDuty::Types::UpdateMalwareScanSettingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::UpdateMalwareScanSettingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector that specifies the GuardDuty service where you want to update scan settings.
-
#ebs_snapshot_preservation ⇒ String
An enum value representing possible snapshot preservation settings.
-
#scan_resource_criteria ⇒ Types::ScanResourceCriteria
Represents the criteria to be used in the filter for selecting resources to scan.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector that specifies the GuardDuty service where you want to update scan settings.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
14426 14427 14428 14429 14430 14431 14432 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14426 class UpdateMalwareScanSettingsRequest < Struct.new( :detector_id, :scan_resource_criteria, :ebs_snapshot_preservation) SENSITIVE = [] include Aws::Structure end |
#ebs_snapshot_preservation ⇒ String
An enum value representing possible snapshot preservation settings.
14426 14427 14428 14429 14430 14431 14432 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14426 class UpdateMalwareScanSettingsRequest < Struct.new( :detector_id, :scan_resource_criteria, :ebs_snapshot_preservation) SENSITIVE = [] include Aws::Structure end |
#scan_resource_criteria ⇒ Types::ScanResourceCriteria
Represents the criteria to be used in the filter for selecting resources to scan.
14426 14427 14428 14429 14430 14431 14432 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14426 class UpdateMalwareScanSettingsRequest < Struct.new( :detector_id, :scan_resource_criteria, :ebs_snapshot_preservation) SENSITIVE = [] include Aws::Structure end |