Class: Aws::GuardDuty::Types::UpdatePublishingDestinationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#destination_idString

The ID of the publishing destination to update.

Returns:

  • (String)


14603
14604
14605
14606
14607
14608
14609
# File 'lib/aws-sdk-guardduty/types.rb', line 14603

class UpdatePublishingDestinationRequest < Struct.new(
  :detector_id,
  :destination_id,
  :destination_properties)
  SENSITIVE = []
  include Aws::Structure
end

#destination_propertiesTypes::DestinationProperties

A DestinationProperties object that includes the DestinationArn and KmsKeyArn of the publishing destination.



14603
14604
14605
14606
14607
14608
14609
# File 'lib/aws-sdk-guardduty/types.rb', line 14603

class UpdatePublishingDestinationRequest < Struct.new(
  :detector_id,
  :destination_id,
  :destination_properties)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The ID of the detector associated with the publishing destinations to update.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


14603
14604
14605
14606
14607
14608
14609
# File 'lib/aws-sdk-guardduty/types.rb', line 14603

class UpdatePublishingDestinationRequest < Struct.new(
  :detector_id,
  :destination_id,
  :destination_properties)
  SENSITIVE = []
  include Aws::Structure
end