Class: Aws::GuardDuty::Types::UpdateThreatEntitySetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activateBoolean

A boolean value that indicates whether GuardDuty is to start using this updated threat entity set. After you update an entity set, you will need to activate it again. It might take up to 15 minutes for the updated entity set to be effective.



15535
15536
15537
15538
15539
15540
15541
15542
15543
15544
# File 'lib/aws-sdk-guardduty/types.rb', line 15535

class UpdateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :threat_entity_set_id,
  :name,
  :location,
  :expected_bucket_owner,
  :activate)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The unique ID of the GuardDuty detector associated with the threat entity set that you want to update.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.



15535
15536
15537
15538
15539
15540
15541
15542
15543
15544
# File 'lib/aws-sdk-guardduty/types.rb', line 15535

class UpdateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :threat_entity_set_id,
  :name,
  :location,
  :expected_bucket_owner,
  :activate)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.



15535
15536
15537
15538
15539
15540
15541
15542
15543
15544
# File 'lib/aws-sdk-guardduty/types.rb', line 15535

class UpdateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :threat_entity_set_id,
  :name,
  :location,
  :expected_bucket_owner,
  :activate)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The URI of the file that contains the trusted entity set.



15535
15536
15537
15538
15539
15540
15541
15542
15543
15544
# File 'lib/aws-sdk-guardduty/types.rb', line 15535

class UpdateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :threat_entity_set_id,
  :name,
  :location,
  :expected_bucket_owner,
  :activate)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A user-friendly name to identify the trusted entity set.

The name of your list can include lowercase letters, uppercase letters, numbers, dash (-), and underscore (_).



15535
15536
15537
15538
15539
15540
15541
15542
15543
15544
# File 'lib/aws-sdk-guardduty/types.rb', line 15535

class UpdateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :threat_entity_set_id,
  :name,
  :location,
  :expected_bucket_owner,
  :activate)
  SENSITIVE = []
  include Aws::Structure
end

#threat_entity_set_idString

The ID returned by GuardDuty after updating the threat entity set resource.



15535
15536
15537
15538
15539
15540
15541
15542
15543
15544
# File 'lib/aws-sdk-guardduty/types.rb', line 15535

class UpdateThreatEntitySetRequest < Struct.new(
  :detector_id,
  :threat_entity_set_id,
  :name,
  :location,
  :expected_bucket_owner,
  :activate)
  SENSITIVE = []
  include Aws::Structure
end