Class: Aws::GuardDuty::Types::UsageTopAccountsResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::UsageTopAccountsResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Information about the usage statistics, calculated by top accounts by feature.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accounts ⇒ Array<Types::UsageTopAccountResult>
The accounts that contributed to the total usage cost.
-
#feature ⇒ String
Features by which you can generate the usage statistics.
Instance Attribute Details
#accounts ⇒ Array<Types::UsageTopAccountResult>
The accounts that contributed to the total usage cost.
15851 15852 15853 15854 15855 15856 |
# File 'lib/aws-sdk-guardduty/types.rb', line 15851 class UsageTopAccountsResult < Struct.new( :feature, :accounts) SENSITIVE = [] include Aws::Structure end |
#feature ⇒ String
Features by which you can generate the usage statistics.
RDS_LOGIN_EVENTS is currently not supported with
topAccountsByFeature.
15851 15852 15853 15854 15855 15856 |
# File 'lib/aws-sdk-guardduty/types.rb', line 15851 class UsageTopAccountsResult < Struct.new( :feature, :accounts) SENSITIVE = [] include Aws::Structure end |