Class: Aws::GuardDuty::Types::CloudDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::CloudDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains details about the cloud environment associated with an investigation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account ⇒ String
The Amazon Web Services account ID of the investigated resource.
-
#provider ⇒ String
The cloud provider.
-
#region ⇒ String
The Amazon Web Services Region in which the investigated resource resides.
Instance Attribute Details
#account ⇒ String
The Amazon Web Services account ID of the investigated resource.
848 849 850 851 852 853 854 |
# File 'lib/aws-sdk-guardduty/types.rb', line 848 class CloudDetails < Struct.new( :provider, :region, :account) SENSITIVE = [] include Aws::Structure end |
#provider ⇒ String
The cloud provider. Currently, only ‘AWS` is supported.
848 849 850 851 852 853 854 |
# File 'lib/aws-sdk-guardduty/types.rb', line 848 class CloudDetails < Struct.new( :provider, :region, :account) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
The Amazon Web Services Region in which the investigated resource resides.
848 849 850 851 852 853 854 |
# File 'lib/aws-sdk-guardduty/types.rb', line 848 class CloudDetails < Struct.new( :provider, :region, :account) SENSITIVE = [] include Aws::Structure end |