Class: Aws::GuardDuty::Types::ContinuousScanDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ContinuousScanDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the time range within the continuous backup in Amazon Web Services Backup to scan for a point-in-time recovery resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
The timestamp representing the end of the time range to scan.
-
#start_time ⇒ Time
The timestamp representing the start of the time range to scan.
Instance Attribute Details
#end_time ⇒ Time
The timestamp representing the end of the time range to scan.
1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1100 class ContinuousScanDetails < Struct.new( :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The timestamp representing the start of the time range to scan. Reserved for internal use.
1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1100 class ContinuousScanDetails < Struct.new( :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |