Class: Aws::GuardDuty::Types::CreateDetectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::CreateDetectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The idempotency token for the create request.
-
#data_sources ⇒ Types::DataSourceConfigurations
Describes which data sources will be enabled for the detector.
-
#enable ⇒ Boolean
A Boolean value that specifies whether the detector is to be enabled.
-
#features ⇒ Array<Types::DetectorFeatureConfiguration>
A list of features that will be configured for the detector.
-
#finding_publishing_frequency ⇒ String
A value that specifies how frequently updated findings are exported.
-
#tags ⇒ Hash<String,String>
The tags to be added to a new detector resource.
Instance Attribute Details
#client_token ⇒ String
The idempotency token for the create request.
A suitable default value is auto-generated. You should normally not need to pass this option.
1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1585 class CreateDetectorRequest < Struct.new( :enable, :client_token, :finding_publishing_frequency, :data_sources, :tags, :features) SENSITIVE = [] include Aws::Structure end |
#data_sources ⇒ Types::DataSourceConfigurations
Describes which data sources will be enabled for the detector.
There might be regional differences because some data sources might not be available in all the Amazon Web Services Regions where GuardDuty is presently supported. For more information, see Regions and endpoints.
1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1585 class CreateDetectorRequest < Struct.new( :enable, :client_token, :finding_publishing_frequency, :data_sources, :tags, :features) SENSITIVE = [] include Aws::Structure end |
#enable ⇒ Boolean
A Boolean value that specifies whether the detector is to be enabled.
1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1585 class CreateDetectorRequest < Struct.new( :enable, :client_token, :finding_publishing_frequency, :data_sources, :tags, :features) SENSITIVE = [] include Aws::Structure end |
#features ⇒ Array<Types::DetectorFeatureConfiguration>
A list of features that will be configured for the detector.
1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1585 class CreateDetectorRequest < Struct.new( :enable, :client_token, :finding_publishing_frequency, :data_sources, :tags, :features) SENSITIVE = [] include Aws::Structure end |
#finding_publishing_frequency ⇒ String
A value that specifies how frequently updated findings are exported.
1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1585 class CreateDetectorRequest < Struct.new( :enable, :client_token, :finding_publishing_frequency, :data_sources, :tags, :features) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to be added to a new detector resource.
1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1585 class CreateDetectorRequest < Struct.new( :enable, :client_token, :finding_publishing_frequency, :data_sources, :tags, :features) SENSITIVE = [] include Aws::Structure end |