Class: Aws::GuardDuty::Types::CreateDetectorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The idempotency token for the create request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
# File 'lib/aws-sdk-guardduty/types.rb', line 1496

class CreateDetectorRequest < Struct.new(
  :enable,
  :client_token,
  :finding_publishing_frequency,
  :data_sources,
  :tags,
  :features)
  SENSITIVE = []
  include Aws::Structure
end

#data_sourcesTypes::DataSourceConfigurations

Describes which data sources will be enabled for the detector.

There might be regional differences because some data sources might not be available in all the Amazon Web Services Regions where GuardDuty is presently supported. For more information, see [Regions and endpoints].

[1]: docs.aws.amazon.com/guardduty/latest/ug/guardduty_regions.html



1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
# File 'lib/aws-sdk-guardduty/types.rb', line 1496

class CreateDetectorRequest < Struct.new(
  :enable,
  :client_token,
  :finding_publishing_frequency,
  :data_sources,
  :tags,
  :features)
  SENSITIVE = []
  include Aws::Structure
end

#enableBoolean

A Boolean value that specifies whether the detector is to be enabled.

Returns:

  • (Boolean)


1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
# File 'lib/aws-sdk-guardduty/types.rb', line 1496

class CreateDetectorRequest < Struct.new(
  :enable,
  :client_token,
  :finding_publishing_frequency,
  :data_sources,
  :tags,
  :features)
  SENSITIVE = []
  include Aws::Structure
end

#featuresArray<Types::DetectorFeatureConfiguration>

A list of features that will be configured for the detector.



1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
# File 'lib/aws-sdk-guardduty/types.rb', line 1496

class CreateDetectorRequest < Struct.new(
  :enable,
  :client_token,
  :finding_publishing_frequency,
  :data_sources,
  :tags,
  :features)
  SENSITIVE = []
  include Aws::Structure
end

#finding_publishing_frequencyString

A value that specifies how frequently updated findings are exported.

Returns:

  • (String)


1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
# File 'lib/aws-sdk-guardduty/types.rb', line 1496

class CreateDetectorRequest < Struct.new(
  :enable,
  :client_token,
  :finding_publishing_frequency,
  :data_sources,
  :tags,
  :features)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to be added to a new detector resource.

Returns:

  • (Hash<String,String>)


1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
# File 'lib/aws-sdk-guardduty/types.rb', line 1496

class CreateDetectorRequest < Struct.new(
  :enable,
  :client_token,
  :finding_publishing_frequency,
  :data_sources,
  :tags,
  :features)
  SENSITIVE = []
  include Aws::Structure
end