Class: Aws::GuardDuty::Types::CreateDetectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::CreateDetectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The idempotency token for the create request.
-
#data_sources ⇒ Types::DataSourceConfigurations
Describes which data sources will be enabled for the detector.
-
#enable ⇒ Boolean
A Boolean value that specifies whether the detector is to be enabled.
-
#features ⇒ Array<Types::DetectorFeatureConfiguration>
A list of features that will be configured for the detector.
-
#finding_publishing_frequency ⇒ String
A value that specifies how frequently updated findings are exported.
-
#tags ⇒ Hash<String,String>
The tags to be added to a new detector resource.
Instance Attribute Details
#client_token ⇒ String
The idempotency token for the create request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1438 class CreateDetectorRequest < Struct.new( :enable, :client_token, :finding_publishing_frequency, :data_sources, :tags, :features) SENSITIVE = [] include Aws::Structure end |
#data_sources ⇒ Types::DataSourceConfigurations
Describes which data sources will be enabled for the detector.
There might be regional differences because some data sources might not be available in all the Amazon Web Services Regions where GuardDuty is presently supported. For more information, see [Regions and endpoints].
[1]: docs.aws.amazon.com/guardduty/latest/ug/guardduty_regions.html
1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1438 class CreateDetectorRequest < Struct.new( :enable, :client_token, :finding_publishing_frequency, :data_sources, :tags, :features) SENSITIVE = [] include Aws::Structure end |
#enable ⇒ Boolean
A Boolean value that specifies whether the detector is to be enabled.
1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1438 class CreateDetectorRequest < Struct.new( :enable, :client_token, :finding_publishing_frequency, :data_sources, :tags, :features) SENSITIVE = [] include Aws::Structure end |
#features ⇒ Array<Types::DetectorFeatureConfiguration>
A list of features that will be configured for the detector.
1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1438 class CreateDetectorRequest < Struct.new( :enable, :client_token, :finding_publishing_frequency, :data_sources, :tags, :features) SENSITIVE = [] include Aws::Structure end |
#finding_publishing_frequency ⇒ String
A value that specifies how frequently updated findings are exported.
1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1438 class CreateDetectorRequest < Struct.new( :enable, :client_token, :finding_publishing_frequency, :data_sources, :tags, :features) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to be added to a new detector resource.
1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 |
# File 'lib/aws-sdk-guardduty/types.rb', line 1438 class CreateDetectorRequest < Struct.new( :enable, :client_token, :finding_publishing_frequency, :data_sources, :tags, :features) SENSITIVE = [] include Aws::Structure end |