Class: Aws::GuardDuty::Types::CreateIPSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::CreateIPSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activate ⇒ Boolean
A Boolean value that indicates whether GuardDuty is to start using the uploaded IPSet.
-
#client_token ⇒ String
The idempotency token for the create request.
-
#detector_id ⇒ String
The unique ID of the detector of the GuardDuty account for which you want to create an IPSet.
-
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
-
#format ⇒ String
The format of the file that contains the IPSet.
-
#location ⇒ String
The URI of the file that contains the IPSet.
-
#name ⇒ String
The user-friendly name to identify the IPSet.
-
#tags ⇒ Hash<String,String>
The tags to be added to a new IP set resource.
Instance Attribute Details
#activate ⇒ Boolean
A Boolean value that indicates whether GuardDuty is to start using the uploaded IPSet.
3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3000 class CreateIPSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The idempotency token for the create request.
A suitable default value is auto-generated. You should normally not need to pass this option.
3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3000 class CreateIPSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The unique ID of the detector of the GuardDuty account for which you want to create an IPSet.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3000 class CreateIPSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3000 class CreateIPSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
The format of the file that contains the IPSet.
3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3000 class CreateIPSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The URI of the file that contains the IPSet.
3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3000 class CreateIPSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The user-friendly name to identify the IPSet.
Allowed characters are alphanumeric, whitespace, dash (-), and underscores (_).
3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3000 class CreateIPSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to be added to a new IP set resource.
3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3000 class CreateIPSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |