Class: Aws::GuardDuty::Types::CreateIPSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activateBoolean

A Boolean value that indicates whether GuardDuty is to start using the uploaded IPSet.

Returns:

  • (Boolean)


1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
# File 'lib/aws-sdk-guardduty/types.rb', line 1813

class CreateIPSetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :activate,
  :client_token,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

The idempotency token for the create request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
# File 'lib/aws-sdk-guardduty/types.rb', line 1813

class CreateIPSetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :activate,
  :client_token,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The unique ID of the detector of the GuardDuty account for which you want to create an IPSet.

To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

Returns:

  • (String)


1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
# File 'lib/aws-sdk-guardduty/types.rb', line 1813

class CreateIPSetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :activate,
  :client_token,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.

Returns:

  • (String)


1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
# File 'lib/aws-sdk-guardduty/types.rb', line 1813

class CreateIPSetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :activate,
  :client_token,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#formatString

The format of the file that contains the IPSet.

Returns:

  • (String)


1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
# File 'lib/aws-sdk-guardduty/types.rb', line 1813

class CreateIPSetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :activate,
  :client_token,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The URI of the file that contains the IPSet.

Returns:

  • (String)


1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
# File 'lib/aws-sdk-guardduty/types.rb', line 1813

class CreateIPSetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :activate,
  :client_token,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The user-friendly name to identify the IPSet.

Allowed characters are alphanumeric, whitespace, dash (-), and underscores (_).

Returns:

  • (String)


1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
# File 'lib/aws-sdk-guardduty/types.rb', line 1813

class CreateIPSetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :activate,
  :client_token,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to be added to a new IP set resource.

Returns:

  • (Hash<String,String>)


1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
# File 'lib/aws-sdk-guardduty/types.rb', line 1813

class CreateIPSetRequest < Struct.new(
  :detector_id,
  :name,
  :format,
  :location,
  :activate,
  :client_token,
  :tags,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end