Class: Aws::GuardDuty::Types::CreateMalwareProtectionPlanRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::CreateMalwareProtectionPlanRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Types::MalwareProtectionPlanActions
Information about whether the tags will be added to the S3 object after scanning.
-
#client_token ⇒ String
The idempotency token for the create request.
-
#protected_resource ⇒ Types::CreateProtectedResource
Information about the protected resource that is associated with the created Malware Protection plan.
-
#role ⇒ String
Amazon Resource Name (ARN) of the IAM role that has the permissions to scan and add tags to the associated protected resource.
-
#tags ⇒ Hash<String,String>
Tags added to the Malware Protection plan resource.
Instance Attribute Details
#actions ⇒ Types::MalwareProtectionPlanActions
Information about whether the tags will be added to the S3 object after scanning.
3018 3019 3020 3021 3022 3023 3024 3025 3026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3018 class CreateMalwareProtectionPlanRequest < Struct.new( :client_token, :role, :protected_resource, :actions, :tags) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The idempotency token for the create request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3018 3019 3020 3021 3022 3023 3024 3025 3026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3018 class CreateMalwareProtectionPlanRequest < Struct.new( :client_token, :role, :protected_resource, :actions, :tags) SENSITIVE = [] include Aws::Structure end |
#protected_resource ⇒ Types::CreateProtectedResource
Information about the protected resource that is associated with the created Malware Protection plan. Presently, ‘S3Bucket` is the only supported protected resource.
3018 3019 3020 3021 3022 3023 3024 3025 3026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3018 class CreateMalwareProtectionPlanRequest < Struct.new( :client_token, :role, :protected_resource, :actions, :tags) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
Amazon Resource Name (ARN) of the IAM role that has the permissions to scan and add tags to the associated protected resource.
3018 3019 3020 3021 3022 3023 3024 3025 3026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3018 class CreateMalwareProtectionPlanRequest < Struct.new( :client_token, :role, :protected_resource, :actions, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags added to the Malware Protection plan resource.
3018 3019 3020 3021 3022 3023 3024 3025 3026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3018 class CreateMalwareProtectionPlanRequest < Struct.new( :client_token, :role, :protected_resource, :actions, :tags) SENSITIVE = [] include Aws::Structure end |