Class: Aws::GuardDuty::Types::CreatePublishingDestinationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The idempotency token for the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


1980
1981
1982
1983
1984
1985
1986
1987
1988
# File 'lib/aws-sdk-guardduty/types.rb', line 1980

class CreatePublishingDestinationRequest < Struct.new(
  :detector_id,
  :destination_type,
  :destination_properties,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#destination_propertiesTypes::DestinationProperties

The properties of the publishing destination, including the ARNs for the destination and the KMS key used for encryption.



1980
1981
1982
1983
1984
1985
1986
1987
1988
# File 'lib/aws-sdk-guardduty/types.rb', line 1980

class CreatePublishingDestinationRequest < Struct.new(
  :detector_id,
  :destination_type,
  :destination_properties,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#destination_typeString

The type of resource for the publishing destination. Currently only Amazon S3 buckets are supported.

Returns:

  • (String)


1980
1981
1982
1983
1984
1985
1986
1987
1988
# File 'lib/aws-sdk-guardduty/types.rb', line 1980

class CreatePublishingDestinationRequest < Struct.new(
  :detector_id,
  :destination_type,
  :destination_properties,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The ID of the GuardDuty detector associated with the publishing destination.

To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

Returns:

  • (String)


1980
1981
1982
1983
1984
1985
1986
1987
1988
# File 'lib/aws-sdk-guardduty/types.rb', line 1980

class CreatePublishingDestinationRequest < Struct.new(
  :detector_id,
  :destination_type,
  :destination_properties,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to be added to a new publishing destination resource.

Returns:

  • (Hash<String,String>)


1980
1981
1982
1983
1984
1985
1986
1987
1988
# File 'lib/aws-sdk-guardduty/types.rb', line 1980

class CreatePublishingDestinationRequest < Struct.new(
  :detector_id,
  :destination_type,
  :destination_properties,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end