Class: Aws::GuardDuty::Types::CreateSampleFindingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::CreateSampleFindingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The ID of the detector for which you need to create sample findings.
-
#finding_types ⇒ Array<String>
The types of sample findings to generate.
Instance Attribute Details
#detector_id ⇒ String
The ID of the detector for which you need to create sample findings.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
3368 3369 3370 3371 3372 3373 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3368 class CreateSampleFindingsRequest < Struct.new( :detector_id, :finding_types) SENSITIVE = [] include Aws::Structure end |
#finding_types ⇒ Array<String>
The types of sample findings to generate.
3368 3369 3370 3371 3372 3373 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3368 class CreateSampleFindingsRequest < Struct.new( :detector_id, :finding_types) SENSITIVE = [] include Aws::Structure end |