Class: Aws::GuardDuty::Types::CreateThreatIntelSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::CreateThreatIntelSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activate ⇒ Boolean
A Boolean value that indicates whether GuardDuty is to start using the uploaded ThreatIntelSet.
-
#client_token ⇒ String
The idempotency token for the create request.
-
#detector_id ⇒ String
The unique ID of the detector of the GuardDuty account for which you want to create a ‘threatIntelSet`.
-
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
-
#format ⇒ String
The format of the file that contains the ThreatIntelSet.
-
#location ⇒ String
The URI of the file that contains the ThreatIntelSet.
-
#name ⇒ String
A user-friendly ThreatIntelSet name displayed in all findings that are generated by activity that involves IP addresses included in this ThreatIntelSet.
-
#tags ⇒ Hash<String,String>
The tags to be added to a new threat list resource.
Instance Attribute Details
#activate ⇒ Boolean
A Boolean value that indicates whether GuardDuty is to start using the uploaded ThreatIntelSet.
3337 3338 3339 3340 3341 3342 3343 3344 3345 3346 3347 3348 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3337 class CreateThreatIntelSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
The idempotency token for the create request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3337 3338 3339 3340 3341 3342 3343 3344 3345 3346 3347 3348 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3337 class CreateThreatIntelSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The unique ID of the detector of the GuardDuty account for which you want to create a ‘threatIntelSet`.
To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
3337 3338 3339 3340 3341 3342 3343 3344 3345 3346 3347 3348 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3337 class CreateThreatIntelSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
3337 3338 3339 3340 3341 3342 3343 3344 3345 3346 3347 3348 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3337 class CreateThreatIntelSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
The format of the file that contains the ThreatIntelSet.
3337 3338 3339 3340 3341 3342 3343 3344 3345 3346 3347 3348 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3337 class CreateThreatIntelSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The URI of the file that contains the ThreatIntelSet.
3337 3338 3339 3340 3341 3342 3343 3344 3345 3346 3347 3348 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3337 class CreateThreatIntelSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A user-friendly ThreatIntelSet name displayed in all findings that are generated by activity that involves IP addresses included in this ThreatIntelSet.
3337 3338 3339 3340 3341 3342 3343 3344 3345 3346 3347 3348 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3337 class CreateThreatIntelSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to be added to a new threat list resource.
3337 3338 3339 3340 3341 3342 3343 3344 3345 3346 3347 3348 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3337 class CreateThreatIntelSetRequest < Struct.new( :detector_id, :name, :format, :location, :activate, :client_token, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |