Class: Aws::GuardDuty::Types::CreateTrustedEntitySetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::CreateTrustedEntitySetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#trusted_entity_set_id ⇒ String
The ID returned by GuardDuty after creation of the trusted entity set resource.
Instance Attribute Details
#trusted_entity_set_id ⇒ String
The ID returned by GuardDuty after creation of the trusted entity set resource.
3442 3443 3444 3445 3446 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3442 class CreateTrustedEntitySetResponse < Struct.new( :trusted_entity_set_id) SENSITIVE = [] include Aws::Structure end |