Class: Aws::GuardDuty::Types::DeleteDetectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::DeleteDetectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector that you want to delete.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector that you want to delete.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
3866 3867 3868 3869 3870 |
# File 'lib/aws-sdk-guardduty/types.rb', line 3866 class DeleteDetectorRequest < Struct.new( :detector_id) SENSITIVE = [] include Aws::Structure end |