Class: Aws::GuardDuty::Types::DeleteThreatEntitySetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector associated with the threat entity set resource.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


4058
4059
4060
4061
4062
4063
# File 'lib/aws-sdk-guardduty/types.rb', line 4058

class DeleteThreatEntitySetRequest < Struct.new(
  :detector_id,
  :threat_entity_set_id)
  SENSITIVE = []
  include Aws::Structure
end

#threat_entity_set_idString

The unique ID that helps GuardDuty identify which threat entity set needs to be deleted.

Returns:

  • (String)


4058
4059
4060
4061
4062
4063
# File 'lib/aws-sdk-guardduty/types.rb', line 4058

class DeleteThreatEntitySetRequest < Struct.new(
  :detector_id,
  :threat_entity_set_id)
  SENSITIVE = []
  include Aws::Structure
end