Class: Aws::GuardDuty::Types::DeleteThreatEntitySetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::DeleteThreatEntitySetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector associated with the threat entity set resource.
-
#threat_entity_set_id ⇒ String
The unique ID that helps GuardDuty identify which threat entity set needs to be deleted.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector associated with the threat entity set resource.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
4058 4059 4060 4061 4062 4063 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4058 class DeleteThreatEntitySetRequest < Struct.new( :detector_id, :threat_entity_set_id) SENSITIVE = [] include Aws::Structure end |
#threat_entity_set_id ⇒ String
The unique ID that helps GuardDuty identify which threat entity set needs to be deleted.
4058 4059 4060 4061 4062 4063 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4058 class DeleteThreatEntitySetRequest < Struct.new( :detector_id, :threat_entity_set_id) SENSITIVE = [] include Aws::Structure end |