Class: Aws::GuardDuty::Types::DeleteTrustedEntitySetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::DeleteTrustedEntitySetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector associated with the trusted entity set resource.
-
#trusted_entity_set_id ⇒ String
The unique ID that helps GuardDuty identify which trusted entity set needs to be deleted.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector associated with the trusted entity set resource.
To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
2789 2790 2791 2792 2793 2794 |
# File 'lib/aws-sdk-guardduty/types.rb', line 2789 class DeleteTrustedEntitySetRequest < Struct.new( :detector_id, :trusted_entity_set_id) SENSITIVE = [] include Aws::Structure end |
#trusted_entity_set_id ⇒ String
The unique ID that helps GuardDuty identify which trusted entity set needs to be deleted.
2789 2790 2791 2792 2793 2794 |
# File 'lib/aws-sdk-guardduty/types.rb', line 2789 class DeleteTrustedEntitySetRequest < Struct.new( :detector_id, :trusted_entity_set_id) SENSITIVE = [] include Aws::Structure end |