Class: Aws::GuardDuty::Types::DescribeMalwareScansRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::DescribeMalwareScansRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector that the request is associated with.
-
#filter_criteria ⇒ Types::FilterCriteria
Represents the criteria to be used in the filter for describing scan entries.
-
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items that you want in the response.
-
#next_token ⇒ String
You can use this parameter when paginating results.
-
#sort_criteria ⇒ Types::SortCriteria
Represents the criteria used for sorting scan entries.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector that the request is associated with.
To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
4002 4003 4004 4005 4006 4007 4008 4009 4010 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4002 class DescribeMalwareScansRequest < Struct.new( :detector_id, :next_token, :max_results, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#filter_criteria ⇒ Types::FilterCriteria
Represents the criteria to be used in the filter for describing scan entries.
4002 4003 4004 4005 4006 4007 4008 4009 4010 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4002 class DescribeMalwareScansRequest < Struct.new( :detector_id, :next_token, :max_results, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50.
4002 4003 4004 4005 4006 4007 4008 4009 4010 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4002 class DescribeMalwareScansRequest < Struct.new( :detector_id, :next_token, :max_results, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
4002 4003 4004 4005 4006 4007 4008 4009 4010 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4002 class DescribeMalwareScansRequest < Struct.new( :detector_id, :next_token, :max_results, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#sort_criteria ⇒ Types::SortCriteria
Represents the criteria used for sorting scan entries. The [ ‘attributeName` ][1] is required and it must be `scanStartTime`.
4002 4003 4004 4005 4006 4007 4008 4009 4010 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4002 class DescribeMalwareScansRequest < Struct.new( :detector_id, :next_token, :max_results, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |