Class: Aws::GuardDuty::Types::DescribePublishingDestinationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::DescribePublishingDestinationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_id ⇒ String
The ID of the publishing destination to retrieve.
-
#detector_id ⇒ String
The unique ID of the detector associated with the publishing destination to retrieve.
Instance Attribute Details
#destination_id ⇒ String
The ID of the publishing destination to retrieve.
4320 4321 4322 4323 4324 4325 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4320 class DescribePublishingDestinationRequest < Struct.new( :detector_id, :destination_id) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The unique ID of the detector associated with the publishing destination to retrieve.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
4320 4321 4322 4323 4324 4325 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4320 class DescribePublishingDestinationRequest < Struct.new( :detector_id, :destination_id) SENSITIVE = [] include Aws::Structure end |