Class: Aws::GuardDuty::Types::DescribePublishingDestinationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::DescribePublishingDestinationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination_id ⇒ String
The ID of the publishing destination.
-
#destination_properties ⇒ Types::DestinationProperties
A ‘DestinationProperties` object that includes the `DestinationArn` and `KmsKeyArn` of the publishing destination.
-
#destination_type ⇒ String
The type of publishing destination.
-
#publishing_failure_start_timestamp ⇒ Integer
The time, in epoch millisecond format, at which GuardDuty was first unable to publish findings to the destination.
-
#status ⇒ String
The status of the publishing destination.
-
#tags ⇒ Hash<String,String>
The tags of the publishing destination resource.
Instance Attribute Details
#destination_id ⇒ String
The ID of the publishing destination.
4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4179 class DescribePublishingDestinationResponse < Struct.new( :destination_id, :destination_type, :status, :publishing_failure_start_timestamp, :destination_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#destination_properties ⇒ Types::DestinationProperties
A ‘DestinationProperties` object that includes the `DestinationArn` and `KmsKeyArn` of the publishing destination.
4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4179 class DescribePublishingDestinationResponse < Struct.new( :destination_id, :destination_type, :status, :publishing_failure_start_timestamp, :destination_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#destination_type ⇒ String
The type of publishing destination. Currently, only Amazon S3 buckets are supported.
4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4179 class DescribePublishingDestinationResponse < Struct.new( :destination_id, :destination_type, :status, :publishing_failure_start_timestamp, :destination_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#publishing_failure_start_timestamp ⇒ Integer
The time, in epoch millisecond format, at which GuardDuty was first unable to publish findings to the destination.
4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4179 class DescribePublishingDestinationResponse < Struct.new( :destination_id, :destination_type, :status, :publishing_failure_start_timestamp, :destination_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the publishing destination.
4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4179 class DescribePublishingDestinationResponse < Struct.new( :destination_id, :destination_type, :status, :publishing_failure_start_timestamp, :destination_properties, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the publishing destination resource.
4179 4180 4181 4182 4183 4184 4185 4186 4187 4188 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4179 class DescribePublishingDestinationResponse < Struct.new( :destination_id, :destination_type, :status, :publishing_failure_start_timestamp, :destination_properties, :tags) SENSITIVE = [] include Aws::Structure end |