Class: Aws::GuardDuty::Types::GetDetectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetDetectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector that you want to get.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector that you want to get.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
5694 5695 5696 5697 5698 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5694 class GetDetectorRequest < Struct.new( :detector_id) SENSITIVE = [] include Aws::Structure end |