Class: Aws::GuardDuty::Types::GetDetectorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector that you want to get.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

Returns:

  • (String)


4366
4367
4368
4369
4370
# File 'lib/aws-sdk-guardduty/types.rb', line 4366

class GetDetectorRequest < Struct.new(
  :detector_id)
  SENSITIVE = []
  include Aws::Structure
end