Class: Aws::GuardDuty::Types::GetDetectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetDetectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector that you want to get.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector that you want to get.
To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
4366 4367 4368 4369 4370 |
# File 'lib/aws-sdk-guardduty/types.rb', line 4366 class GetDetectorRequest < Struct.new( :detector_id) SENSITIVE = [] include Aws::Structure end |