Class: Aws::GuardDuty::Types::GetFilterResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetFilterResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
Specifies the action that is to be applied to the findings that match the filter.
-
#created_at ⇒ Time
The timestamp when the filter was created.
-
#description ⇒ String
The description of the filter.
-
#finding_criteria ⇒ Types::FindingCriteria
Represents the criteria to be used in the filter for querying findings.
-
#name ⇒ String
The name of the filter.
-
#rank ⇒ Integer
Specifies the position of the filter in the list of current filters.
-
#tags ⇒ Hash<String,String>
The tags of the filter resource.
-
#updated_at ⇒ Time
The timestamp when the filter was last updated.
-
#version ⇒ Integer
The version of the filter.
Instance Attribute Details
#action ⇒ String
Specifies the action that is to be applied to the findings that match the filter.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6315 class GetFilterResponse < Struct.new( :name, :description, :action, :rank, :finding_criteria, :tags, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the filter was created. This field is not available for filters that were created before the lifecycle metadata feature was enabled (legacy filters).
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6315 class GetFilterResponse < Struct.new( :name, :description, :action, :rank, :finding_criteria, :tags, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the filter.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6315 class GetFilterResponse < Struct.new( :name, :description, :action, :rank, :finding_criteria, :tags, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#finding_criteria ⇒ Types::FindingCriteria
Represents the criteria to be used in the filter for querying findings.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6315 class GetFilterResponse < Struct.new( :name, :description, :action, :rank, :finding_criteria, :tags, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the filter.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6315 class GetFilterResponse < Struct.new( :name, :description, :action, :rank, :finding_criteria, :tags, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#rank ⇒ Integer
Specifies the position of the filter in the list of current filters. Also specifies the order in which this filter is applied to the findings.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6315 class GetFilterResponse < Struct.new( :name, :description, :action, :rank, :finding_criteria, :tags, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the filter resource.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6315 class GetFilterResponse < Struct.new( :name, :description, :action, :rank, :finding_criteria, :tags, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the filter was last updated. For legacy filters, this field is present only after the filter has been updated at least once since the lifecycle metadata feature was enabled.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6315 class GetFilterResponse < Struct.new( :name, :description, :action, :rank, :finding_criteria, :tags, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Integer
The version of the filter. Every time the filter is updated, the version increments by 1. This field is not available for legacy filters that were created before the lifecycle metadata feature was enabled.
6315 6316 6317 6318 6319 6320 6321 6322 6323 6324 6325 6326 6327 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6315 class GetFilterResponse < Struct.new( :name, :description, :action, :rank, :finding_criteria, :tags, :created_at, :updated_at, :version) SENSITIVE = [] include Aws::Structure end |