Class: Aws::GuardDuty::Types::GetFindingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetFindingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The ID of the detector that specifies the GuardDuty service whose findings you want to retrieve.
-
#finding_ids ⇒ Array<String>
The IDs of the findings that you want to retrieve.
-
#sort_criteria ⇒ Types::SortCriteria
Represents the criteria used for sorting findings.
Instance Attribute Details
#detector_id ⇒ String
The ID of the detector that specifies the GuardDuty service whose findings you want to retrieve.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
5856 5857 5858 5859 5860 5861 5862 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5856 class GetFindingsRequest < Struct.new( :detector_id, :finding_ids, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#finding_ids ⇒ Array<String>
The IDs of the findings that you want to retrieve.
5856 5857 5858 5859 5860 5861 5862 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5856 class GetFindingsRequest < Struct.new( :detector_id, :finding_ids, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#sort_criteria ⇒ Types::SortCriteria
Represents the criteria used for sorting findings.
5856 5857 5858 5859 5860 5861 5862 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5856 class GetFindingsRequest < Struct.new( :detector_id, :finding_ids, :sort_criteria) SENSITIVE = [] include Aws::Structure end |