Class: Aws::GuardDuty::Types::GetIPSetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetIPSetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
-
#format ⇒ String
The format of the file that contains the IPSet.
-
#location ⇒ String
The URI of the file that contains the IPSet.
-
#name ⇒ String
The user-friendly name for the IPSet.
-
#status ⇒ String
The status of IPSet file that was uploaded.
-
#tags ⇒ Hash<String,String>
The tags of the IPSet resource.
Instance Attribute Details
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter. This field appears in the response only if it was provided during IPSet creation or update.
6495 6496 6497 6498 6499 6500 6501 6502 6503 6504 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6495 class GetIPSetResponse < Struct.new( :name, :format, :location, :status, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
The format of the file that contains the IPSet.
6495 6496 6497 6498 6499 6500 6501 6502 6503 6504 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6495 class GetIPSetResponse < Struct.new( :name, :format, :location, :status, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The URI of the file that contains the IPSet.
6495 6496 6497 6498 6499 6500 6501 6502 6503 6504 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6495 class GetIPSetResponse < Struct.new( :name, :format, :location, :status, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The user-friendly name for the IPSet.
6495 6496 6497 6498 6499 6500 6501 6502 6503 6504 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6495 class GetIPSetResponse < Struct.new( :name, :format, :location, :status, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of IPSet file that was uploaded.
6495 6496 6497 6498 6499 6500 6501 6502 6503 6504 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6495 class GetIPSetResponse < Struct.new( :name, :format, :location, :status, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the IPSet resource.
6495 6496 6497 6498 6499 6500 6501 6502 6503 6504 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6495 class GetIPSetResponse < Struct.new( :name, :format, :location, :status, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |