Class: Aws::GuardDuty::Types::GetMalwareProtectionPlanResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetMalwareProtectionPlanResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actions ⇒ Types::MalwareProtectionPlanActions
Information about whether the tags will be added to the S3 object after scanning.
-
#arn ⇒ String
Amazon Resource Name (ARN) of the protected resource.
-
#created_at ⇒ Time
The timestamp when the Malware Protection plan resource was created.
-
#protected_resource ⇒ Types::CreateProtectedResource
Information about the protected resource that is associated with the created Malware Protection plan.
-
#role ⇒ String
Amazon Resource Name (ARN) of the IAM role that includes the permissions to scan and add tags to the associated protected resource.
-
#status ⇒ String
Malware Protection plan status.
-
#status_reasons ⇒ Array<Types::MalwareProtectionPlanStatusReason>
Information about the issue code and message associated to the status of your Malware Protection plan.
-
#tags ⇒ Hash<String,String>
Tags added to the Malware Protection plan resource.
Instance Attribute Details
#actions ⇒ Types::MalwareProtectionPlanActions
Information about whether the tags will be added to the S3 object after scanning.
5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5907 class GetMalwareProtectionPlanResponse < Struct.new( :arn, :role, :protected_resource, :actions, :created_at, :status, :status_reasons, :tags) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
Amazon Resource Name (ARN) of the protected resource.
5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5907 class GetMalwareProtectionPlanResponse < Struct.new( :arn, :role, :protected_resource, :actions, :created_at, :status, :status_reasons, :tags) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the Malware Protection plan resource was created.
5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5907 class GetMalwareProtectionPlanResponse < Struct.new( :arn, :role, :protected_resource, :actions, :created_at, :status, :status_reasons, :tags) SENSITIVE = [] include Aws::Structure end |
#protected_resource ⇒ Types::CreateProtectedResource
Information about the protected resource that is associated with the created Malware Protection plan. Presently, ‘S3Bucket` is the only supported protected resource.
5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5907 class GetMalwareProtectionPlanResponse < Struct.new( :arn, :role, :protected_resource, :actions, :created_at, :status, :status_reasons, :tags) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
Amazon Resource Name (ARN) of the IAM role that includes the permissions to scan and add tags to the associated protected resource.
5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5907 class GetMalwareProtectionPlanResponse < Struct.new( :arn, :role, :protected_resource, :actions, :created_at, :status, :status_reasons, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Malware Protection plan status.
5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5907 class GetMalwareProtectionPlanResponse < Struct.new( :arn, :role, :protected_resource, :actions, :created_at, :status, :status_reasons, :tags) SENSITIVE = [] include Aws::Structure end |
#status_reasons ⇒ Array<Types::MalwareProtectionPlanStatusReason>
Information about the issue code and message associated to the status of your Malware Protection plan.
5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5907 class GetMalwareProtectionPlanResponse < Struct.new( :arn, :role, :protected_resource, :actions, :created_at, :status, :status_reasons, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags added to the Malware Protection plan resource.
5907 5908 5909 5910 5911 5912 5913 5914 5915 5916 5917 5918 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5907 class GetMalwareProtectionPlanResponse < Struct.new( :arn, :role, :protected_resource, :actions, :created_at, :status, :status_reasons, :tags) SENSITIVE = [] include Aws::Structure end |