Class: Aws::GuardDuty::Types::GetMalwareScanResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#admin_detector_idString

The unique detector ID of the administrator account that the request is associated with. If the account is an administrator, the ‘AdminDetectorId` will be the same as the one used for `DetectorId. If the customer is not a GuardDuty customer, this field will not be present.`.

To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

Returns:

  • (String)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The unique ID of the detector that is associated with the request, if it belongs to an account which is a GuardDuty customer.

To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

Returns:

  • (String)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#failed_resources_countInteger

The total number of resources that failed to be scanned.

Returns:

  • (Integer)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

Amazon Resource Name (ARN) of the resource on which a malware scan was invoked.

Returns:

  • (String)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of resource that was scanned for malware.

Returns:

  • (String)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#scan_categoryString

The category of the malware scan, indicating the type of scan performed.

Returns:

  • (String)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#scan_completed_atTime

The timestamp representing when the malware scan was completed.

Returns:

  • (Time)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#scan_configurationTypes::ScanConfiguration

Information about the scan configuration used for the malware scan.



6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#scan_idString

A unique identifier associated with the malware scan. Each malware scan has a corresponding scan ID. Using this scan ID, you can monitor the status of your malware scan.

Returns:

  • (String)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#scan_result_detailsTypes::GetMalwareScanResultDetails

Detailed information about the results of the malware scan, if the scan completed.



6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#scan_started_atTime

The timestamp representing when the malware scan was started.

Returns:

  • (Time)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#scan_statusString

A value representing the current status of the malware scan.

Returns:

  • (String)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#scan_status_reasonString

Represents the reason for the current scan status, if applicable.

Returns:

  • (String)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#scan_typeString

A value representing the initiator of the scan.

Returns:

  • (String)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#scanned_resourcesArray<Types::ScannedResource>

A list of resources along with their metadata that were scanned as part of the malware scan operation.

Returns:



6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#scanned_resources_countInteger

The total number of resources that were successfully scanned. This is dependent on the resource type.

Returns:

  • (Integer)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end

#skipped_resources_countInteger

The total number of resources that were skipped during the scan.

Returns:

  • (Integer)


6006
6007
6008
6009
6010
6011
6012
6013
6014
6015
6016
6017
6018
6019
6020
6021
6022
6023
6024
6025
6026
# File 'lib/aws-sdk-guardduty/types.rb', line 6006

class GetMalwareScanResponse < Struct.new(
  :scan_id,
  :detector_id,
  :admin_detector_id,
  :resource_arn,
  :resource_type,
  :scanned_resources_count,
  :skipped_resources_count,
  :failed_resources_count,
  :scanned_resources,
  :scan_configuration,
  :scan_category,
  :scan_status,
  :scan_status_reason,
  :scan_type,
  :scan_started_at,
  :scan_completed_at,
  :scan_result_details)
  SENSITIVE = []
  include Aws::Structure
end