Class: Aws::GuardDuty::Types::GetMalwareScanResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetMalwareScanResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#admin_detector_id ⇒ String
The unique detector ID of the administrator account that the request is associated with.
-
#detector_id ⇒ String
The unique ID of the detector that is associated with the request, if it belongs to an account which is a GuardDuty customer.
-
#failed_resources_count ⇒ Integer
The total number of resources that failed to be scanned.
-
#resource_arn ⇒ String
Amazon Resource Name (ARN) of the resource on which a malware scan was invoked.
-
#resource_type ⇒ String
The type of resource that was scanned for malware.
-
#scan_category ⇒ String
The category of the malware scan, indicating the type of scan performed.
-
#scan_completed_at ⇒ Time
The timestamp representing when the malware scan was completed.
-
#scan_configuration ⇒ Types::ScanConfiguration
Information about the scan configuration used for the malware scan.
-
#scan_id ⇒ String
A unique identifier associated with the malware scan.
-
#scan_result_details ⇒ Types::GetMalwareScanResultDetails
Detailed information about the results of the malware scan, if the scan completed.
-
#scan_started_at ⇒ Time
The timestamp representing when the malware scan was started.
-
#scan_status ⇒ String
A value representing the current status of the malware scan.
-
#scan_status_reason ⇒ String
Represents the reason for the current scan status, if applicable.
-
#scan_type ⇒ String
A value representing the initiator of the scan.
-
#scanned_resources ⇒ Array<Types::ScannedResource>
A list of resources along with their metadata that were scanned as part of the malware scan operation.
-
#scanned_resources_count ⇒ Integer
The total number of resources that were successfully scanned.
-
#skipped_resources_count ⇒ Integer
The total number of resources that were skipped during the scan.
Instance Attribute Details
#admin_detector_id ⇒ String
The unique detector ID of the administrator account that the request is associated with. If the account is an administrator, the ‘AdminDetectorId` will be the same as the one used for `DetectorId. If the customer is not a GuardDuty customer, this field will not be present.`.
To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The unique ID of the detector that is associated with the request, if it belongs to an account which is a GuardDuty customer.
To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#failed_resources_count ⇒ Integer
The total number of resources that failed to be scanned.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
Amazon Resource Name (ARN) of the resource on which a malware scan was invoked.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resource that was scanned for malware.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#scan_category ⇒ String
The category of the malware scan, indicating the type of scan performed.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#scan_completed_at ⇒ Time
The timestamp representing when the malware scan was completed.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#scan_configuration ⇒ Types::ScanConfiguration
Information about the scan configuration used for the malware scan.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#scan_id ⇒ String
A unique identifier associated with the malware scan. Each malware scan has a corresponding scan ID. Using this scan ID, you can monitor the status of your malware scan.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#scan_result_details ⇒ Types::GetMalwareScanResultDetails
Detailed information about the results of the malware scan, if the scan completed.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#scan_started_at ⇒ Time
The timestamp representing when the malware scan was started.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#scan_status ⇒ String
A value representing the current status of the malware scan.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#scan_status_reason ⇒ String
Represents the reason for the current scan status, if applicable.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#scan_type ⇒ String
A value representing the initiator of the scan.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#scanned_resources ⇒ Array<Types::ScannedResource>
A list of resources along with their metadata that were scanned as part of the malware scan operation.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#scanned_resources_count ⇒ Integer
The total number of resources that were successfully scanned. This is dependent on the resource type.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |
#skipped_resources_count ⇒ Integer
The total number of resources that were skipped during the scan.
6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6006 class GetMalwareScanResponse < Struct.new( :scan_id, :detector_id, :admin_detector_id, :resource_arn, :resource_type, :scanned_resources_count, :skipped_resources_count, :failed_resources_count, :scanned_resources, :scan_configuration, :scan_category, :scan_status, :scan_status_reason, :scan_type, :scan_started_at, :scan_completed_at, :scan_result_details) SENSITIVE = [] include Aws::Structure end |