Class: Aws::GuardDuty::Types::GetThreatEntitySetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector associated with the threat entity set resource.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


6520
6521
6522
6523
6524
6525
# File 'lib/aws-sdk-guardduty/types.rb', line 6520

class GetThreatEntitySetRequest < Struct.new(
  :detector_id,
  :threat_entity_set_id)
  SENSITIVE = []
  include Aws::Structure
end

#threat_entity_set_idString

The unique ID that helps GuardDuty identify the threat entity set.

Returns:

  • (String)


6520
6521
6522
6523
6524
6525
# File 'lib/aws-sdk-guardduty/types.rb', line 6520

class GetThreatEntitySetRequest < Struct.new(
  :detector_id,
  :threat_entity_set_id)
  SENSITIVE = []
  include Aws::Structure
end