Class: Aws::GuardDuty::Types::GetThreatEntitySetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetThreatEntitySetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector associated with the threat entity set resource.
-
#threat_entity_set_id ⇒ String
The unique ID that helps GuardDuty identify the threat entity set.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector associated with the threat entity set resource.
To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
5155 5156 5157 5158 5159 5160 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5155 class GetThreatEntitySetRequest < Struct.new( :detector_id, :threat_entity_set_id) SENSITIVE = [] include Aws::Structure end |
#threat_entity_set_id ⇒ String
The unique ID that helps GuardDuty identify the threat entity set.
5155 5156 5157 5158 5159 5160 |
# File 'lib/aws-sdk-guardduty/types.rb', line 5155 class GetThreatEntitySetRequest < Struct.new( :detector_id, :threat_entity_set_id) SENSITIVE = [] include Aws::Structure end |