Class: Aws::GuardDuty::Types::GetThreatEntitySetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetThreatEntitySetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the associated threat entity set was created.
-
#error_details ⇒ String
The error details when the status is shown as ‘ERROR`.
-
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
-
#format ⇒ String
The format of the file that contains the threat entity set.
-
#location ⇒ String
The URI of the file that contains the threat entity set.
-
#name ⇒ String
The name of the threat entity set associated with the specified ‘threatEntitySetId`.
-
#status ⇒ String
The status of the associated threat entity set.
-
#tags ⇒ Hash<String,String>
The tags associated with the threat entity set resource.
-
#updated_at ⇒ Time
The timestamp when the associated threat entity set was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the associated threat entity set was created.
6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6353 class GetThreatEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#error_details ⇒ String
The error details when the status is shown as ‘ERROR`.
6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6353 class GetThreatEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6353 class GetThreatEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
The format of the file that contains the threat entity set.
6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6353 class GetThreatEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The URI of the file that contains the threat entity set.
6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6353 class GetThreatEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the threat entity set associated with the specified ‘threatEntitySetId`.
6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6353 class GetThreatEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the associated threat entity set.
6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6353 class GetThreatEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags associated with the threat entity set resource.
6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6353 class GetThreatEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the associated threat entity set was updated.
6353 6354 6355 6356 6357 6358 6359 6360 6361 6362 6363 6364 6365 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6353 class GetThreatEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |