Class: Aws::GuardDuty::Types::GetThreatIntelSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector that is associated with the threatIntelSet.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


6599
6600
6601
6602
6603
6604
# File 'lib/aws-sdk-guardduty/types.rb', line 6599

class GetThreatIntelSetRequest < Struct.new(
  :detector_id,
  :threat_intel_set_id)
  SENSITIVE = []
  include Aws::Structure
end

#threat_intel_set_idString

The unique ID of the threatIntelSet that you want to get.

Returns:

  • (String)


6599
6600
6601
6602
6603
6604
# File 'lib/aws-sdk-guardduty/types.rb', line 6599

class GetThreatIntelSetRequest < Struct.new(
  :detector_id,
  :threat_intel_set_id)
  SENSITIVE = []
  include Aws::Structure
end