Class: Aws::GuardDuty::Types::GetThreatIntelSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetThreatIntelSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector that is associated with the threatIntelSet.
-
#threat_intel_set_id ⇒ String
The unique ID of the threatIntelSet that you want to get.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector that is associated with the threatIntelSet.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
6599 6600 6601 6602 6603 6604 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6599 class GetThreatIntelSetRequest < Struct.new( :detector_id, :threat_intel_set_id) SENSITIVE = [] include Aws::Structure end |
#threat_intel_set_id ⇒ String
The unique ID of the threatIntelSet that you want to get.
6599 6600 6601 6602 6603 6604 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6599 class GetThreatIntelSetRequest < Struct.new( :detector_id, :threat_intel_set_id) SENSITIVE = [] include Aws::Structure end |