Class: Aws::GuardDuty::Types::GetThreatIntelSetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetThreatIntelSetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
-
#format ⇒ String
The format of the threatIntelSet.
-
#location ⇒ String
The URI of the file that contains the ThreatIntelSet.
-
#name ⇒ String
A user-friendly ThreatIntelSet name displayed in all findings that are generated by activity that involves IP addresses included in this ThreatIntelSet.
-
#status ⇒ String
The status of threatIntelSet file uploaded.
-
#tags ⇒ Hash<String,String>
The tags of the threat list resource.
Instance Attribute Details
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter. This field appears in the response only if it was provided during ThreatIntelSet creation or update.
6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6433 class GetThreatIntelSetResponse < Struct.new( :name, :format, :location, :status, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
The format of the threatIntelSet.
6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6433 class GetThreatIntelSetResponse < Struct.new( :name, :format, :location, :status, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The URI of the file that contains the ThreatIntelSet.
6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6433 class GetThreatIntelSetResponse < Struct.new( :name, :format, :location, :status, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A user-friendly ThreatIntelSet name displayed in all findings that are generated by activity that involves IP addresses included in this ThreatIntelSet.
6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6433 class GetThreatIntelSetResponse < Struct.new( :name, :format, :location, :status, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of threatIntelSet file uploaded.
6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6433 class GetThreatIntelSetResponse < Struct.new( :name, :format, :location, :status, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the threat list resource.
6433 6434 6435 6436 6437 6438 6439 6440 6441 6442 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6433 class GetThreatIntelSetResponse < Struct.new( :name, :format, :location, :status, :tags, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |