Class: Aws::GuardDuty::Types::GetTrustedEntitySetResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp when the associated trusted entity set was created.

Returns:

  • (Time)


6728
6729
6730
6731
6732
6733
6734
6735
6736
6737
6738
6739
6740
# File 'lib/aws-sdk-guardduty/types.rb', line 6728

class GetTrustedEntitySetResponse < Struct.new(
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :status,
  :tags,
  :created_at,
  :updated_at,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#error_detailsString

The error details when the status is shown as ERROR.

Returns:

  • (String)


6728
6729
6730
6731
6732
6733
6734
6735
6736
6737
6738
6739
6740
# File 'lib/aws-sdk-guardduty/types.rb', line 6728

class GetTrustedEntitySetResponse < Struct.new(
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :status,
  :tags,
  :created_at,
  :updated_at,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.

Returns:

  • (String)


6728
6729
6730
6731
6732
6733
6734
6735
6736
6737
6738
6739
6740
# File 'lib/aws-sdk-guardduty/types.rb', line 6728

class GetTrustedEntitySetResponse < Struct.new(
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :status,
  :tags,
  :created_at,
  :updated_at,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#formatString

The format of the file that contains the trusted entity set.

Returns:

  • (String)


6728
6729
6730
6731
6732
6733
6734
6735
6736
6737
6738
6739
6740
# File 'lib/aws-sdk-guardduty/types.rb', line 6728

class GetTrustedEntitySetResponse < Struct.new(
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :status,
  :tags,
  :created_at,
  :updated_at,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The URI of the file that contains the trusted entity set.

Returns:

  • (String)


6728
6729
6730
6731
6732
6733
6734
6735
6736
6737
6738
6739
6740
# File 'lib/aws-sdk-guardduty/types.rb', line 6728

class GetTrustedEntitySetResponse < Struct.new(
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :status,
  :tags,
  :created_at,
  :updated_at,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the threat entity set associated with the specified trustedEntitySetId.

Returns:

  • (String)


6728
6729
6730
6731
6732
6733
6734
6735
6736
6737
6738
6739
6740
# File 'lib/aws-sdk-guardduty/types.rb', line 6728

class GetTrustedEntitySetResponse < Struct.new(
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :status,
  :tags,
  :created_at,
  :updated_at,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the associated trusted entity set.

Returns:

  • (String)


6728
6729
6730
6731
6732
6733
6734
6735
6736
6737
6738
6739
6740
# File 'lib/aws-sdk-guardduty/types.rb', line 6728

class GetTrustedEntitySetResponse < Struct.new(
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :status,
  :tags,
  :created_at,
  :updated_at,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags associated with trusted entity set resource.

Returns:

  • (Hash<String,String>)


6728
6729
6730
6731
6732
6733
6734
6735
6736
6737
6738
6739
6740
# File 'lib/aws-sdk-guardduty/types.rb', line 6728

class GetTrustedEntitySetResponse < Struct.new(
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :status,
  :tags,
  :created_at,
  :updated_at,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp when the associated trusted entity set was updated.

Returns:

  • (Time)


6728
6729
6730
6731
6732
6733
6734
6735
6736
6737
6738
6739
6740
# File 'lib/aws-sdk-guardduty/types.rb', line 6728

class GetTrustedEntitySetResponse < Struct.new(
  :name,
  :format,
  :location,
  :expected_bucket_owner,
  :status,
  :tags,
  :created_at,
  :updated_at,
  :error_details)
  SENSITIVE = []
  include Aws::Structure
end