Class: Aws::GuardDuty::Types::GetTrustedEntitySetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::GetTrustedEntitySetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the associated trusted entity set was created.
-
#error_details ⇒ String
The error details when the status is shown as
ERROR. -
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
-
#format ⇒ String
The format of the file that contains the trusted entity set.
-
#location ⇒ String
The URI of the file that contains the trusted entity set.
-
#name ⇒ String
The name of the threat entity set associated with the specified
trustedEntitySetId. -
#status ⇒ String
The status of the associated trusted entity set.
-
#tags ⇒ Hash<String,String>
The tags associated with trusted entity set resource.
-
#updated_at ⇒ Time
The timestamp when the associated trusted entity set was updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the associated trusted entity set was created.
6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6728 class GetTrustedEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#error_details ⇒ String
The error details when the status is shown as ERROR.
6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6728 class GetTrustedEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6728 class GetTrustedEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
The format of the file that contains the trusted entity set.
6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6728 class GetTrustedEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The URI of the file that contains the trusted entity set.
6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6728 class GetTrustedEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the threat entity set associated with the specified
trustedEntitySetId.
6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6728 class GetTrustedEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the associated trusted entity set.
6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6728 class GetTrustedEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags associated with trusted entity set resource.
6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6728 class GetTrustedEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the associated trusted entity set was updated.
6728 6729 6730 6731 6732 6733 6734 6735 6736 6737 6738 6739 6740 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6728 class GetTrustedEntitySetResponse < Struct.new( :name, :format, :location, :expected_bucket_owner, :status, :tags, :created_at, :updated_at, :error_details) SENSITIVE = [] include Aws::Structure end |