Class: Aws::GuardDuty::Types::Indicator
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::Indicator
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the indicators that include a set of signals observed in an attack sequence.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
Specific indicator keys observed in the attack sequence.
-
#title ⇒ String
Title describing the indicator.
-
#values ⇒ Array<String>
Values associated with each indicator key.
Instance Attribute Details
#key ⇒ String
Specific indicator keys observed in the attack sequence. For description of the valid values for key, see Attack sequence finding details in the Amazon GuardDuty User Guide.
6950 6951 6952 6953 6954 6955 6956 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6950 class Indicator < Struct.new( :key, :values, :title) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
Title describing the indicator.
6950 6951 6952 6953 6954 6955 6956 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6950 class Indicator < Struct.new( :key, :values, :title) SENSITIVE = [] include Aws::Structure end |
#values ⇒ Array<String>
Values associated with each indicator key. For example, if the
indicator key is SUSPICIOUS_NETWORK, then the value will be the
name of the network. If the indicator key is ATTACK_TACTIC, then
the value will be one of the MITRE tactics.
6950 6951 6952 6953 6954 6955 6956 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6950 class Indicator < Struct.new( :key, :values, :title) SENSITIVE = [] include Aws::Structure end |