Class: Aws::GuardDuty::Types::Indicator

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about the indicators that include a set of signals observed in an attack sequence.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#keyString

Specific indicator keys observed in the attack sequence. For description of the valid values for key, see Attack sequence finding details in the Amazon GuardDuty User Guide.

Returns:

  • (String)


6839
6840
6841
6842
6843
6844
6845
# File 'lib/aws-sdk-guardduty/types.rb', line 6839

class Indicator < Struct.new(
  :key,
  :values,
  :title)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

Title describing the indicator.

Returns:

  • (String)


6839
6840
6841
6842
6843
6844
6845
# File 'lib/aws-sdk-guardduty/types.rb', line 6839

class Indicator < Struct.new(
  :key,
  :values,
  :title)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<String>

Values associated with each indicator key. For example, if the indicator key is SUSPICIOUS_NETWORK, then the value will be the name of the network. If the indicator key is ATTACK_TACTIC, then the value will be one of the MITRE tactics.

Returns:

  • (Array<String>)


6839
6840
6841
6842
6843
6844
6845
# File 'lib/aws-sdk-guardduty/types.rb', line 6839

class Indicator < Struct.new(
  :key,
  :values,
  :title)
  SENSITIVE = []
  include Aws::Structure
end