Class: Aws::GuardDuty::Types::Investigation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains the details and results of a GuardDuty investigation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cloudTypes::CloudDetails

Details about the cloud environment in which the investigation was performed, including the provider, region, and account.

Returns:



7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-guardduty/types.rb', line 7004

class Investigation < Struct.new(
  :investigation_id,
  :status,
  :trigger_prompt,
  :triggered_by,
  :metadata,
  :cloud,
  :risk_level,
  :risk,
  :confidence,
  :summary,
  :start_time,
  :end_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#confidenceString

The confidence level of the investigation’s assessment. Possible values are ‘Unknown`, `Low`, `Medium`, and `High`.

Returns:

  • (String)


7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-guardduty/types.rb', line 7004

class Investigation < Struct.new(
  :investigation_id,
  :status,
  :trigger_prompt,
  :triggered_by,
  :metadata,
  :cloud,
  :risk_level,
  :risk,
  :confidence,
  :summary,
  :start_time,
  :end_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

The timestamp at which the investigation completed.

Returns:

  • (Time)


7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-guardduty/types.rb', line 7004

class Investigation < Struct.new(
  :investigation_id,
  :status,
  :trigger_prompt,
  :triggered_by,
  :metadata,
  :cloud,
  :risk_level,
  :risk,
  :confidence,
  :summary,
  :start_time,
  :end_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#errorString

Details about the error if the investigation status is ‘FAILED`.

Returns:

  • (String)


7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-guardduty/types.rb', line 7004

class Investigation < Struct.new(
  :investigation_id,
  :status,
  :trigger_prompt,
  :triggered_by,
  :metadata,
  :cloud,
  :risk_level,
  :risk,
  :confidence,
  :summary,
  :start_time,
  :end_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#investigation_idString

The unique identifier of the investigation.

Returns:

  • (String)


7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-guardduty/types.rb', line 7004

class Investigation < Struct.new(
  :investigation_id,
  :status,
  :trigger_prompt,
  :triggered_by,
  :metadata,
  :cloud,
  :risk_level,
  :risk,
  :confidence,
  :summary,
  :start_time,
  :end_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#metadataTypes::InvestigationMetadata

Metadata about the product and version that produced the investigation.



7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-guardduty/types.rb', line 7004

class Investigation < Struct.new(
  :investigation_id,
  :status,
  :trigger_prompt,
  :triggered_by,
  :metadata,
  :cloud,
  :risk_level,
  :risk,
  :confidence,
  :summary,
  :start_time,
  :end_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#riskString

A human-readable description of the assessed risk.

Returns:

  • (String)


7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-guardduty/types.rb', line 7004

class Investigation < Struct.new(
  :investigation_id,
  :status,
  :trigger_prompt,
  :triggered_by,
  :metadata,
  :cloud,
  :risk_level,
  :risk,
  :confidence,
  :summary,
  :start_time,
  :end_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#risk_levelString

The assessed risk level of the investigated threat. Possible values are ‘Info`, `Low`, `Medium`, `High`, and `Critical`.

Returns:

  • (String)


7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-guardduty/types.rb', line 7004

class Investigation < Struct.new(
  :investigation_id,
  :status,
  :trigger_prompt,
  :triggered_by,
  :metadata,
  :cloud,
  :risk_level,
  :risk,
  :confidence,
  :summary,
  :start_time,
  :end_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

The timestamp at which the investigation started.

Returns:

  • (Time)


7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-guardduty/types.rb', line 7004

class Investigation < Struct.new(
  :investigation_id,
  :status,
  :trigger_prompt,
  :triggered_by,
  :metadata,
  :cloud,
  :risk_level,
  :risk,
  :confidence,
  :summary,
  :start_time,
  :end_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the investigation. Possible values are ‘RUNNING`, `COMPLETED`, and `FAILED`.

Returns:

  • (String)


7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-guardduty/types.rb', line 7004

class Investigation < Struct.new(
  :investigation_id,
  :status,
  :trigger_prompt,
  :triggered_by,
  :metadata,
  :cloud,
  :risk_level,
  :risk,
  :confidence,
  :summary,
  :start_time,
  :end_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#summaryString

A structured summary of the investigation findings, including affected resources, threat assessment, and recommended remediation steps.

Returns:

  • (String)


7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-guardduty/types.rb', line 7004

class Investigation < Struct.new(
  :investigation_id,
  :status,
  :trigger_prompt,
  :triggered_by,
  :metadata,
  :cloud,
  :risk_level,
  :risk,
  :confidence,
  :summary,
  :start_time,
  :end_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#trigger_promptString

The natural-language prompt that initiated this investigation.

Returns:

  • (String)


7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-guardduty/types.rb', line 7004

class Investigation < Struct.new(
  :investigation_id,
  :status,
  :trigger_prompt,
  :triggered_by,
  :metadata,
  :cloud,
  :risk_level,
  :risk,
  :confidence,
  :summary,
  :start_time,
  :end_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#triggered_byString

The account that initiated the investigation.

Returns:

  • (String)


7004
7005
7006
7007
7008
7009
7010
7011
7012
7013
7014
7015
7016
7017
7018
7019
7020
# File 'lib/aws-sdk-guardduty/types.rb', line 7004

class Investigation < Struct.new(
  :investigation_id,
  :status,
  :trigger_prompt,
  :triggered_by,
  :metadata,
  :cloud,
  :risk_level,
  :risk,
  :confidence,
  :summary,
  :start_time,
  :end_time,
  :error)
  SENSITIVE = []
  include Aws::Structure
end