Class: Aws::GuardDuty::Types::InvestigationMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::InvestigationMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains metadata about the product and version that produced an investigation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#product ⇒ Types::Product
Information about the product that produced the investigation.
-
#version ⇒ String
The version of the investigation engine that produced the results.
Instance Attribute Details
#product ⇒ Types::Product
Information about the product that produced the investigation.
7035 7036 7037 7038 7039 7040 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7035 class InvestigationMetadata < Struct.new( :version, :product) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the investigation engine that produced the results.
7035 7036 7037 7038 7039 7040 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7035 class InvestigationMetadata < Struct.new( :version, :product) SENSITIVE = [] include Aws::Structure end |