Class: Aws::GuardDuty::Types::KubernetesApiCallAction
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::KubernetesApiCallAction
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Information about the Kubernetes API call action described in this finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#namespace ⇒ String
The name of the namespace where the Kubernetes API call action takes place.
-
#parameters ⇒ String
Parameters related to the Kubernetes API call action.
-
#remote_ip_details ⇒ Types::RemoteIpDetails
Contains information about the remote IP address of the connection.
-
#request_uri ⇒ String
The Kubernetes API request URI.
-
#resource ⇒ String
The resource component in the Kubernetes API call action.
-
#resource_name ⇒ String
The name of the resource in the Kubernetes API call action.
-
#source_ips ⇒ Array<String>
The IP of the Kubernetes API caller and the IPs of any proxies or load balancers between the caller and the API endpoint.
-
#status_code ⇒ Integer
The resulting HTTP response code of the Kubernetes API call action.
-
#subresource ⇒ String
The name of the sub-resource in the Kubernetes API call action.
-
#user_agent ⇒ String
The user agent of the caller of the Kubernetes API.
-
#verb ⇒ String
The Kubernetes API request HTTP verb.
Instance Attribute Details
#namespace ⇒ String
The name of the namespace where the Kubernetes API call action takes place.
7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7024 class KubernetesApiCallAction < Struct.new( :request_uri, :verb, :resource, :subresource, :namespace, :resource_name, :source_ips, :user_agent, :remote_ip_details, :status_code, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ String
Parameters related to the Kubernetes API call action.
7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7024 class KubernetesApiCallAction < Struct.new( :request_uri, :verb, :resource, :subresource, :namespace, :resource_name, :source_ips, :user_agent, :remote_ip_details, :status_code, :parameters) SENSITIVE = [] include Aws::Structure end |
#remote_ip_details ⇒ Types::RemoteIpDetails
Contains information about the remote IP address of the connection.
7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7024 class KubernetesApiCallAction < Struct.new( :request_uri, :verb, :resource, :subresource, :namespace, :resource_name, :source_ips, :user_agent, :remote_ip_details, :status_code, :parameters) SENSITIVE = [] include Aws::Structure end |
#request_uri ⇒ String
The Kubernetes API request URI.
7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7024 class KubernetesApiCallAction < Struct.new( :request_uri, :verb, :resource, :subresource, :namespace, :resource_name, :source_ips, :user_agent, :remote_ip_details, :status_code, :parameters) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ String
The resource component in the Kubernetes API call action.
7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7024 class KubernetesApiCallAction < Struct.new( :request_uri, :verb, :resource, :subresource, :namespace, :resource_name, :source_ips, :user_agent, :remote_ip_details, :status_code, :parameters) SENSITIVE = [] include Aws::Structure end |
#resource_name ⇒ String
The name of the resource in the Kubernetes API call action.
7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7024 class KubernetesApiCallAction < Struct.new( :request_uri, :verb, :resource, :subresource, :namespace, :resource_name, :source_ips, :user_agent, :remote_ip_details, :status_code, :parameters) SENSITIVE = [] include Aws::Structure end |
#source_ips ⇒ Array<String>
The IP of the Kubernetes API caller and the IPs of any proxies or load balancers between the caller and the API endpoint.
7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7024 class KubernetesApiCallAction < Struct.new( :request_uri, :verb, :resource, :subresource, :namespace, :resource_name, :source_ips, :user_agent, :remote_ip_details, :status_code, :parameters) SENSITIVE = [] include Aws::Structure end |
#status_code ⇒ Integer
The resulting HTTP response code of the Kubernetes API call action.
7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7024 class KubernetesApiCallAction < Struct.new( :request_uri, :verb, :resource, :subresource, :namespace, :resource_name, :source_ips, :user_agent, :remote_ip_details, :status_code, :parameters) SENSITIVE = [] include Aws::Structure end |
#subresource ⇒ String
The name of the sub-resource in the Kubernetes API call action.
7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7024 class KubernetesApiCallAction < Struct.new( :request_uri, :verb, :resource, :subresource, :namespace, :resource_name, :source_ips, :user_agent, :remote_ip_details, :status_code, :parameters) SENSITIVE = [] include Aws::Structure end |
#user_agent ⇒ String
The user agent of the caller of the Kubernetes API.
7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7024 class KubernetesApiCallAction < Struct.new( :request_uri, :verb, :resource, :subresource, :namespace, :resource_name, :source_ips, :user_agent, :remote_ip_details, :status_code, :parameters) SENSITIVE = [] include Aws::Structure end |
#verb ⇒ String
The Kubernetes API request HTTP verb.
7024 7025 7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 7036 7037 7038 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7024 class KubernetesApiCallAction < Struct.new( :request_uri, :verb, :resource, :subresource, :namespace, :resource_name, :source_ips, :user_agent, :remote_ip_details, :status_code, :parameters) SENSITIVE = [] include Aws::Structure end |