Class: Aws::GuardDuty::Types::KubernetesPermissionCheckedDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Information about the Kubernetes API for which you check if you have permission to call.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowedBoolean

Information whether the user has the permission to call the Kubernetes API.

Returns:

  • (Boolean)


7527
7528
7529
7530
7531
7532
7533
7534
# File 'lib/aws-sdk-guardduty/types.rb', line 7527

class KubernetesPermissionCheckedDetails < Struct.new(
  :verb,
  :resource,
  :namespace,
  :allowed)
  SENSITIVE = []
  include Aws::Structure
end

#namespaceString

The namespace where the Kubernetes API action will take place.

Returns:

  • (String)


7527
7528
7529
7530
7531
7532
7533
7534
# File 'lib/aws-sdk-guardduty/types.rb', line 7527

class KubernetesPermissionCheckedDetails < Struct.new(
  :verb,
  :resource,
  :namespace,
  :allowed)
  SENSITIVE = []
  include Aws::Structure
end

#resourceString

The Kubernetes resource with which your Kubernetes API call will interact.

Returns:

  • (String)


7527
7528
7529
7530
7531
7532
7533
7534
# File 'lib/aws-sdk-guardduty/types.rb', line 7527

class KubernetesPermissionCheckedDetails < Struct.new(
  :verb,
  :resource,
  :namespace,
  :allowed)
  SENSITIVE = []
  include Aws::Structure
end

#verbString

The verb component of the Kubernetes API call. For example, when you check whether or not you have the permission to call the CreatePod API, the verb component will be Create.

Returns:

  • (String)


7527
7528
7529
7530
7531
7532
7533
7534
# File 'lib/aws-sdk-guardduty/types.rb', line 7527

class KubernetesPermissionCheckedDetails < Struct.new(
  :verb,
  :resource,
  :namespace,
  :allowed)
  SENSITIVE = []
  include Aws::Structure
end