Class: Aws::GuardDuty::Types::KubernetesPermissionCheckedDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::KubernetesPermissionCheckedDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Information about the Kubernetes API for which you check if you have permission to call.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed ⇒ Boolean
Information whether the user has the permission to call the Kubernetes API.
-
#namespace ⇒ String
The namespace where the Kubernetes API action will take place.
-
#resource ⇒ String
The Kubernetes resource with which your Kubernetes API call will interact.
-
#verb ⇒ String
The verb component of the Kubernetes API call.
Instance Attribute Details
#allowed ⇒ Boolean
Information whether the user has the permission to call the Kubernetes API.
8044 8045 8046 8047 8048 8049 8050 8051 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8044 class KubernetesPermissionCheckedDetails < Struct.new( :verb, :resource, :namespace, :allowed) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace where the Kubernetes API action will take place.
8044 8045 8046 8047 8048 8049 8050 8051 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8044 class KubernetesPermissionCheckedDetails < Struct.new( :verb, :resource, :namespace, :allowed) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ String
The Kubernetes resource with which your Kubernetes API call will interact.
8044 8045 8046 8047 8048 8049 8050 8051 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8044 class KubernetesPermissionCheckedDetails < Struct.new( :verb, :resource, :namespace, :allowed) SENSITIVE = [] include Aws::Structure end |
#verb ⇒ String
The verb component of the Kubernetes API call. For example, when you
check whether or not you have the permission to call the CreatePod
API, the verb component will be Create.
8044 8045 8046 8047 8048 8049 8050 8051 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8044 class KubernetesPermissionCheckedDetails < Struct.new( :verb, :resource, :namespace, :allowed) SENSITIVE = [] include Aws::Structure end |