Class: Aws::GuardDuty::Types::ListCoverageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ListCoverageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector whose coverage details you want to retrieve.
-
#filter_criteria ⇒ Types::CoverageFilterCriteria
Represents the criteria used to filter the coverage details.
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
A token to use for paginating results that are returned in the response.
-
#sort_criteria ⇒ Types::CoverageSortCriteria
Represents the criteria used to sort the coverage details.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector whose coverage details you want to retrieve.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
8386 8387 8388 8389 8390 8391 8392 8393 8394 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8386 class ListCoverageRequest < Struct.new( :detector_id, :next_token, :max_results, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#filter_criteria ⇒ Types::CoverageFilterCriteria
Represents the criteria used to filter the coverage details.
8386 8387 8388 8389 8390 8391 8392 8393 8394 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8386 class ListCoverageRequest < Struct.new( :detector_id, :next_token, :max_results, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in the response.
8386 8387 8388 8389 8390 8391 8392 8393 8394 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8386 class ListCoverageRequest < Struct.new( :detector_id, :next_token, :max_results, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.
8386 8387 8388 8389 8390 8391 8392 8393 8394 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8386 class ListCoverageRequest < Struct.new( :detector_id, :next_token, :max_results, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#sort_criteria ⇒ Types::CoverageSortCriteria
Represents the criteria used to sort the coverage details.
8386 8387 8388 8389 8390 8391 8392 8393 8394 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8386 class ListCoverageRequest < Struct.new( :detector_id, :next_token, :max_results, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |