Class: Aws::GuardDuty::Types::ListCoverageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The unique ID of the detector whose coverage details you want to retrieve.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

Returns:

  • (String)


6328
6329
6330
6331
6332
6333
6334
6335
6336
# File 'lib/aws-sdk-guardduty/types.rb', line 6328

class ListCoverageRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#filter_criteriaTypes::CoverageFilterCriteria

Represents the criteria used to filter the coverage details.



6328
6329
6330
6331
6332
6333
6334
6335
6336
# File 'lib/aws-sdk-guardduty/types.rb', line 6328

class ListCoverageRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in the response.

Returns:

  • (Integer)


6328
6329
6330
6331
6332
6333
6334
6335
6336
# File 'lib/aws-sdk-guardduty/types.rb', line 6328

class ListCoverageRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page.

Returns:

  • (String)


6328
6329
6330
6331
6332
6333
6334
6335
6336
# File 'lib/aws-sdk-guardduty/types.rb', line 6328

class ListCoverageRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#sort_criteriaTypes::CoverageSortCriteria

Represents the criteria used to sort the coverage details.



6328
6329
6330
6331
6332
6333
6334
6335
6336
# File 'lib/aws-sdk-guardduty/types.rb', line 6328

class ListCoverageRequest < Struct.new(
  :detector_id,
  :next_token,
  :max_results,
  :filter_criteria,
  :sort_criteria)
  SENSITIVE = []
  include Aws::Structure
end