Class: Aws::GuardDuty::Types::ListCustomDetectionRuleAssociationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ListCustomDetectionRuleAssociationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A pagination token to retrieve the next page of results.
-
#rule_associations ⇒ Array<Types::AssociationSummary>
A list of custom detection rule association summaries.
Instance Attribute Details
#next_token ⇒ String
A pagination token to retrieve the next page of results. If this field is empty, there are no additional results.
8455 8456 8457 8458 8459 8460 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8455 class ListCustomDetectionRuleAssociationsResponse < Struct.new( :rule_associations, :next_token) SENSITIVE = [] include Aws::Structure end |
#rule_associations ⇒ Array<Types::AssociationSummary>
A list of custom detection rule association summaries.
8455 8456 8457 8458 8459 8460 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8455 class ListCustomDetectionRuleAssociationsResponse < Struct.new( :rule_associations, :next_token) SENSITIVE = [] include Aws::Structure end |