Class: Aws::GuardDuty::Types::ListCustomDetectionRuleOrgConfigurationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ListCustomDetectionRuleOrgConfigurationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in a single page.
-
#next_token ⇒ String
A pagination token from a previous response.
-
#status ⇒ String
The configuration status to filter by.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in a single page. Minimum value of 1, maximum value of 100.
8478 8479 8480 8481 8482 8483 8484 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8478 class ListCustomDetectionRuleOrgConfigurationsRequest < Struct.new( :max_results, :next_token, :status) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token from a previous response. Use this token to retrieve the next page of results.
8478 8479 8480 8481 8482 8483 8484 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8478 class ListCustomDetectionRuleOrgConfigurationsRequest < Struct.new( :max_results, :next_token, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The configuration status to filter by.
8478 8479 8480 8481 8482 8483 8484 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8478 class ListCustomDetectionRuleOrgConfigurationsRequest < Struct.new( :max_results, :next_token, :status) SENSITIVE = [] include Aws::Structure end |