Class: Aws::GuardDuty::Types::ListCustomDetectionRuleOrgConfigurationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ListCustomDetectionRuleOrgConfigurationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configurations ⇒ Array<Types::DetectionRuleOrgConfigurationSummary>
A list of organization configurations for custom detection rules.
-
#next_token ⇒ String
A pagination token to retrieve the next page of results.
Instance Attribute Details
#configurations ⇒ Array<Types::DetectionRuleOrgConfigurationSummary>
A list of organization configurations for custom detection rules.
8497 8498 8499 8500 8501 8502 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8497 class ListCustomDetectionRuleOrgConfigurationsResponse < Struct.new( :configurations, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A pagination token to retrieve the next page of results. If this field is empty, there are no additional results.
8497 8498 8499 8500 8501 8502 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8497 class ListCustomDetectionRuleOrgConfigurationsResponse < Struct.new( :configurations, :next_token) SENSITIVE = [] include Aws::Structure end |