Class: Aws::GuardDuty::Types::ListCustomDetectionRulesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ListCustomDetectionRulesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A pagination token to retrieve the next page of results.
-
#rules ⇒ Array<Types::RuleSummary>
A list of custom detection rule summaries.
Instance Attribute Details
#next_token ⇒ String
A pagination token to retrieve the next page of results. If this field is empty, there are no additional results.
8540 8541 8542 8543 8544 8545 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8540 class ListCustomDetectionRulesResponse < Struct.new( :rules, :next_token) SENSITIVE = [] include Aws::Structure end |
#rules ⇒ Array<Types::RuleSummary>
A list of custom detection rule summaries.
8540 8541 8542 8543 8544 8545 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8540 class ListCustomDetectionRulesResponse < Struct.new( :rules, :next_token) SENSITIVE = [] include Aws::Structure end |