Class: Aws::GuardDuty::Types::ListInvestigationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ListInvestigationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#investigations ⇒ Array<Types::InvestigationSummary>
A list of investigation summaries associated with the specified detector.
-
#next_token ⇒ String
The pagination parameter to be used on the next list operation to retrieve more items.
Instance Attribute Details
#investigations ⇒ Array<Types::InvestigationSummary>
A list of investigation summaries associated with the specified detector.
8918 8919 8920 8921 8922 8923 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8918 class ListInvestigationsResponse < Struct.new( :investigations, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination parameter to be used on the next list operation to retrieve more items.
8918 8919 8920 8921 8922 8923 |
# File 'lib/aws-sdk-guardduty/types.rb', line 8918 class ListInvestigationsResponse < Struct.new( :investigations, :next_token) SENSITIVE = [] include Aws::Structure end |