Class: Aws::GuardDuty::Types::ListMalwareProtectionPlansRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ListMalwareProtectionPlansRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
You can use this parameter when paginating results.
Instance Attribute Details
#next_token ⇒ String
You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data. The default page size is 100 plans.
6726 6727 6728 6729 6730 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6726 class ListMalwareProtectionPlansRequest < Struct.new( :next_token) SENSITIVE = [] include Aws::Structure end |