Class: Aws::GuardDuty::Types::ListMalwareScansRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ListMalwareScansRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter_criteria ⇒ Types::ListMalwareScansFilterCriteria
Represents the criteria used to filter the malware scan entries.
-
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items that you want in the response.
-
#next_token ⇒ String
You can use this parameter when paginating results.
-
#sort_criteria ⇒ Types::SortCriteria
Represents the criteria used for sorting malware scan entries.
Instance Attribute Details
#filter_criteria ⇒ Types::ListMalwareScansFilterCriteria
Represents the criteria used to filter the malware scan entries.
6817 6818 6819 6820 6821 6822 6823 6824 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6817 class ListMalwareScansRequest < Struct.new( :max_results, :next_token, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50.
6817 6818 6819 6820 6821 6822 6823 6824 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6817 class ListMalwareScansRequest < Struct.new( :max_results, :next_token, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
You can use this parameter when paginating results. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing results.
6817 6818 6819 6820 6821 6822 6823 6824 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6817 class ListMalwareScansRequest < Struct.new( :max_results, :next_token, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |
#sort_criteria ⇒ Types::SortCriteria
Represents the criteria used for sorting malware scan entries.
6817 6818 6819 6820 6821 6822 6823 6824 |
# File 'lib/aws-sdk-guardduty/types.rb', line 6817 class ListMalwareScansRequest < Struct.new( :max_results, :next_token, :filter_criteria, :sort_criteria) SENSITIVE = [] include Aws::Structure end |