Class: Aws::GuardDuty::Types::ListThreatIntelSetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ListThreatIntelSetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The unique ID of the detector that is associated with the threatIntelSet.
-
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items that you want in the response.
-
#next_token ⇒ String
You can use this parameter to paginate results in the response.
Instance Attribute Details
#detector_id ⇒ String
The unique ID of the detector that is associated with the threatIntelSet.
To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
7116 7117 7118 7119 7120 7121 7122 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7116 class ListThreatIntelSetsRequest < Struct.new( :detector_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
You can use this parameter to indicate the maximum number of items that you want in the response. The default value is 50. The maximum value is 50.
7116 7117 7118 7119 7120 7121 7122 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7116 class ListThreatIntelSetsRequest < Struct.new( :detector_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
You can use this parameter to paginate results in the response. Set the value of this parameter to null on your first call to the list action. For subsequent calls to the action, fill nextToken in the request with the value of NextToken from the previous response to continue listing data.
7116 7117 7118 7119 7120 7121 7122 |
# File 'lib/aws-sdk-guardduty/types.rb', line 7116 class ListThreatIntelSetsRequest < Struct.new( :detector_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |