Class: Aws::GuardDuty::Types::Product
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::Product
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the product that produced an investigation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#feature ⇒ String
The specific feature within the product that produced the investigation.
-
#name ⇒ String
The name of the product.