Class: Aws::GuardDuty::Types::ResourceData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about the Amazon Web Services resource that is associated with the activity that prompted GuardDuty to generate a finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_keyTypes::AccessKey

Contains information about the IAM access key details of a user that involved in the GuardDuty finding.

Returns:



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#autoscaling_auto_scaling_groupTypes::AutoscalingAutoScalingGroup

Contains detailed information about the Auto Scaling Group associated with the activity that prompted GuardDuty to generate a finding.



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#cloudformation_stackTypes::CloudformationStack

Contains detailed information about the CloudFormation stack associated with the activity that prompted GuardDuty to generate a finding.



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#containerTypes::ContainerFindingResource

Contains detailed information about the container associated with the activity that prompted GuardDuty to generate a finding.



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_imageTypes::Ec2Image

Contains detailed information about the EC2 Image associated with the activity that prompted GuardDuty to generate a finding.

Returns:



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_instanceTypes::Ec2Instance

Contains information about the Amazon EC2 instance.

Returns:



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_launch_templateTypes::Ec2LaunchTemplate

Contains detailed information about the EC2 launch template associated with the activity that prompted GuardDuty to generate a finding.



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_network_interfaceTypes::Ec2NetworkInterface

Contains information about the elastic network interface of the Amazon EC2 instance.



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_vpcTypes::Ec2Vpc

Contains detailed information about the EC2 VPC associated with the activity that prompted GuardDuty to generate a finding.

Returns:



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#ecs_clusterTypes::EcsCluster

Contains detailed information about the Amazon ECS cluster associated with the activity that prompted GuardDuty to generate a finding.

Returns:



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#ecs_taskTypes::EcsTask

Contains detailed information about the Amazon ECS task associated with the activity that prompted GuardDuty to generate a finding.

Returns:



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#eks_clusterTypes::EksCluster

Contains detailed information about the Amazon EKS cluster associated with the activity that prompted GuardDuty to generate a finding.

Returns:



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#iam_instance_profileTypes::IamInstanceProfileV2

Contains detailed information about the IAM instance profile associated with the activity that prompted GuardDuty to generate a finding.



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#kubernetes_workloadTypes::KubernetesWorkload

Contains detailed information about the Kubernetes workload associated with the activity that prompted GuardDuty to generate a finding.



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucketTypes::S3Bucket

Contains information about the Amazon S3 bucket.

Returns:



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end

#s3_objectTypes::S3Object

Contains information about the Amazon S3 object.

Returns:



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
10381
10382
10383
10384
10385
10386
10387
10388
10389
# File 'lib/aws-sdk-guardduty/types.rb', line 10370

class ResourceData < Struct.new(
  :s3_bucket,
  :ec2_instance,
  :access_key,
  :ec2_network_interface,
  :s3_object,
  :eks_cluster,
  :kubernetes_workload,
  :container,
  :ecs_cluster,
  :ecs_task,
  :iam_instance_profile,
  :autoscaling_auto_scaling_group,
  :ec2_launch_template,
  :ec2_vpc,
  :ec2_image,
  :cloudformation_stack)
  SENSITIVE = []
  include Aws::Structure
end