Class: Aws::GuardDuty::Types::ResourceData
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ResourceData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the Amazon Web Services resource that is associated with the activity that prompted GuardDuty to generate a finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_key ⇒ Types::AccessKey
Contains information about the IAM access key details of a user that involved in the GuardDuty finding.
-
#autoscaling_auto_scaling_group ⇒ Types::AutoscalingAutoScalingGroup
Contains detailed information about the Auto Scaling Group associated with the activity that prompted GuardDuty to generate a finding.
-
#cloudformation_stack ⇒ Types::CloudformationStack
Contains detailed information about the CloudFormation stack associated with the activity that prompted GuardDuty to generate a finding.
-
#container ⇒ Types::ContainerFindingResource
Contains detailed information about the container associated with the activity that prompted GuardDuty to generate a finding.
-
#ec2_image ⇒ Types::Ec2Image
Contains detailed information about the EC2 Image associated with the activity that prompted GuardDuty to generate a finding.
-
#ec2_instance ⇒ Types::Ec2Instance
Contains information about the Amazon EC2 instance.
-
#ec2_launch_template ⇒ Types::Ec2LaunchTemplate
Contains detailed information about the EC2 launch template associated with the activity that prompted GuardDuty to generate a finding.
-
#ec2_network_interface ⇒ Types::Ec2NetworkInterface
Contains information about the elastic network interface of the Amazon EC2 instance.
-
#ec2_vpc ⇒ Types::Ec2Vpc
Contains detailed information about the EC2 VPC associated with the activity that prompted GuardDuty to generate a finding.
-
#ecs_cluster ⇒ Types::EcsCluster
Contains detailed information about the Amazon ECS cluster associated with the activity that prompted GuardDuty to generate a finding.
-
#ecs_task ⇒ Types::EcsTask
Contains detailed information about the Amazon ECS task associated with the activity that prompted GuardDuty to generate a finding.
-
#eks_cluster ⇒ Types::EksCluster
Contains detailed information about the Amazon EKS cluster associated with the activity that prompted GuardDuty to generate a finding.
-
#iam_instance_profile ⇒ Types::IamInstanceProfileV2
Contains detailed information about the IAM instance profile associated with the activity that prompted GuardDuty to generate a finding.
-
#kubernetes_workload ⇒ Types::KubernetesWorkload
Contains detailed information about the Kubernetes workload associated with the activity that prompted GuardDuty to generate a finding.
-
#s3_bucket ⇒ Types::S3Bucket
Contains information about the Amazon S3 bucket.
-
#s3_object ⇒ Types::S3Object
Contains information about the Amazon S3 object.
Instance Attribute Details
#access_key ⇒ Types::AccessKey
Contains information about the IAM access key details of a user that involved in the GuardDuty finding.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#autoscaling_auto_scaling_group ⇒ Types::AutoscalingAutoScalingGroup
Contains detailed information about the Auto Scaling Group associated with the activity that prompted GuardDuty to generate a finding.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#cloudformation_stack ⇒ Types::CloudformationStack
Contains detailed information about the CloudFormation stack associated with the activity that prompted GuardDuty to generate a finding.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#container ⇒ Types::ContainerFindingResource
Contains detailed information about the container associated with the activity that prompted GuardDuty to generate a finding.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#ec2_image ⇒ Types::Ec2Image
Contains detailed information about the EC2 Image associated with the activity that prompted GuardDuty to generate a finding.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#ec2_instance ⇒ Types::Ec2Instance
Contains information about the Amazon EC2 instance.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#ec2_launch_template ⇒ Types::Ec2LaunchTemplate
Contains detailed information about the EC2 launch template associated with the activity that prompted GuardDuty to generate a finding.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#ec2_network_interface ⇒ Types::Ec2NetworkInterface
Contains information about the elastic network interface of the Amazon EC2 instance.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#ec2_vpc ⇒ Types::Ec2Vpc
Contains detailed information about the EC2 VPC associated with the activity that prompted GuardDuty to generate a finding.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#ecs_cluster ⇒ Types::EcsCluster
Contains detailed information about the Amazon ECS cluster associated with the activity that prompted GuardDuty to generate a finding.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#ecs_task ⇒ Types::EcsTask
Contains detailed information about the Amazon ECS task associated with the activity that prompted GuardDuty to generate a finding.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#eks_cluster ⇒ Types::EksCluster
Contains detailed information about the Amazon EKS cluster associated with the activity that prompted GuardDuty to generate a finding.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#iam_instance_profile ⇒ Types::IamInstanceProfileV2
Contains detailed information about the IAM instance profile associated with the activity that prompted GuardDuty to generate a finding.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#kubernetes_workload ⇒ Types::KubernetesWorkload
Contains detailed information about the Kubernetes workload associated with the activity that prompted GuardDuty to generate a finding.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#s3_bucket ⇒ Types::S3Bucket
Contains information about the Amazon S3 bucket.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |
#s3_object ⇒ Types::S3Object
Contains information about the Amazon S3 object.
10370 10371 10372 10373 10374 10375 10376 10377 10378 10379 10380 10381 10382 10383 10384 10385 10386 10387 10388 10389 |
# File 'lib/aws-sdk-guardduty/types.rb', line 10370 class ResourceData < Struct.new( :s3_bucket, :ec2_instance, :access_key, :ec2_network_interface, :s3_object, :eks_cluster, :kubernetes_workload, :container, :ecs_cluster, :ecs_task, :iam_instance_profile, :autoscaling_auto_scaling_group, :ec2_launch_template, :ec2_vpc, :ec2_image, :cloudformation_stack) SENSITIVE = [] include Aws::Structure end |