Class: Aws::GuardDuty::Types::RuntimeContext

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Additional information about the suspicious activity.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#address_familyString

Represents the communication protocol associated with the address. For example, the address family ‘AF_INET` is used for IP version of 4 protocol.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#command_line_exampleString

Example of the command line involved in the suspicious activity.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#file_operationString

Represents the type of file operation that triggered the finding, such as Write, Delete, Rename, Link, or Symlink.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#file_pathString

The path of the sensitive file that was modified. Modification includes write, delete, rename, link, or symlink operations. This field is indexed for filtering.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#file_system_typeString

Represents the type of mounted fileSystem.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#flagsArray<String>

Represents options that control the behavior of a runtime operation or action. For example, a filesystem mount operation may contain a read-only flag.

Returns:

  • (Array<String>)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#iana_protocol_numberInteger

Specifies a particular protocol within the address family. Usually there is a single protocol in address families. For example, the address family ‘AF_INET` only has the IP protocol.

Returns:

  • (Integer)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#ld_preload_valueString

The value of the LD_PRELOAD environment variable.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#library_pathString

The path to the new library that was loaded.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#memory_regionsArray<String>

Specifies the Region of a process’s address space such as stack and heap.

Returns:

  • (Array<String>)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#modified_atTime

The timestamp at which the process modified the current process. The timestamp is in UTC date string format.

Returns:

  • (Time)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#modifying_processTypes::ProcessDetails

Information about the process that modified the current process. This is available for multiple finding types.



10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#module_file_pathString

The path to the module loaded into the kernel.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#module_nameString

The name of the module loaded into the kernel.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#module_sha_256String

The ‘SHA256` hash of the module.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#mount_sourceString

The path on the host that is mounted by the container.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#mount_targetString

The path in the container that is mapped to the host directory.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

All file paths modified by the same process that triggered the finding, up to a maximum of 25 paths.

Returns:

  • (Array<String>)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#release_agent_pathString

The path in the container that modified the release agent file.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#runc_binary_pathString

The path to the leveraged ‘runc` implementation.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#script_pathString

The path to the script that was executed.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#service_nameString

Name of the security service that has been potentially disabled.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#shell_history_file_pathString

The path to the modified shell history file.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#socket_pathString

The path to the docket socket that was accessed.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#target_processTypes::ProcessDetails

Information about the process that had its memory overwritten by the current process.



10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#threat_file_pathString

The suspicious file path for which the threat intelligence details were found.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#tool_categoryString

Category that the tool belongs to. Some of the examples are Backdoor Tool, Pentest Tool, Network Scanner, and Network Sniffer.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end

#tool_nameString

Name of the potentially suspicious tool.

Returns:

  • (String)


10661
10662
10663
10664
10665
10666
10667
10668
10669
10670
10671
10672
10673
10674
10675
10676
10677
10678
10679
10680
10681
10682
10683
10684
10685
10686
10687
10688
10689
10690
10691
10692
# File 'lib/aws-sdk-guardduty/types.rb', line 10661

class RuntimeContext < Struct.new(
  :modifying_process,
  :modified_at,
  :script_path,
  :library_path,
  :ld_preload_value,
  :socket_path,
  :runc_binary_path,
  :release_agent_path,
  :mount_source,
  :mount_target,
  :file_system_type,
  :flags,
  :module_name,
  :module_file_path,
  :module_sha_256,
  :shell_history_file_path,
  :target_process,
  :address_family,
  :iana_protocol_number,
  :memory_regions,
  :tool_name,
  :tool_category,
  :service_name,
  :command_line_example,
  :threat_file_path,
  :file_operation,
  :file_path,
  :related_file_paths)
  SENSITIVE = []
  include Aws::Structure
end