Class: Aws::GuardDuty::Types::S3ObjectForSendObjectMalwareScan
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::S3ObjectForSendObjectMalwareScan
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
The S3 object path to initiate a scan, including bucket name, object key, and optional version ID.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bucket ⇒ String
The name of the S3 bucket containing the object to scan.
-
#key ⇒ String
The key (name) of the S3 object to scan for malware.
-
#version_id ⇒ String
The version ID of the S3 object to scan.
Instance Attribute Details
#bucket ⇒ String
The name of the S3 bucket containing the object to scan. The bucket must have GuardDuty Malware Protection enabled.
11319 11320 11321 11322 11323 11324 11325 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11319 class S3ObjectForSendObjectMalwareScan < Struct.new( :bucket, :key, :version_id) SENSITIVE = [] include Aws::Structure end |
#key ⇒ String
The key (name) of the S3 object to scan for malware. This must be the full key path of the object within the bucket.
11319 11320 11321 11322 11323 11324 11325 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11319 class S3ObjectForSendObjectMalwareScan < Struct.new( :bucket, :key, :version_id) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The version ID of the S3 object to scan. If not specified, the latest version of the object is scanned.
11319 11320 11321 11322 11323 11324 11325 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11319 class S3ObjectForSendObjectMalwareScan < Struct.new( :bucket, :key, :version_id) SENSITIVE = [] include Aws::Structure end |