Class: Aws::GuardDuty::Types::ScanConfigurationRecoveryPoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::ScanConfigurationRecoveryPoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the recovery point configuration used in the scan.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_name ⇒ String
The name of the Amazon Web Services Backup vault that contains the recovery point for the scanned.
-
#continuous_scan_details ⇒ Types::ScanConfigurationContinuousScanDetails
The time range within the continuous backup in Amazon Web Services Backup that was scanned for a point-in-time recovery resource.
Instance Attribute Details
#backup_vault_name ⇒ String
The name of the Amazon Web Services Backup vault that contains the recovery point for the scanned.
11160 11161 11162 11163 11164 11165 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11160 class ScanConfigurationRecoveryPoint < Struct.new( :backup_vault_name, :continuous_scan_details) SENSITIVE = [] include Aws::Structure end |
#continuous_scan_details ⇒ Types::ScanConfigurationContinuousScanDetails
The time range within the continuous backup in Amazon Web Services Backup that was scanned for a point-in-time recovery resource.
11160 11161 11162 11163 11164 11165 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11160 class ScanConfigurationRecoveryPoint < Struct.new( :backup_vault_name, :continuous_scan_details) SENSITIVE = [] include Aws::Structure end |