Class: Aws::GuardDuty::Types::Sequence
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::Sequence
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the GuardDuty attack sequence finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actors ⇒ Array<Types::Actor>
Contains information about the actors involved in the attack sequence.
-
#additional_sequence_types ⇒ Array<String>
Additional types of sequences that may be associated with the attack sequence finding, providing further context about the nature of the detected threat.
-
#description ⇒ String
Description of the attack sequence.
-
#endpoints ⇒ Array<Types::NetworkEndpoint>
Contains information about the network endpoints that were used in the attack sequence.
-
#resources ⇒ Array<Types::ResourceV2>
Contains information about the resources involved in the attack sequence.
-
#sequence_indicators ⇒ Array<Types::Indicator>
Contains information about the indicators observed in the attack sequence.
-
#signals ⇒ Array<Types::Signal>
Contains information about the signals involved in the attack sequence.
-
#uid ⇒ String
Unique identifier of the attack sequence.
Instance Attribute Details
#actors ⇒ Array<Types::Actor>
Contains information about the actors involved in the attack sequence.
11558 11559 11560 11561 11562 11563 11564 11565 11566 11567 11568 11569 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11558 class Sequence < Struct.new( :uid, :description, :actors, :resources, :endpoints, :signals, :sequence_indicators, :additional_sequence_types) SENSITIVE = [] include Aws::Structure end |
#additional_sequence_types ⇒ Array<String>
Additional types of sequences that may be associated with the attack sequence finding, providing further context about the nature of the detected threat.
11558 11559 11560 11561 11562 11563 11564 11565 11566 11567 11568 11569 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11558 class Sequence < Struct.new( :uid, :description, :actors, :resources, :endpoints, :signals, :sequence_indicators, :additional_sequence_types) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description of the attack sequence.
11558 11559 11560 11561 11562 11563 11564 11565 11566 11567 11568 11569 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11558 class Sequence < Struct.new( :uid, :description, :actors, :resources, :endpoints, :signals, :sequence_indicators, :additional_sequence_types) SENSITIVE = [] include Aws::Structure end |
#endpoints ⇒ Array<Types::NetworkEndpoint>
Contains information about the network endpoints that were used in the attack sequence.
11558 11559 11560 11561 11562 11563 11564 11565 11566 11567 11568 11569 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11558 class Sequence < Struct.new( :uid, :description, :actors, :resources, :endpoints, :signals, :sequence_indicators, :additional_sequence_types) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<Types::ResourceV2>
Contains information about the resources involved in the attack sequence.
11558 11559 11560 11561 11562 11563 11564 11565 11566 11567 11568 11569 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11558 class Sequence < Struct.new( :uid, :description, :actors, :resources, :endpoints, :signals, :sequence_indicators, :additional_sequence_types) SENSITIVE = [] include Aws::Structure end |
#sequence_indicators ⇒ Array<Types::Indicator>
Contains information about the indicators observed in the attack sequence.
11558 11559 11560 11561 11562 11563 11564 11565 11566 11567 11568 11569 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11558 class Sequence < Struct.new( :uid, :description, :actors, :resources, :endpoints, :signals, :sequence_indicators, :additional_sequence_types) SENSITIVE = [] include Aws::Structure end |
#signals ⇒ Array<Types::Signal>
Contains information about the signals involved in the attack sequence.
11558 11559 11560 11561 11562 11563 11564 11565 11566 11567 11568 11569 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11558 class Sequence < Struct.new( :uid, :description, :actors, :resources, :endpoints, :signals, :sequence_indicators, :additional_sequence_types) SENSITIVE = [] include Aws::Structure end |
#uid ⇒ String
Unique identifier of the attack sequence.
11558 11559 11560 11561 11562 11563 11564 11565 11566 11567 11568 11569 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11558 class Sequence < Struct.new( :uid, :description, :actors, :resources, :endpoints, :signals, :sequence_indicators, :additional_sequence_types) SENSITIVE = [] include Aws::Structure end |