Class: Aws::GuardDuty::Types::Service
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::Service
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains additional information about the generated finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ Types::Action
Information about the activity that is described in a finding.
-
#additional_info ⇒ Types::ServiceAdditionalInfo
Contains additional information about the generated finding.
-
#archived ⇒ Boolean
Indicates whether this finding is archived.
-
#count ⇒ Integer
The total count of the occurrences of this finding type.
-
#detection ⇒ Types::Detection
Contains information about the detected unusual behavior.
-
#detector_id ⇒ String
The detector ID for the GuardDuty service.
-
#ebs_volume_scan_details ⇒ Types::EbsVolumeScanDetails
Returns details from the malware scan that created a finding.
-
#event_first_seen ⇒ String
The first-seen timestamp of the activity that prompted GuardDuty to generate this finding.
-
#event_last_seen ⇒ String
The last-seen timestamp of the activity that prompted GuardDuty to generate this finding.
-
#evidence ⇒ Types::Evidence
An evidence object associated with the service.
-
#feature_name ⇒ String
The name of the feature that generated a finding.
-
#malware_scan_details ⇒ Types::MalwareScanDetails
Returns details from the malware scan that generated a GuardDuty finding.
-
#resource_role ⇒ String
The resource role information for this finding.
-
#runtime_details ⇒ Types::RuntimeDetails
Information about the process and any required context values for a specific finding.
-
#service_name ⇒ String
The name of the Amazon Web Services service (GuardDuty) that generated a finding.
-
#user_feedback ⇒ String
Feedback that was submitted about the finding.
Instance Attribute Details
#action ⇒ Types::Action
Information about the activity that is described in a finding.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#additional_info ⇒ Types::ServiceAdditionalInfo
Contains additional information about the generated finding.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#archived ⇒ Boolean
Indicates whether this finding is archived.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#count ⇒ Integer
The total count of the occurrences of this finding type.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#detection ⇒ Types::Detection
Contains information about the detected unusual behavior.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The detector ID for the GuardDuty service.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#ebs_volume_scan_details ⇒ Types::EbsVolumeScanDetails
Returns details from the malware scan that created a finding.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#event_first_seen ⇒ String
The first-seen timestamp of the activity that prompted GuardDuty to generate this finding.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#event_last_seen ⇒ String
The last-seen timestamp of the activity that prompted GuardDuty to generate this finding.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#evidence ⇒ Types::Evidence
An evidence object associated with the service.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#feature_name ⇒ String
The name of the feature that generated a finding.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#malware_scan_details ⇒ Types::MalwareScanDetails
Returns details from the malware scan that generated a GuardDuty finding.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#resource_role ⇒ String
The resource role information for this finding.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#runtime_details ⇒ Types::RuntimeDetails
Information about the process and any required context values for a specific finding
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#service_name ⇒ String
The name of the Amazon Web Services service (GuardDuty) that generated a finding.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |
#user_feedback ⇒ String
Feedback that was submitted about the finding.
11644 11645 11646 11647 11648 11649 11650 11651 11652 11653 11654 11655 11656 11657 11658 11659 11660 11661 11662 11663 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11644 class Service < Struct.new( :action, :evidence, :archived, :count, :detector_id, :event_first_seen, :event_last_seen, :resource_role, :service_name, :user_feedback, :additional_info, :feature_name, :ebs_volume_scan_details, :runtime_details, :detection, :malware_scan_details) SENSITIVE = [] include Aws::Structure end |