Class: Aws::GuardDuty::Types::Signal
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::Signal
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the signals involved in the attack sequence.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#actor_ids ⇒ Array<String>
Information about the IDs of the threat actors involved in the signal.
-
#count ⇒ Integer
The number of times this signal was observed.
-
#created_at ⇒ Time
The timestamp when the first finding or activity related to this signal was observed.
-
#description ⇒ String
The description of the signal.
-
#endpoint_ids ⇒ Array<String>
Information about the endpoint IDs associated with this signal.
-
#first_seen_at ⇒ Time
The timestamp when the first finding or activity related to this signal was observed.
-
#last_seen_at ⇒ Time
The timestamp when the last finding or activity related to this signal was observed.
-
#name ⇒ String
The name of the signal.
-
#resource_uids ⇒ Array<String>
Information about the unique identifiers of the resources involved in the signal.
-
#severity ⇒ Float
The severity associated with the signal.
-
#signal_indicators ⇒ Array<Types::Indicator>
Contains information about the indicators associated with the signals.
-
#type ⇒ String
The type of the signal used to identify an attack sequence.
-
#uid ⇒ String
The unique identifier of the signal.
-
#updated_at ⇒ Time
The timestamp when this signal was last observed.
Instance Attribute Details
#actor_ids ⇒ Array<String>
Information about the IDs of the threat actors involved in the signal.
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |
#count ⇒ Integer
The number of times this signal was observed.
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The timestamp when the first finding or activity related to this signal was observed.
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the signal.
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |
#endpoint_ids ⇒ Array<String>
Information about the endpoint IDs associated with this signal.
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |
#first_seen_at ⇒ Time
The timestamp when the first finding or activity related to this signal was observed.
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |
#last_seen_at ⇒ Time
The timestamp when the last finding or activity related to this signal was observed.
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the signal. For example, when signal type is ‘FINDING`, the signal name is the name of the finding.
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |
#resource_uids ⇒ Array<String>
Information about the unique identifiers of the resources involved in the signal.
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ Float
The severity associated with the signal. For more information about severity, see [Findings severity levels] in the *Amazon GuardDuty User Guide*.
[1]: docs.aws.amazon.com/guardduty/latest/ug/guardduty_findings-severity.html
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |
#signal_indicators ⇒ Array<Types::Indicator>
Contains information about the indicators associated with the signals.
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the signal used to identify an attack sequence.
Signals can be GuardDuty findings or activities observed in data sources that GuardDuty monitors. For more information, see
- Foundational data sources][1
-
in the *Amazon GuardDuty User Guide*.
A signal type can be one of the valid values listed in this API. Here are the related descriptions:
-
‘FINDING` - Individually generated GuardDuty finding.
-
‘CLOUD_TRAIL` - Activity observed from CloudTrail logs
-
‘S3_DATA_EVENTS` - Activity observed from CloudTrail data events for S3. Activities associated with this type will show up only when you have enabled GuardDuty S3 Protection feature in your account. For more information about S3 Protection and steps to enable it, see [S3 Protection] in the *Amazon GuardDuty User Guide*.
[1]: docs.aws.amazon.com/guardduty/latest/ug/guardduty_data-sources.html [2]: docs.aws.amazon.com/guardduty/latest/ug/s3-protection.html
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |
#uid ⇒ String
The unique identifier of the signal.
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when this signal was last observed.
11826 11827 11828 11829 11830 11831 11832 11833 11834 11835 11836 11837 11838 11839 11840 11841 11842 11843 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11826 class Signal < Struct.new( :uid, :type, :description, :name, :created_at, :updated_at, :first_seen_at, :last_seen_at, :severity, :count, :resource_uids, :actor_ids, :endpoint_ids, :signal_indicators) SENSITIVE = [] include Aws::Structure end |