Class: Aws::GuardDuty::Types::StartMonitoringMembersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::StartMonitoringMembersRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
A list of account IDs of the GuardDuty member accounts to start monitoring.
-
#detector_id ⇒ String
The unique ID of the detector of the GuardDuty administrator account associated with the member accounts to monitor.
Instance Attribute Details
#account_ids ⇒ Array<String>
A list of account IDs of the GuardDuty member accounts to start monitoring.
12455 12456 12457 12458 12459 12460 |
# File 'lib/aws-sdk-guardduty/types.rb', line 12455 class StartMonitoringMembersRequest < Struct.new( :detector_id, :account_ids) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The unique ID of the detector of the GuardDuty administrator account associated with the member accounts to monitor.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
12455 12456 12457 12458 12459 12460 |
# File 'lib/aws-sdk-guardduty/types.rb', line 12455 class StartMonitoringMembersRequest < Struct.new( :detector_id, :account_ids) SENSITIVE = [] include Aws::Structure end |