Class: Aws::GuardDuty::Types::StartMonitoringMembersRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idsArray<String>

A list of account IDs of the GuardDuty member accounts to start monitoring.

Returns:

  • (Array<String>)


12329
12330
12331
12332
12333
12334
# File 'lib/aws-sdk-guardduty/types.rb', line 12329

class StartMonitoringMembersRequest < Struct.new(
  :detector_id,
  :account_ids)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The unique ID of the detector of the GuardDuty administrator account associated with the member accounts to monitor.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


12329
12330
12331
12332
12333
12334
# File 'lib/aws-sdk-guardduty/types.rb', line 12329

class StartMonitoringMembersRequest < Struct.new(
  :detector_id,
  :account_ids)
  SENSITIVE = []
  include Aws::Structure
end