Class: Aws::GuardDuty::Types::UnarchiveFindingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detector_idString

The ID of the detector associated with the findings to unarchive.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


12752
12753
12754
12755
12756
12757
# File 'lib/aws-sdk-guardduty/types.rb', line 12752

class UnarchiveFindingsRequest < Struct.new(
  :detector_id,
  :finding_ids)
  SENSITIVE = []
  include Aws::Structure
end

#finding_idsArray<String>

The IDs of the findings to unarchive.

Returns:

  • (Array<String>)


12752
12753
12754
12755
12756
12757
# File 'lib/aws-sdk-guardduty/types.rb', line 12752

class UnarchiveFindingsRequest < Struct.new(
  :detector_id,
  :finding_ids)
  SENSITIVE = []
  include Aws::Structure
end