Class: Aws::GuardDuty::Types::UnarchiveFindingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::UnarchiveFindingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The ID of the detector associated with the findings to unarchive.
-
#finding_ids ⇒ Array<String>
The IDs of the findings to unarchive.
Instance Attribute Details
#detector_id ⇒ String
The ID of the detector associated with the findings to unarchive.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
12752 12753 12754 12755 12756 12757 |
# File 'lib/aws-sdk-guardduty/types.rb', line 12752 class UnarchiveFindingsRequest < Struct.new( :detector_id, :finding_ids) SENSITIVE = [] include Aws::Structure end |
#finding_ids ⇒ Array<String>
The IDs of the findings to unarchive.
12752 12753 12754 12755 12756 12757 |
# File 'lib/aws-sdk-guardduty/types.rb', line 12752 class UnarchiveFindingsRequest < Struct.new( :detector_id, :finding_ids) SENSITIVE = [] include Aws::Structure end |