Class: Aws::GuardDuty::Types::UnarchiveFindingsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::UnarchiveFindingsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#detector_id ⇒ String
The ID of the detector associated with the findings to unarchive.
-
#finding_ids ⇒ Array<String>
The IDs of the findings to unarchive.
Instance Attribute Details
#detector_id ⇒ String
The ID of the detector associated with the findings to unarchive.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
12730 12731 12732 12733 12734 12735 |
# File 'lib/aws-sdk-guardduty/types.rb', line 12730 class UnarchiveFindingsRequest < Struct.new( :detector_id, :finding_ids) SENSITIVE = [] include Aws::Structure end |
#finding_ids ⇒ Array<String>
The IDs of the findings to unarchive.
12730 12731 12732 12733 12734 12735 |
# File 'lib/aws-sdk-guardduty/types.rb', line 12730 class UnarchiveFindingsRequest < Struct.new( :detector_id, :finding_ids) SENSITIVE = [] include Aws::Structure end |