Class: Aws::GuardDuty::Types::UpdateDetectorRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_sourcesTypes::DataSourceConfigurations

Describes which data sources will be updated.

There might be regional differences because some data sources might not be available in all the Amazon Web Services Regions where GuardDuty is presently supported. For more information, see Regions and endpoints.



12857
12858
12859
12860
12861
12862
12863
12864
12865
# File 'lib/aws-sdk-guardduty/types.rb', line 12857

class UpdateDetectorRequest < Struct.new(
  :detector_id,
  :enable,
  :finding_publishing_frequency,
  :data_sources,
  :features)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The unique ID of the detector to update.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


12857
12858
12859
12860
12861
12862
12863
12864
12865
# File 'lib/aws-sdk-guardduty/types.rb', line 12857

class UpdateDetectorRequest < Struct.new(
  :detector_id,
  :enable,
  :finding_publishing_frequency,
  :data_sources,
  :features)
  SENSITIVE = []
  include Aws::Structure
end

#enableBoolean

Specifies whether the detector is enabled or not enabled.

Returns:

  • (Boolean)


12857
12858
12859
12860
12861
12862
12863
12864
12865
# File 'lib/aws-sdk-guardduty/types.rb', line 12857

class UpdateDetectorRequest < Struct.new(
  :detector_id,
  :enable,
  :finding_publishing_frequency,
  :data_sources,
  :features)
  SENSITIVE = []
  include Aws::Structure
end

#featuresArray<Types::DetectorFeatureConfiguration>

Provides the features that will be updated for the detector.



12857
12858
12859
12860
12861
12862
12863
12864
12865
# File 'lib/aws-sdk-guardduty/types.rb', line 12857

class UpdateDetectorRequest < Struct.new(
  :detector_id,
  :enable,
  :finding_publishing_frequency,
  :data_sources,
  :features)
  SENSITIVE = []
  include Aws::Structure
end

#finding_publishing_frequencyString

An enum value that specifies how frequently findings are exported, such as to CloudWatch Events.

Returns:

  • (String)


12857
12858
12859
12860
12861
12862
12863
12864
12865
# File 'lib/aws-sdk-guardduty/types.rb', line 12857

class UpdateDetectorRequest < Struct.new(
  :detector_id,
  :enable,
  :finding_publishing_frequency,
  :data_sources,
  :features)
  SENSITIVE = []
  include Aws::Structure
end