Class: Aws::GuardDuty::Types::UpdateDetectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::UpdateDetectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_sources ⇒ Types::DataSourceConfigurations
Describes which data sources will be updated.
-
#detector_id ⇒ String
The unique ID of the detector to update.
-
#enable ⇒ Boolean
Specifies whether the detector is enabled or not enabled.
-
#features ⇒ Array<Types::DetectorFeatureConfiguration>
Provides the features that will be updated for the detector.
-
#finding_publishing_frequency ⇒ String
An enum value that specifies how frequently findings are exported, such as to CloudWatch Events.
Instance Attribute Details
#data_sources ⇒ Types::DataSourceConfigurations
Describes which data sources will be updated.
There might be regional differences because some data sources might not be available in all the Amazon Web Services Regions where GuardDuty is presently supported. For more information, see [Regions and endpoints].
[1]: docs.aws.amazon.com/guardduty/latest/ug/guardduty_regions.html
12334 12335 12336 12337 12338 12339 12340 12341 12342 |
# File 'lib/aws-sdk-guardduty/types.rb', line 12334 class UpdateDetectorRequest < Struct.new( :detector_id, :enable, :finding_publishing_frequency, :data_sources, :features) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The unique ID of the detector to update.
To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
12334 12335 12336 12337 12338 12339 12340 12341 12342 |
# File 'lib/aws-sdk-guardduty/types.rb', line 12334 class UpdateDetectorRequest < Struct.new( :detector_id, :enable, :finding_publishing_frequency, :data_sources, :features) SENSITIVE = [] include Aws::Structure end |
#enable ⇒ Boolean
Specifies whether the detector is enabled or not enabled.
12334 12335 12336 12337 12338 12339 12340 12341 12342 |
# File 'lib/aws-sdk-guardduty/types.rb', line 12334 class UpdateDetectorRequest < Struct.new( :detector_id, :enable, :finding_publishing_frequency, :data_sources, :features) SENSITIVE = [] include Aws::Structure end |
#features ⇒ Array<Types::DetectorFeatureConfiguration>
Provides the features that will be updated for the detector.
12334 12335 12336 12337 12338 12339 12340 12341 12342 |
# File 'lib/aws-sdk-guardduty/types.rb', line 12334 class UpdateDetectorRequest < Struct.new( :detector_id, :enable, :finding_publishing_frequency, :data_sources, :features) SENSITIVE = [] include Aws::Structure end |
#finding_publishing_frequency ⇒ String
An enum value that specifies how frequently findings are exported, such as to CloudWatch Events.
12334 12335 12336 12337 12338 12339 12340 12341 12342 |
# File 'lib/aws-sdk-guardduty/types.rb', line 12334 class UpdateDetectorRequest < Struct.new( :detector_id, :enable, :finding_publishing_frequency, :data_sources, :features) SENSITIVE = [] include Aws::Structure end |