Class: Aws::GuardDuty::Types::UpdateFilterRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::UpdateFilterRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
Specifies the action that is to be applied to the findings that match the filter.
-
#description ⇒ String
The description of the filter.
-
#detector_id ⇒ String
The unique ID of the detector that specifies the GuardDuty service where you want to update a filter.
-
#filter_name ⇒ String
The name of the filter.
-
#finding_criteria ⇒ Types::FindingCriteria
Represents the criteria to be used in the filter for querying findings.
-
#rank ⇒ Integer
Specifies the position of the filter in the list of current filters.
Instance Attribute Details
#action ⇒ String
Specifies the action that is to be applied to the findings that match the filter.
11180 11181 11182 11183 11184 11185 11186 11187 11188 11189 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11180 class UpdateFilterRequest < Struct.new( :detector_id, :filter_name, :description, :action, :rank, :finding_criteria) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the filter. Valid characters include alphanumeric characters, and special characters such as hyphen, period, colon, underscore, parentheses (‘{ }`, `[ ]`, and `( )`), forward slash, horizontal tab, vertical tab, newline, form feed, return, and whitespace.
11180 11181 11182 11183 11184 11185 11186 11187 11188 11189 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11180 class UpdateFilterRequest < Struct.new( :detector_id, :filter_name, :description, :action, :rank, :finding_criteria) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The unique ID of the detector that specifies the GuardDuty service where you want to update a filter.
To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
11180 11181 11182 11183 11184 11185 11186 11187 11188 11189 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11180 class UpdateFilterRequest < Struct.new( :detector_id, :filter_name, :description, :action, :rank, :finding_criteria) SENSITIVE = [] include Aws::Structure end |
#filter_name ⇒ String
The name of the filter.
11180 11181 11182 11183 11184 11185 11186 11187 11188 11189 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11180 class UpdateFilterRequest < Struct.new( :detector_id, :filter_name, :description, :action, :rank, :finding_criteria) SENSITIVE = [] include Aws::Structure end |
#finding_criteria ⇒ Types::FindingCriteria
Represents the criteria to be used in the filter for querying findings.
11180 11181 11182 11183 11184 11185 11186 11187 11188 11189 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11180 class UpdateFilterRequest < Struct.new( :detector_id, :filter_name, :description, :action, :rank, :finding_criteria) SENSITIVE = [] include Aws::Structure end |
#rank ⇒ Integer
Specifies the position of the filter in the list of current filters. Also specifies the order in which this filter is applied to the findings.
11180 11181 11182 11183 11184 11185 11186 11187 11188 11189 |
# File 'lib/aws-sdk-guardduty/types.rb', line 11180 class UpdateFilterRequest < Struct.new( :detector_id, :filter_name, :description, :action, :rank, :finding_criteria) SENSITIVE = [] include Aws::Structure end |