Class: Aws::GuardDuty::Types::UpdateFindingsFeedbackRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::UpdateFindingsFeedbackRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:comments]
Instance Attribute Summary collapse
-
#comments ⇒ String
Additional feedback about the GuardDuty findings.
-
#detector_id ⇒ String
The ID of the detector that is associated with the findings for which you want to update the feedback.
-
#feedback ⇒ String
The feedback for the finding.
-
#finding_ids ⇒ Array<String>
The IDs of the findings that you want to mark as useful or not useful.
Instance Attribute Details
#comments ⇒ String
Additional feedback about the GuardDuty findings.
14308 14309 14310 14311 14312 14313 14314 14315 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14308 class UpdateFindingsFeedbackRequest < Struct.new( :detector_id, :finding_ids, :feedback, :comments) SENSITIVE = [:comments] include Aws::Structure end |
#detector_id ⇒ String
The ID of the detector that is associated with the findings for which you want to update the feedback.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
14308 14309 14310 14311 14312 14313 14314 14315 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14308 class UpdateFindingsFeedbackRequest < Struct.new( :detector_id, :finding_ids, :feedback, :comments) SENSITIVE = [:comments] include Aws::Structure end |
#feedback ⇒ String
The feedback for the finding.
14308 14309 14310 14311 14312 14313 14314 14315 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14308 class UpdateFindingsFeedbackRequest < Struct.new( :detector_id, :finding_ids, :feedback, :comments) SENSITIVE = [:comments] include Aws::Structure end |
#finding_ids ⇒ Array<String>
The IDs of the findings that you want to mark as useful or not useful.
14308 14309 14310 14311 14312 14313 14314 14315 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14308 class UpdateFindingsFeedbackRequest < Struct.new( :detector_id, :finding_ids, :feedback, :comments) SENSITIVE = [:comments] include Aws::Structure end |