Class: Aws::GuardDuty::Types::UpdateFindingsFeedbackRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:comments]

Instance Attribute Summary collapse

Instance Attribute Details

#commentsString

Additional feedback about the GuardDuty findings.

Returns:

  • (String)


11230
11231
11232
11233
11234
11235
11236
11237
# File 'lib/aws-sdk-guardduty/types.rb', line 11230

class UpdateFindingsFeedbackRequest < Struct.new(
  :detector_id,
  :finding_ids,
  :feedback,
  :comments)
  SENSITIVE = [:comments]
  include Aws::Structure
end

#detector_idString

The ID of the detector that is associated with the findings for which you want to update the feedback.

To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

Returns:

  • (String)


11230
11231
11232
11233
11234
11235
11236
11237
# File 'lib/aws-sdk-guardduty/types.rb', line 11230

class UpdateFindingsFeedbackRequest < Struct.new(
  :detector_id,
  :finding_ids,
  :feedback,
  :comments)
  SENSITIVE = [:comments]
  include Aws::Structure
end

#feedbackString

The feedback for the finding.

Returns:

  • (String)


11230
11231
11232
11233
11234
11235
11236
11237
# File 'lib/aws-sdk-guardduty/types.rb', line 11230

class UpdateFindingsFeedbackRequest < Struct.new(
  :detector_id,
  :finding_ids,
  :feedback,
  :comments)
  SENSITIVE = [:comments]
  include Aws::Structure
end

#finding_idsArray<String>

The IDs of the findings that you want to mark as useful or not useful.

Returns:

  • (Array<String>)


11230
11231
11232
11233
11234
11235
11236
11237
# File 'lib/aws-sdk-guardduty/types.rb', line 11230

class UpdateFindingsFeedbackRequest < Struct.new(
  :detector_id,
  :finding_ids,
  :feedback,
  :comments)
  SENSITIVE = [:comments]
  include Aws::Structure
end