Class: Aws::GuardDuty::Types::UpdateIPSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activateBoolean

The updated Boolean value that specifies whether the IPSet is active or not.

Returns:

  • (Boolean)


14209
14210
14211
14212
14213
14214
14215
14216
14217
14218
# File 'lib/aws-sdk-guardduty/types.rb', line 14209

class UpdateIPSetRequest < Struct.new(
  :detector_id,
  :ip_set_id,
  :name,
  :location,
  :activate,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The detectorID that specifies the GuardDuty service whose IPSet you want to update.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


14209
14210
14211
14212
14213
14214
14215
14216
14217
14218
# File 'lib/aws-sdk-guardduty/types.rb', line 14209

class UpdateIPSetRequest < Struct.new(
  :detector_id,
  :ip_set_id,
  :name,
  :location,
  :activate,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.

Returns:

  • (String)


14209
14210
14211
14212
14213
14214
14215
14216
14217
14218
# File 'lib/aws-sdk-guardduty/types.rb', line 14209

class UpdateIPSetRequest < Struct.new(
  :detector_id,
  :ip_set_id,
  :name,
  :location,
  :activate,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#ip_set_idString

The unique ID that specifies the IPSet that you want to update.

Returns:

  • (String)


14209
14210
14211
14212
14213
14214
14215
14216
14217
14218
# File 'lib/aws-sdk-guardduty/types.rb', line 14209

class UpdateIPSetRequest < Struct.new(
  :detector_id,
  :ip_set_id,
  :name,
  :location,
  :activate,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The updated URI of the file that contains the IPSet.

Returns:

  • (String)


14209
14210
14211
14212
14213
14214
14215
14216
14217
14218
# File 'lib/aws-sdk-guardduty/types.rb', line 14209

class UpdateIPSetRequest < Struct.new(
  :detector_id,
  :ip_set_id,
  :name,
  :location,
  :activate,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The unique ID that specifies the IPSet that you want to update.

Returns:

  • (String)


14209
14210
14211
14212
14213
14214
14215
14216
14217
14218
# File 'lib/aws-sdk-guardduty/types.rb', line 14209

class UpdateIPSetRequest < Struct.new(
  :detector_id,
  :ip_set_id,
  :name,
  :location,
  :activate,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end