Class: Aws::GuardDuty::Types::UpdateMemberDetectorsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::UpdateMemberDetectorsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
A list of member account IDs to be updated.
-
#data_sources ⇒ Types::DataSourceConfigurations
Describes which data sources will be updated.
-
#detector_id ⇒ String
The detector ID of the administrator account.
-
#features ⇒ Array<Types::MemberFeaturesConfiguration>
A list of features that will be updated for the specified member accounts.
Instance Attribute Details
#account_ids ⇒ Array<String>
A list of member account IDs to be updated.
14316 14317 14318 14319 14320 14321 14322 14323 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14316 class UpdateMemberDetectorsRequest < Struct.new( :detector_id, :account_ids, :data_sources, :features) SENSITIVE = [] include Aws::Structure end |
#data_sources ⇒ Types::DataSourceConfigurations
Describes which data sources will be updated.
14316 14317 14318 14319 14320 14321 14322 14323 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14316 class UpdateMemberDetectorsRequest < Struct.new( :detector_id, :account_ids, :data_sources, :features) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The detector ID of the administrator account.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
14316 14317 14318 14319 14320 14321 14322 14323 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14316 class UpdateMemberDetectorsRequest < Struct.new( :detector_id, :account_ids, :data_sources, :features) SENSITIVE = [] include Aws::Structure end |
#features ⇒ Array<Types::MemberFeaturesConfiguration>
A list of features that will be updated for the specified member accounts.
14316 14317 14318 14319 14320 14321 14322 14323 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14316 class UpdateMemberDetectorsRequest < Struct.new( :detector_id, :account_ids, :data_sources, :features) SENSITIVE = [] include Aws::Structure end |