Class: Aws::GuardDuty::Types::UpdateThreatEntitySetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::UpdateThreatEntitySetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activate ⇒ Boolean
A boolean value that indicates whether GuardDuty is to start using this updated threat entity set.
-
#detector_id ⇒ String
The unique ID of the GuardDuty detector associated with the threat entity set that you want to update.
-
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
-
#location ⇒ String
The URI of the file that contains the trusted entity set.
-
#name ⇒ String
A user-friendly name to identify the trusted entity set.
-
#threat_entity_set_id ⇒ String
The ID returned by GuardDuty after updating the threat entity set resource.
Instance Attribute Details
#activate ⇒ Boolean
A boolean value that indicates whether GuardDuty is to start using this updated threat entity set. After you update an entity set, you will need to activate it again. It might take up to 15 minutes for the updated entity set to be effective.
14105 14106 14107 14108 14109 14110 14111 14112 14113 14114 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14105 class UpdateThreatEntitySetRequest < Struct.new( :detector_id, :threat_entity_set_id, :name, :location, :expected_bucket_owner, :activate) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The unique ID of the GuardDuty detector associated with the threat entity set that you want to update.
To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
14105 14106 14107 14108 14109 14110 14111 14112 14113 14114 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14105 class UpdateThreatEntitySetRequest < Struct.new( :detector_id, :threat_entity_set_id, :name, :location, :expected_bucket_owner, :activate) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
14105 14106 14107 14108 14109 14110 14111 14112 14113 14114 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14105 class UpdateThreatEntitySetRequest < Struct.new( :detector_id, :threat_entity_set_id, :name, :location, :expected_bucket_owner, :activate) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The URI of the file that contains the trusted entity set.
14105 14106 14107 14108 14109 14110 14111 14112 14113 14114 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14105 class UpdateThreatEntitySetRequest < Struct.new( :detector_id, :threat_entity_set_id, :name, :location, :expected_bucket_owner, :activate) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A user-friendly name to identify the trusted entity set.
The name of your list can include lowercase letters, uppercase letters, numbers, dash (-), and underscore (_).
14105 14106 14107 14108 14109 14110 14111 14112 14113 14114 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14105 class UpdateThreatEntitySetRequest < Struct.new( :detector_id, :threat_entity_set_id, :name, :location, :expected_bucket_owner, :activate) SENSITIVE = [] include Aws::Structure end |
#threat_entity_set_id ⇒ String
The ID returned by GuardDuty after updating the threat entity set resource.
14105 14106 14107 14108 14109 14110 14111 14112 14113 14114 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14105 class UpdateThreatEntitySetRequest < Struct.new( :detector_id, :threat_entity_set_id, :name, :location, :expected_bucket_owner, :activate) SENSITIVE = [] include Aws::Structure end |