Class: Aws::GuardDuty::Types::UpdateThreatIntelSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::UpdateThreatIntelSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activate ⇒ Boolean
The updated Boolean value that specifies whether the ThreateIntelSet is active or not.
-
#detector_id ⇒ String
The detectorID that specifies the GuardDuty service whose ThreatIntelSet you want to update.
-
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
-
#location ⇒ String
The updated URI of the file that contains the ThreateIntelSet.
-
#name ⇒ String
The unique ID that specifies the ThreatIntelSet that you want to update.
-
#threat_intel_set_id ⇒ String
The unique ID that specifies the ThreatIntelSet that you want to update.
Instance Attribute Details
#activate ⇒ Boolean
The updated Boolean value that specifies whether the ThreateIntelSet is active or not.
14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14726 class UpdateThreatIntelSetRequest < Struct.new( :detector_id, :threat_intel_set_id, :name, :location, :activate, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The detectorID that specifies the GuardDuty service whose ThreatIntelSet you want to update.
To find the detectorId in the current Region, see the Settings
page in the GuardDuty console, or run the ListDetectors API.
14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14726 class UpdateThreatIntelSetRequest < Struct.new( :detector_id, :threat_intel_set_id, :name, :location, :activate, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14726 class UpdateThreatIntelSetRequest < Struct.new( :detector_id, :threat_intel_set_id, :name, :location, :activate, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The updated URI of the file that contains the ThreateIntelSet.
14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14726 class UpdateThreatIntelSetRequest < Struct.new( :detector_id, :threat_intel_set_id, :name, :location, :activate, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The unique ID that specifies the ThreatIntelSet that you want to update.
14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14726 class UpdateThreatIntelSetRequest < Struct.new( :detector_id, :threat_intel_set_id, :name, :location, :activate, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#threat_intel_set_id ⇒ String
The unique ID that specifies the ThreatIntelSet that you want to update.
14726 14727 14728 14729 14730 14731 14732 14733 14734 14735 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14726 class UpdateThreatIntelSetRequest < Struct.new( :detector_id, :threat_intel_set_id, :name, :location, :activate, :expected_bucket_owner) SENSITIVE = [] include Aws::Structure end |