Class: Aws::GuardDuty::Types::UpdateThreatIntelSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activateBoolean

The updated Boolean value that specifies whether the ThreateIntelSet is active or not.

Returns:

  • (Boolean)


14704
14705
14706
14707
14708
14709
14710
14711
14712
14713
# File 'lib/aws-sdk-guardduty/types.rb', line 14704

class UpdateThreatIntelSetRequest < Struct.new(
  :detector_id,
  :threat_intel_set_id,
  :name,
  :location,
  :activate,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The detectorID that specifies the GuardDuty service whose ThreatIntelSet you want to update.

To find the detectorId in the current Region, see the Settings page in the GuardDuty console, or run the ListDetectors API.

Returns:

  • (String)


14704
14705
14706
14707
14708
14709
14710
14711
14712
14713
# File 'lib/aws-sdk-guardduty/types.rb', line 14704

class UpdateThreatIntelSetRequest < Struct.new(
  :detector_id,
  :threat_intel_set_id,
  :name,
  :location,
  :activate,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.

Returns:

  • (String)


14704
14705
14706
14707
14708
14709
14710
14711
14712
14713
# File 'lib/aws-sdk-guardduty/types.rb', line 14704

class UpdateThreatIntelSetRequest < Struct.new(
  :detector_id,
  :threat_intel_set_id,
  :name,
  :location,
  :activate,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The updated URI of the file that contains the ThreateIntelSet.

Returns:

  • (String)


14704
14705
14706
14707
14708
14709
14710
14711
14712
14713
# File 'lib/aws-sdk-guardduty/types.rb', line 14704

class UpdateThreatIntelSetRequest < Struct.new(
  :detector_id,
  :threat_intel_set_id,
  :name,
  :location,
  :activate,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The unique ID that specifies the ThreatIntelSet that you want to update.

Returns:

  • (String)


14704
14705
14706
14707
14708
14709
14710
14711
14712
14713
# File 'lib/aws-sdk-guardduty/types.rb', line 14704

class UpdateThreatIntelSetRequest < Struct.new(
  :detector_id,
  :threat_intel_set_id,
  :name,
  :location,
  :activate,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end

#threat_intel_set_idString

The unique ID that specifies the ThreatIntelSet that you want to update.

Returns:

  • (String)


14704
14705
14706
14707
14708
14709
14710
14711
14712
14713
# File 'lib/aws-sdk-guardduty/types.rb', line 14704

class UpdateThreatIntelSetRequest < Struct.new(
  :detector_id,
  :threat_intel_set_id,
  :name,
  :location,
  :activate,
  :expected_bucket_owner)
  SENSITIVE = []
  include Aws::Structure
end