Class: Aws::GuardDuty::Types::UpdateTrustedEntitySetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::UpdateTrustedEntitySetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activate ⇒ Boolean
A boolean value that indicates whether GuardDuty is to start using this updated trusted entity set.
-
#detector_id ⇒ String
The unique ID of the GuardDuty detector associated with the threat entity set that you want to update.
-
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
-
#location ⇒ String
The URI of the file that contains the trusted entity set.
-
#name ⇒ String
A user-friendly name to identify the trusted entity set.
-
#trusted_entity_set_id ⇒ String
The ID returned by GuardDuty after updating the trusted entity set resource.
Instance Attribute Details
#activate ⇒ Boolean
A boolean value that indicates whether GuardDuty is to start using this updated trusted entity set. After you update an entity set, you will need to activate it again. It might take up to 15 minutes for the updated entity set to be effective.
14635 14636 14637 14638 14639 14640 14641 14642 14643 14644 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14635 class UpdateTrustedEntitySetRequest < Struct.new( :detector_id, :trusted_entity_set_id, :name, :location, :expected_bucket_owner, :activate) SENSITIVE = [] include Aws::Structure end |
#detector_id ⇒ String
The unique ID of the GuardDuty detector associated with the threat entity set that you want to update.
To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.
[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html
14635 14636 14637 14638 14639 14640 14641 14642 14643 14644 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14635 class UpdateTrustedEntitySetRequest < Struct.new( :detector_id, :trusted_entity_set_id, :name, :location, :expected_bucket_owner, :activate) SENSITIVE = [] include Aws::Structure end |
#expected_bucket_owner ⇒ String
The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.
14635 14636 14637 14638 14639 14640 14641 14642 14643 14644 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14635 class UpdateTrustedEntitySetRequest < Struct.new( :detector_id, :trusted_entity_set_id, :name, :location, :expected_bucket_owner, :activate) SENSITIVE = [] include Aws::Structure end |
#location ⇒ String
The URI of the file that contains the trusted entity set.
14635 14636 14637 14638 14639 14640 14641 14642 14643 14644 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14635 class UpdateTrustedEntitySetRequest < Struct.new( :detector_id, :trusted_entity_set_id, :name, :location, :expected_bucket_owner, :activate) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A user-friendly name to identify the trusted entity set.
The name of your list can include lowercase letters, uppercase letters, numbers, dash (-), and underscore (_).
14635 14636 14637 14638 14639 14640 14641 14642 14643 14644 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14635 class UpdateTrustedEntitySetRequest < Struct.new( :detector_id, :trusted_entity_set_id, :name, :location, :expected_bucket_owner, :activate) SENSITIVE = [] include Aws::Structure end |
#trusted_entity_set_id ⇒ String
The ID returned by GuardDuty after updating the trusted entity set resource.
14635 14636 14637 14638 14639 14640 14641 14642 14643 14644 |
# File 'lib/aws-sdk-guardduty/types.rb', line 14635 class UpdateTrustedEntitySetRequest < Struct.new( :detector_id, :trusted_entity_set_id, :name, :location, :expected_bucket_owner, :activate) SENSITIVE = [] include Aws::Structure end |