Class: Aws::GuardDuty::Types::UpdateTrustedEntitySetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#activateBoolean

A boolean value that indicates whether GuardDuty is to start using this updated trusted entity set. After you update an entity set, you will need to activate it again. It might take up to 15 minutes for the updated entity set to be effective.

Returns:

  • (Boolean)


14293
14294
14295
14296
14297
14298
14299
14300
14301
14302
# File 'lib/aws-sdk-guardduty/types.rb', line 14293

class UpdateTrustedEntitySetRequest < Struct.new(
  :detector_id,
  :trusted_entity_set_id,
  :name,
  :location,
  :expected_bucket_owner,
  :activate)
  SENSITIVE = []
  include Aws::Structure
end

#detector_idString

The unique ID of the GuardDuty detector associated with the threat entity set that you want to update.

To find the ‘detectorId` in the current Region, see the Settings page in the GuardDuty console, or run the [ListDetectors] API.

[1]: docs.aws.amazon.com/guardduty/latest/APIReference/API_ListDetectors.html

Returns:

  • (String)


14293
14294
14295
14296
14297
14298
14299
14300
14301
14302
# File 'lib/aws-sdk-guardduty/types.rb', line 14293

class UpdateTrustedEntitySetRequest < Struct.new(
  :detector_id,
  :trusted_entity_set_id,
  :name,
  :location,
  :expected_bucket_owner,
  :activate)
  SENSITIVE = []
  include Aws::Structure
end

#expected_bucket_ownerString

The Amazon Web Services account ID that owns the Amazon S3 bucket specified in the location parameter.

Returns:

  • (String)


14293
14294
14295
14296
14297
14298
14299
14300
14301
14302
# File 'lib/aws-sdk-guardduty/types.rb', line 14293

class UpdateTrustedEntitySetRequest < Struct.new(
  :detector_id,
  :trusted_entity_set_id,
  :name,
  :location,
  :expected_bucket_owner,
  :activate)
  SENSITIVE = []
  include Aws::Structure
end

#locationString

The URI of the file that contains the trusted entity set.

Returns:

  • (String)


14293
14294
14295
14296
14297
14298
14299
14300
14301
14302
# File 'lib/aws-sdk-guardduty/types.rb', line 14293

class UpdateTrustedEntitySetRequest < Struct.new(
  :detector_id,
  :trusted_entity_set_id,
  :name,
  :location,
  :expected_bucket_owner,
  :activate)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A user-friendly name to identify the trusted entity set.

The name of your list can include lowercase letters, uppercase letters, numbers, dash (-), and underscore (_).

Returns:

  • (String)


14293
14294
14295
14296
14297
14298
14299
14300
14301
14302
# File 'lib/aws-sdk-guardduty/types.rb', line 14293

class UpdateTrustedEntitySetRequest < Struct.new(
  :detector_id,
  :trusted_entity_set_id,
  :name,
  :location,
  :expected_bucket_owner,
  :activate)
  SENSITIVE = []
  include Aws::Structure
end

#trusted_entity_set_idString

The ID returned by GuardDuty after updating the trusted entity set resource.

Returns:

  • (String)


14293
14294
14295
14296
14297
14298
14299
14300
14301
14302
# File 'lib/aws-sdk-guardduty/types.rb', line 14293

class UpdateTrustedEntitySetRequest < Struct.new(
  :detector_id,
  :trusted_entity_set_id,
  :name,
  :location,
  :expected_bucket_owner,
  :activate)
  SENSITIVE = []
  include Aws::Structure
end