Class: Aws::GuardDuty::Types::UsageTopAccountsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Information about the usage statistics, calculated by top accounts by feature.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accountsArray<Types::UsageTopAccountResult>

The accounts that contributed to the total usage cost.

Returns:



14967
14968
14969
14970
14971
14972
# File 'lib/aws-sdk-guardduty/types.rb', line 14967

class UsageTopAccountsResult < Struct.new(
  :feature,
  :accounts)
  SENSITIVE = []
  include Aws::Structure
end

#featureString

Features by which you can generate the usage statistics.

RDS_LOGIN_EVENTS is currently not supported with topAccountsByFeature.

Returns:

  • (String)


14967
14968
14969
14970
14971
14972
# File 'lib/aws-sdk-guardduty/types.rb', line 14967

class UsageTopAccountsResult < Struct.new(
  :feature,
  :accounts)
  SENSITIVE = []
  include Aws::Structure
end