Class: Aws::GuardDuty::Types::User
- Inherits:
-
Struct
- Object
- Struct
- Aws::GuardDuty::Types::User
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-guardduty/types.rb
Overview
Contains information about the user involved in the attack sequence.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account ⇒ Types::Account
Contains information about the Amazon Web Services account within which the activity took place.
-
#credential_uid ⇒ String
The credentials of the user ID.
-
#name ⇒ String
The name of the user.
-
#type ⇒ String
The type of the user.
-
#uid ⇒ String
The unique identifier of the user.
Instance Attribute Details
#account ⇒ Types::Account
Contains information about the Amazon Web Services account within which the activity took place. This is not necessarily the account that owns the user identity.
15022 15023 15024 15025 15026 15027 15028 15029 15030 |
# File 'lib/aws-sdk-guardduty/types.rb', line 15022 class User < Struct.new( :name, :uid, :type, :credential_uid, :account) SENSITIVE = [] include Aws::Structure end |
#credential_uid ⇒ String
The credentials of the user ID.
15022 15023 15024 15025 15026 15027 15028 15029 15030 |
# File 'lib/aws-sdk-guardduty/types.rb', line 15022 class User < Struct.new( :name, :uid, :type, :credential_uid, :account) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the user.
15022 15023 15024 15025 15026 15027 15028 15029 15030 |
# File 'lib/aws-sdk-guardduty/types.rb', line 15022 class User < Struct.new( :name, :uid, :type, :credential_uid, :account) SENSITIVE = [] include Aws::Structure end |