Class: Aws::GuardDuty::Types::User

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about the user involved in the attack sequence.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accountTypes::Account

Contains information about the Amazon Web Services account within which the activity took place. This is not necessarily the account that owns the user identity.

Returns:



14874
14875
14876
14877
14878
14879
14880
14881
14882
# File 'lib/aws-sdk-guardduty/types.rb', line 14874

class User < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#credential_uidString

The credentials of the user ID.

Returns:

  • (String)


14874
14875
14876
14877
14878
14879
14880
14881
14882
# File 'lib/aws-sdk-guardduty/types.rb', line 14874

class User < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the user.

Returns:

  • (String)


14874
14875
14876
14877
14878
14879
14880
14881
14882
# File 'lib/aws-sdk-guardduty/types.rb', line 14874

class User < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the user.

Returns:

  • (String)


14874
14875
14876
14877
14878
14879
14880
14881
14882
# File 'lib/aws-sdk-guardduty/types.rb', line 14874

class User < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#uidString

The unique identifier of the user.

Returns:

  • (String)


14874
14875
14876
14877
14878
14879
14880
14881
14882
# File 'lib/aws-sdk-guardduty/types.rb', line 14874

class User < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end