Class: Aws::GuardDuty::Types::User

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-guardduty/types.rb

Overview

Contains information about the user involved in the attack sequence.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#accountTypes::Account

Contains information about the Amazon Web Services account within which the activity took place. This is not necessarily the account that owns the user identity.

Returns:



14456
14457
14458
14459
14460
14461
14462
14463
14464
# File 'lib/aws-sdk-guardduty/types.rb', line 14456

class User < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#credential_uidString

The credentials of the user ID.

Returns:

  • (String)


14456
14457
14458
14459
14460
14461
14462
14463
14464
# File 'lib/aws-sdk-guardduty/types.rb', line 14456

class User < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the user.

Returns:

  • (String)


14456
14457
14458
14459
14460
14461
14462
14463
14464
# File 'lib/aws-sdk-guardduty/types.rb', line 14456

class User < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of the user.

Returns:

  • (String)


14456
14457
14458
14459
14460
14461
14462
14463
14464
# File 'lib/aws-sdk-guardduty/types.rb', line 14456

class User < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end

#uidString

The unique identifier of the user.

Returns:

  • (String)


14456
14457
14458
14459
14460
14461
14462
14463
14464
# File 'lib/aws-sdk-guardduty/types.rb', line 14456

class User < Struct.new(
  :name,
  :uid,
  :type,
  :credential_uid,
  :account)
  SENSITIVE = []
  include Aws::Structure
end